accessanalyzer_create_service_linked_analyzer: Creates a service-linked analyzer managed by an Amazon Web...

View source: R/accessanalyzer_operations.R

accessanalyzer_create_service_linked_analyzerR Documentation

Creates a service-linked analyzer managed by an Amazon Web Services service

Description

Creates a service-linked analyzer managed by an Amazon Web Services service. This operation can only be invoked by authorized Amazon Web Services services. Direct customer invocation returns AccessDeniedException.

See https://www.paws-r-sdk.com/docs/accessanalyzer_create_service_linked_analyzer/ for full documentation.

Usage

accessanalyzer_create_service_linked_analyzer(
  type,
  archiveRules = NULL,
  clientToken = NULL,
  configuration = NULL
)

Arguments

type

[required] The type of analyzer to create. Valid values are ACCOUNT_UNUSED_ACCESS and ORGANIZATION_UNUSED_ACCESS.

archiveRules

Specifies the archive rules to add for the analyzer. Archive rules automatically archive findings that meet the criteria you define for the rule.

clientToken

A client token.

configuration

Specifies the configuration of the analyzer. The specified scope of unused access is used for the configuration.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.