acm_describe_acme_account: Returns detailed metadata about the specified ACME account,...

View source: R/acm_operations.R

acm_describe_acme_accountR Documentation

Returns detailed metadata about the specified ACME account, including its status, public key thumbprint, and associated external account binding

Description

Returns detailed metadata about the specified ACME account, including its status, public key thumbprint, and associated external account binding.

See https://www.paws-r-sdk.com/docs/acm_describe_acme_account/ for full documentation.

Usage

acm_describe_acme_account(AcmeEndpointArn, AccountUrl)

Arguments

AcmeEndpointArn

[required] The Amazon Resource Name (ARN) of the ACME endpoint.

AccountUrl

[required] The URL of the ACME account.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.