acm_describe_acme_external_account_binding: Returns detailed metadata about the specified external...

View source: R/acm_operations.R

acm_describe_acme_external_account_bindingR Documentation

Returns detailed metadata about the specified external account binding, including the associated IAM role, expiration time, and usage history

Description

Returns detailed metadata about the specified external account binding, including the associated IAM role, expiration time, and usage history.

See https://www.paws-r-sdk.com/docs/acm_describe_acme_external_account_binding/ for full documentation.

Usage

acm_describe_acme_external_account_binding(AcmeExternalAccountBindingArn)

Arguments

AcmeExternalAccountBindingArn

[required] The Amazon Resource Name (ARN) of the ACME external account binding.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.