acm_list_acme_external_account_bindings: Retrieves a list of external account bindings for the...

View source: R/acm_operations.R

acm_list_acme_external_account_bindingsR Documentation

Retrieves a list of external account bindings for the specified ACME endpoint

Description

Retrieves a list of external account bindings for the specified ACME endpoint.

See https://www.paws-r-sdk.com/docs/acm_list_acme_external_account_bindings/ for full documentation.

Usage

acm_list_acme_external_account_bindings(
  NextToken = NULL,
  MaxResults = NULL,
  AcmeEndpointArn
)

Arguments

NextToken

A token for pagination.

MaxResults

The maximum number of results to return.

AcmeEndpointArn

[required] The Amazon Resource Name (ARN) of the ACME endpoint.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.