View source: R/acm_operations.R
| acm_list_certificate_domain_validations | R Documentation |
Returns per-domain validation summaries for an ACM certificate. Each summary includes the domain name, the active validation configuration, and the requested validation configuration when a validation method migration is in progress. You can use the results to monitor the progress of an email-to-DNS validation migration and to retrieve the CNAME records required for DNS validation.
See https://www.paws-r-sdk.com/docs/acm_list_certificate_domain_validations/ for full documentation.
acm_list_certificate_domain_validations(
CertificateArn,
NextToken = NULL,
MaxItems = NULL
)
CertificateArn |
[required] The Amazon Resource Name (ARN) of the certificate for which to list domain validation summaries. |
NextToken |
A token returned by a previous call to |
MaxItems |
The maximum number of domain validation summaries to return. If you don't specify a value, the default is 1000. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.