Retrieves a list of certificate ARNs and domain names. You can request that only certificates that match a specific status be listed. You can also filter by specific attributes of the certificate. Default filtering returns only RSA_2048 certificates. For more information, see Filters.
See https://www.paws-r-sdk.com/docs/acm_list_certificates/ for full documentation.
acm_list_certificates(
CertificateStatuses = NULL,
Includes = NULL,
NextToken = NULL,
MaxItems = NULL,
SortBy = NULL,
SortOrder = NULL
)Filter the certificate list by status value.
Filter the certificate list. For more information, see the Filters structure.
Use this parameter only when paginating results and only in a subsequent
request after you receive a response with truncated results. Set it to
the value of NextToken from the response you just received.
Use this parameter when paginating results to specify the maximum number
of items to return in the response. If additional items exist beyond the
number you specify, the NextToken element is sent in the response. Use
this NextToken value in a subsequent request to retrieve additional
items.
Specifies the field to sort results by. If you specify SortBy, you
must also specify SortOrder.
Specifies the order of sorted results. If you specify SortOrder, you
must also specify SortBy.