Remove one or more tags from an ACM certificate. A tag consists of a key-value pair. If you do not specify the value portion of the tag when calling this function, the tag will be removed regardless of value. If you specify a value, the tag is removed only if it is associated with the specified value.
acm_remove_tags_from_certificate(CertificateArn, Tags)[required] String that contains the ARN of the ACM Certificate with one or more tags that you want to remove. This must be of the form:
arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
[required] The key-value pair that defines the tag to remove.
svc$remove_tags_from_certificate(
CertificateArn = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)
To add tags to a certificate, use the AddTagsToCertificate action. To view all of the tags that have been applied to a specific ACM certificate, use the ListTagsForCertificate action.