acm_revoke_acme_account: Revokes an ACME account, preventing it from requesting or...

View source: R/acm_operations.R

acm_revoke_acme_accountR Documentation

Revokes an ACME account, preventing it from requesting or revoking certificates

Description

Revokes an ACME account, preventing it from requesting or revoking certificates. This operation is irreversible.

See https://www.paws-r-sdk.com/docs/acm_revoke_acme_account/ for full documentation.

Usage

acm_revoke_acme_account(AcmeEndpointArn, AccountUrl)

Arguments

AcmeEndpointArn

[required] The Amazon Resource Name (ARN) of the ACME endpoint.

AccountUrl

[required] The URL of the ACME account to revoke.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.