acm_revoke_acme_external_account_binding: Revokes an external account binding, preventing new ACME...

View source: R/acm_operations.R

acm_revoke_acme_external_account_bindingR Documentation

Revokes an external account binding, preventing new ACME accounts from being registered using this binding

Description

Revokes an external account binding, preventing new ACME accounts from being registered using this binding. Existing ACME accounts that were previously registered using the binding are not affected and must be revoked separately.

See https://www.paws-r-sdk.com/docs/acm_revoke_acme_external_account_binding/ for full documentation.

Usage

acm_revoke_acme_external_account_binding(AcmeExternalAccountBindingArn)

Arguments

AcmeExternalAccountBindingArn

[required] The Amazon Resource Name (ARN) of the ACME external account binding to revoke.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.