acm_revoke_certificate: Revokes a public ACM certificate

View source: R/acm_operations.R

acm_revoke_certificateR Documentation

Revokes a public ACM certificate

Description

Revokes a public ACM certificate. You can only revoke certificates that have been previously exported.

See https://www.paws-r-sdk.com/docs/acm_revoke_certificate/ for full documentation.

Usage

acm_revoke_certificate(CertificateArn, RevocationReason)

Arguments

CertificateArn

[required] The Amazon Resource Name (ARN) of the public or private certificate that will be revoked. The ARN must have the following form:

arn:aws:acm:region:account:certificate/12345678-1234-1234-1234-123456789012

RevocationReason

[required] Specifies why you revoked the certificate.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.