View source: R/acm_operations.R
| acm_search_certificates | R Documentation |
Retrieves a list of certificates matching search criteria. You can filter certificates by X.509 attributes and ACM specific properties like certificate status, type and renewal eligibility. This operation provides more flexible filtering than list_certificates by supporting complex filter statements.
See https://www.paws-r-sdk.com/docs/acm_search_certificates/ for full documentation.
acm_search_certificates(
FilterStatement = NULL,
MaxResults = NULL,
NextToken = NULL,
SortBy = NULL,
SortOrder = NULL
)
FilterStatement |
A filter statement that defines the search criteria. You can combine multiple filters using AND, OR, and NOT logical operators to create complex queries. |
MaxResults |
The maximum number of results to return in the response. Default is 100. |
NextToken |
Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of |
SortBy |
Specifies the field to sort results by. Valid values are CREATED_AT, NOT_AFTER, STATUS, RENEWAL_STATUS, EXPORTED, IN_USE, NOT_BEFORE, KEY_ALGORITHM, TYPE, CERTIFICATE_ARN, COMMON_NAME, REVOKED_AT, RENEWAL_ELIGIBILITY, ISSUED_AT, MANAGED_BY, EXPORT_OPTION, VALIDATION_METHOD, and IMPORTED_AT. |
SortOrder |
Specifies the order of sorted results. Valid values are ASCENDING or DESCENDING. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.