acm_tag_resource: Adds one or more tags to an ACM resource

View source: R/acm_operations.R

acm_tag_resourceR Documentation

Adds one or more tags to an ACM resource

Description

Adds one or more tags to an ACM resource. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a key and an optional value.

See https://www.paws-r-sdk.com/docs/acm_tag_resource/ for full documentation.

Usage

acm_tag_resource(ResourceArn, Tags)

Arguments

ResourceArn

[required] The ARN of the ACM resource to which the tag is to be applied.

Tags

[required] The key-value pair that defines the tag to apply.


paws.security.identity documentation built on Oct. 8, 2026, 9:12 a.m.