acm_update_certificate_options: Updates a certificate

View source: R/acm_operations.R

acm_update_certificate_optionsR Documentation

Updates a certificate

Description

Updates a certificate. You can use this function to specify whether to opt in to or out of recording your certificate in a certificate transparency log and exporting. For more information, see Opting Out of Certificate Transparency Logging and Certificate Manager Exportable Managed Certificates.

See https://www.paws-r-sdk.com/docs/acm_update_certificate_options/ for full documentation.

Usage

acm_update_certificate_options(CertificateArn, Options)

Arguments

CertificateArn

[required] ARN of the requested certificate to update. This must be of the form:

arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012

Options

[required] Use to update the options for your certificate. Currently, you can specify whether to add your certificate to a transparency log or export your certificate. Certificate transparency makes it possible to detect SSL/TLS certificates that have been mistakenly or maliciously issued. Certificates that have not been logged typically produce an error message in a browser.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.