View source: R/acmpca_operations.R
| acmpca_put_policy | R Documentation |
Attaches a resource-based policy to a private CA.
See https://www.paws-r-sdk.com/docs/acmpca_put_policy/ for full documentation.
acmpca_put_policy(ResourceArn, Policy)
ResourceArn |
[required] The Amazon Resource Number (ARN) of the private CA to associate with the policy. The ARN of the CA can be found by calling the |
Policy |
[required] The path and file name of a JSON-formatted IAM policy to attach to the specified private CA resource. If this policy does not contain all required statements or if it includes any statement that is not allowed, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.