cleanroomsml_cancel_trained_model: Submits a request to cancel the trained model job

View source: R/cleanroomsml_operations.R

cleanroomsml_cancel_trained_modelR Documentation

Submits a request to cancel the trained model job

Description

Submits a request to cancel the trained model job.

See https://www.paws-r-sdk.com/docs/cleanroomsml_cancel_trained_model/ for full documentation.

Usage

cleanroomsml_cancel_trained_model(
  membershipIdentifier,
  trainedModelArn,
  versionIdentifier = NULL
)

Arguments

membershipIdentifier

[required] The membership ID of the trained model job that you want to cancel.

trainedModelArn

[required] The Amazon Resource Name (ARN) of the trained model job that you want to cancel.

versionIdentifier

The version identifier of the trained model to cancel. This parameter allows you to specify which version of the trained model you want to cancel when multiple versions exist.

If versionIdentifier is not specified, the base model will be cancelled.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.