View source: R/cleanroomsml_operations.R
| cleanroomsml_create_trained_model | R Documentation |
Creates a trained model from an associated configured model algorithm using data from any member of the collaboration.
See https://www.paws-r-sdk.com/docs/cleanroomsml_create_trained_model/ for full documentation.
cleanroomsml_create_trained_model(
membershipIdentifier,
name,
configuredModelAlgorithmAssociationArn,
hyperparameters = NULL,
environment = NULL,
resourceConfig,
stoppingCondition = NULL,
incrementalTrainingDataChannels = NULL,
dataChannels,
trainingInputMode = NULL,
description = NULL,
kmsKeyArn = NULL,
tags = NULL,
mlModelTrainingPayerAccountId = NULL
)
membershipIdentifier |
[required] The membership ID of the member that is creating the trained model. |
name |
[required] The name of the trained model. |
configuredModelAlgorithmAssociationArn |
[required] The associated configured model algorithm used to train this model. |
hyperparameters |
Algorithm-specific parameters that influence the quality of the model. You set hyperparameters before you start the learning process. |
environment |
The environment variables to set in the Docker container. |
resourceConfig |
[required] Information about the EC2 resources that are used to train this model. |
stoppingCondition |
The criteria that is used to stop model training. |
incrementalTrainingDataChannels |
Specifies the incremental training data channels for the trained model. Incremental training allows you to create a new trained model with updates without retraining from scratch. You can specify up to one incremental training data channel that references a previously trained model and its version. Limit: Maximum of 20 channels total (including both |
dataChannels |
[required] Defines the data channels that are used as input for the trained model request. Limit: Maximum of 20 channels total (including both |
trainingInputMode |
The input mode for accessing the training data. This parameter determines how the training data is made available to the training algorithm. Valid values are:
|
description |
The description of the trained model. |
kmsKeyArn |
The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and decrypt customer-owned data in the trained ML model and the associated data. |
tags |
The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:
|
mlModelTrainingPayerAccountId |
The account ID of the member that is responsible for paying for model training costs. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.