cleanroomsml_delete_trained_model_output: Deletes the model artifacts stored by the service

View source: R/cleanroomsml_operations.R

cleanroomsml_delete_trained_model_outputR Documentation

Deletes the model artifacts stored by the service

Description

Deletes the model artifacts stored by the service.

See https://www.paws-r-sdk.com/docs/cleanroomsml_delete_trained_model_output/ for full documentation.

Usage

cleanroomsml_delete_trained_model_output(
  trainedModelArn,
  membershipIdentifier,
  versionIdentifier = NULL
)

Arguments

trainedModelArn

[required] The Amazon Resource Name (ARN) of the trained model whose output you want to delete.

membershipIdentifier

[required] The membership ID of the member that is deleting the trained model output.

versionIdentifier

The version identifier of the trained model to delete. If not specified, the operation will delete the base version of the trained model. When specified, only the particular version will be deleted.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.