cleanroomsml_get_collaboration_trained_model: Returns information about a trained model in a collaboration

View source: R/cleanroomsml_operations.R

cleanroomsml_get_collaboration_trained_modelR Documentation

Returns information about a trained model in a collaboration

Description

Returns information about a trained model in a collaboration.

See https://www.paws-r-sdk.com/docs/cleanroomsml_get_collaboration_trained_model/ for full documentation.

Usage

cleanroomsml_get_collaboration_trained_model(
  trainedModelArn,
  collaborationIdentifier,
  versionIdentifier = NULL
)

Arguments

trainedModelArn

[required] The Amazon Resource Name (ARN) of the trained model that you want to return information about.

collaborationIdentifier

[required] The collaboration ID that contains the trained model that you want to return information about.

versionIdentifier

The version identifier of the trained model to retrieve. If not specified, the operation returns information about the latest version of the trained model.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.