cleanroomsml_get_trained_model: Returns information about a trained model

View source: R/cleanroomsml_operations.R

cleanroomsml_get_trained_modelR Documentation

Returns information about a trained model

Description

Returns information about a trained model.

See https://www.paws-r-sdk.com/docs/cleanroomsml_get_trained_model/ for full documentation.

Usage

cleanroomsml_get_trained_model(
  trainedModelArn,
  membershipIdentifier,
  versionIdentifier = NULL
)

Arguments

trainedModelArn

[required] The Amazon Resource Name (ARN) of the trained model that you are interested in.

membershipIdentifier

[required] The membership ID of the member that created the trained model that you are interested in.

versionIdentifier

The version identifier of the trained model to retrieve. If not specified, the operation returns information about the latest version of the trained model.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.