cleanroomsml_list_trained_model_inference_jobs: Returns a list of trained model inference jobs that match the...

View source: R/cleanroomsml_operations.R

cleanroomsml_list_trained_model_inference_jobsR Documentation

Returns a list of trained model inference jobs that match the request parameters

Description

Returns a list of trained model inference jobs that match the request parameters.

See https://www.paws-r-sdk.com/docs/cleanroomsml_list_trained_model_inference_jobs/ for full documentation.

Usage

cleanroomsml_list_trained_model_inference_jobs(
  nextToken = NULL,
  maxResults = NULL,
  membershipIdentifier,
  trainedModelArn = NULL,
  trainedModelVersionIdentifier = NULL
)

Arguments

nextToken

The token value retrieved from a previous call to access the next page of results.

maxResults

The maximum size of the results that is returned per call.

membershipIdentifier

[required] The membership

trainedModelArn

The Amazon Resource Name (ARN) of a trained model that was used to create the trained model inference jobs that you are interested in.

trainedModelVersionIdentifier

The version identifier of the trained model to filter inference jobs by. When specified, only inference jobs that used this specific version of the trained model are returned.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.