View source: R/cleanroomsml_operations.R
| cleanroomsml_list_trained_model_versions | R Documentation |
Returns a list of trained model versions for a specified trained model. This operation allows you to view all versions of a trained model, including information about their status and creation details. You can use this to track the evolution of your trained models and select specific versions for inference or further training.
See https://www.paws-r-sdk.com/docs/cleanroomsml_list_trained_model_versions/ for full documentation.
cleanroomsml_list_trained_model_versions(
nextToken = NULL,
maxResults = NULL,
membershipIdentifier,
trainedModelArn,
status = NULL
)
nextToken |
The pagination token from a previous |
maxResults |
The maximum number of trained model versions to return in a single page. The default value is 10, and the maximum value is 100. |
membershipIdentifier |
[required] The membership identifier for the collaboration that contains the trained model. |
trainedModelArn |
[required] The Amazon Resource Name (ARN) of the trained model for which to list versions. |
status |
Filter the results to only include trained model versions with the specified status. Valid values include |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.