cleanroomsml_start_audience_export_job: Export an audience of a specified size after you have...

View source: R/cleanroomsml_operations.R

cleanroomsml_start_audience_export_jobR Documentation

Export an audience of a specified size after you have generated an audience

Description

Export an audience of a specified size after you have generated an audience.

See https://www.paws-r-sdk.com/docs/cleanroomsml_start_audience_export_job/ for full documentation.

Usage

cleanroomsml_start_audience_export_job(
  name,
  audienceGenerationJobArn,
  audienceSize,
  description = NULL
)

Arguments

name

[required] The name of the audience export job.

audienceGenerationJobArn

[required] The Amazon Resource Name (ARN) of the audience generation job that you want to export.

audienceSize

[required] The size of the generated audience. Must match one of the sizes in the configured audience model.

description

The description of the audience export job.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.