cleanroomsml_start_trained_model_export_job: Provides the information necessary to start a trained model...

View source: R/cleanroomsml_operations.R

cleanroomsml_start_trained_model_export_jobR Documentation

Provides the information necessary to start a trained model export job

Description

Provides the information necessary to start a trained model export job.

See https://www.paws-r-sdk.com/docs/cleanroomsml_start_trained_model_export_job/ for full documentation.

Usage

cleanroomsml_start_trained_model_export_job(
  name,
  trainedModelArn,
  trainedModelVersionIdentifier = NULL,
  membershipIdentifier,
  outputConfiguration,
  description = NULL
)

Arguments

name

[required] The name of the trained model export job.

trainedModelArn

[required] The Amazon Resource Name (ARN) of the trained model that you want to export.

trainedModelVersionIdentifier

The version identifier of the trained model to export. This specifies which version of the trained model should be exported to the specified destination.

membershipIdentifier

[required] The membership ID of the member that is receiving the exported trained model artifacts.

outputConfiguration

[required] The output configuration information for the trained model export job.

description

The description of the trained model export job.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.