clouddirectory_get_typed_link_facet_information: Returns the identity attribute order for a specific TypedLinkFacet
Description
Returns the identity attribute order for a specific TypedLinkFacet. For
more information, see Typed Links.
Usage
clouddirectory_get_typed_link_facet_information(SchemaArn, Name)
Arguments
SchemaArn
[required] The Amazon Resource Name (ARN) that is associated with the schema. For
more information, see arns.
Name
[required] The unique name of the typed link facet.
Request syntax
svc$get_typed_link_facet_information(
SchemaArn = "string",
Name = "string"
)