cloudhsmv2_tag_resource: Adds or overwrites one or more tags for the specified...

View source: R/cloudhsmv2_operations.R

cloudhsmv2_tag_resourceR Documentation

Adds or overwrites one or more tags for the specified CloudHSM cluster

Description

Adds or overwrites one or more tags for the specified CloudHSM cluster.

See https://www.paws-r-sdk.com/docs/cloudhsmv2_tag_resource/ for full documentation.

Usage

cloudhsmv2_tag_resource(ResourceId, TagList)

Arguments

ResourceId

[required] The cluster identifier (ID) for the cluster that you are tagging. To find the cluster ID, use describe_clusters.

TagList

[required] A list of one or more tags.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.