Learn R Programming

paws.security.identity (version 0.1.12)

cognitoidentity_describe_identity: Returns metadata related to the given identity, including when the identity was created and any associated linked logins

Description

Returns metadata related to the given identity, including when the identity was created and any associated linked logins.

You must use AWS Developer credentials to call this API.

Usage

cognitoidentity_describe_identity(IdentityId)

Value

A list with the following syntax:

list(
  IdentityId = "string",
  Logins = list(
    "string"
  ),
  CreationDate = as.POSIXct(
    "2015-01-01"
  ),
  LastModifiedDate = as.POSIXct(
    "2015-01-01"
  )
)

Arguments

IdentityId

[required] A unique identifier in the format REGION:GUID.

Request syntax

svc$describe_identity(
  IdentityId = "string"
)