Learn R Programming

paws.security.identity (version 0.1.12)

cognitoidentity_list_identity_pools: Lists all of the Cognito identity pools registered for your account

Description

Lists all of the Cognito identity pools registered for your account.

You must use AWS Developer credentials to call this API.

Usage

cognitoidentity_list_identity_pools(MaxResults, NextToken)

Value

A list with the following syntax:

list(
  IdentityPools = list(
    list(
      IdentityPoolId = "string",
      IdentityPoolName = "string"
    )
  ),
  NextToken = "string"
)

Arguments

MaxResults

[required] The maximum number of identities to return.

NextToken

A pagination token.

Request syntax

svc$list_identity_pools(
  MaxResults = 123,
  NextToken = "string"
)