cognitoidentityprovider_add_user_pool_client_secret: Creates a new client secret for an existing confidential user...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_add_user_pool_client_secretR Documentation

Creates a new client secret for an existing confidential user pool app client

Description

Creates a new client secret for an existing confidential user pool app client. Supports up to 2 active secrets per app client for zero-downtime credential rotation workflows.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_add_user_pool_client_secret/ for full documentation.

Usage

cognitoidentityprovider_add_user_pool_client_secret(
  UserPoolId,
  ClientId,
  ClientSecret = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool that contains the app client.

ClientId

[required] The ID of the app client for which you want to create a new secret.

ClientSecret

The client secret value you want to use. If you don't provide this parameter, Amazon Cognito generates a secure secret for you.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.