View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_add_user_to_group | R Documentation |
Adds a user to a group. A user who is in a group can present a preferred-role claim to an identity pool, and populates a cognito:groups claim to their access and identity tokens.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_add_user_to_group/ for full documentation.
cognitoidentityprovider_admin_add_user_to_group(
UserPoolId,
Username,
GroupName
)
UserPoolId |
[required] The ID of the user pool that contains the group that you want to add the user to. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
GroupName |
[required] The name of the group that you want to add your user to. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.