View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_confirm_sign_up | R Documentation |
Confirms user sign-up as an administrator.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_confirm_sign_up/ for full documentation.
cognitoidentityprovider_admin_confirm_sign_up(
UserPoolId,
Username,
ClientMetadata = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to confirm a user's sign-up request. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.