View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_create_user | R Documentation |
Creates a new user in the specified user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_create_user/ for full documentation.
cognitoidentityprovider_admin_create_user(
UserPoolId,
Username,
UserAttributes = NULL,
ValidationData = NULL,
TemporaryPassword = NULL,
ForceAliasCreation = NULL,
MessageAction = NULL,
DesiredDeliveryMediums = NULL,
ClientMetadata = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to create a user. |
Username |
[required] The value that you want to set as the username sign-in attribute. The following conditions apply to the username parameter.
|
UserAttributes |
An array of name-value pairs that contain user attributes and attribute values to be set for the user to be created. You can create a user without specifying any attributes other than For custom attributes, you must prepend the To send a message inviting the user to sign up, you must specify the user's email address or phone number. You can do this in your call to AdminCreateUser or in the Users tab of the Amazon Cognito console for managing your user pools. You must also provide an email address or phone number when you expect the user to do passwordless sign-in with an email or SMS OTP. These attributes must be provided when passwordless options are the only available, or when you don't submit a In your The email address where you want the user to receive their confirmation code and username. You must provide a value for phone_number The phone number where you want the user to receive their confirmation code and username. You must provide a value for |
ValidationData |
Temporary user attributes that contribute to the outcomes of your pre sign-up Lambda trigger. This set of key-value pairs are for custom validation of information that you collect from your users but don't need to retain. Your Lambda function can analyze this additional data and act on it. Your function can automatically confirm and verify select users or perform external API operations like logging user attributes and validation data to Amazon CloudWatch Logs. For more information about the pre sign-up Lambda trigger, see Pre sign-up Lambda trigger. |
TemporaryPassword |
The user's temporary password. This password must conform to the password policy that you specified when you created the user pool. The exception to the requirement for a password is when your user pool supports passwordless sign-in with email or SMS OTPs. To create a user with no password, omit this parameter or submit a blank value. You can only create a passwordless user when passwordless sign-in is available. The temporary password is valid only once. To complete the Admin Create User flow, the user must enter the temporary password in the sign-in page, along with a new password to be used in all future sign-ins. If you don't specify a value, Amazon Cognito generates one for you unless you have passwordless options active for your user pool. The temporary password can only be used until the user account expiration limit that you set for your user pool. To reset the account after that time limit, you must call |
ForceAliasCreation |
This parameter is used only if the If this parameter is set to If this parameter is set to |
MessageAction |
Set to |
DesiredDeliveryMediums |
Specify |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.