View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_forget_device | R Documentation |
Forgets, or deletes, a remembered device from a user's profile. After you forget the device, the user can no longer complete device authentication with that device and when applicable, must submit MFA codes again. For more information, see Working with devices.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_forget_device/ for full documentation.
cognitoidentityprovider_admin_forget_device(UserPoolId, Username, DeviceKey)
UserPoolId |
[required] The ID of the user pool where the device owner is a user. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
DeviceKey |
[required] The key ID of the device that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.