View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_get_device | R Documentation |
Given the device key, returns details for a user's device. For more information, see Working with devices.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_get_device/ for full documentation.
cognitoidentityprovider_admin_get_device(DeviceKey, UserPoolId, Username)
DeviceKey |
[required] The key of the device that you want to delete. |
UserPoolId |
[required] The ID of the user pool where the device owner is a user. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.