cognitoidentityprovider_admin_get_user: Given a username, returns details about a user profile in a...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_admin_get_userR Documentation

Given a username, returns details about a user profile in a user pool

Description

Given a username, returns details about a user profile in a user pool. You can specify alias attributes in the Username request parameter.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_get_user/ for full documentation.

Usage

cognitoidentityprovider_admin_get_user(UserPoolId, Username)

Arguments

UserPoolId

[required] The ID of the user pool where you want to get information about the user.

Username

[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.