View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_reset_user_password | R Documentation |
Begins the password reset process. Sets the requested user’s account into a RESET_REQUIRED status, and sends them a password-reset code. Your user pool also sends the user a notification with a reset code and the information that their password has been reset. At sign-in, your application or the managed login session receives a challenge to complete the reset by confirming the code and setting a new password.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_reset_user_password/ for full documentation.
cognitoidentityprovider_admin_reset_user_password(
UserPoolId,
Username,
ClientMetadata = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to reset the user's password. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.