View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_respond_to_auth_challenge | R Documentation |
Some API operations in a user pool generate a challenge, like a prompt for an MFA code, for device authentication that bypasses MFA, or for a custom authentication challenge. An admin_respond_to_auth_challenge API request provides the answer to that challenge, like a code or a secure remote password (SRP). The parameters of a response to an authentication challenge vary with the type of challenge.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_respond_to_auth_challenge/ for full documentation.
cognitoidentityprovider_admin_respond_to_auth_challenge(
UserPoolId,
ClientId,
ChallengeName,
ChallengeResponses = NULL,
Session = NULL,
AnalyticsMetadata = NULL,
ContextData = NULL,
ClientMetadata = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to respond to an authentication challenge. |
ClientId |
[required] The ID of the app client where you initiated sign-in. |
ChallengeName |
[required] The name of the challenge that you are responding to. Possible challenges include the following: All of the following challenges require
|
ChallengeResponses |
The responses to the challenge that you received in the previous request. Each challenge has its own required response parameters. The following examples are partial JSON request bodies that highlight challenge-response parameters. You must provide a SECRET_HASH parameter in all challenge responses to an app client that has a client secret. Include a SELECT_CHALLENGE
Available challenges are Complete authentication in the
For
WEB_AUTHN
See AuthenticationResponseJSON. PASSWORD
PASSWORD_SRP
SMS_OTP
EMAIL_OTP
SMS_MFA
PASSWORD_VERIFIER This challenge response is part of the SRP flow. Amazon Cognito requires that your application respond to this challenge within a few seconds. When the response time exceeds this period, your user pool returns a
CUSTOM_CHALLENGE
NEW_PASSWORD_REQUIRED
To set any required attributes that In a SOFTWARE_TOKEN_MFA
DEVICE_SRP_AUTH
DEVICE_PASSWORD_VERIFIER
MFA_SETUP
SELECT_MFA_TYPE
For more information about |
Session |
The session identifier that maintains the state of authentication requests and challenge responses. If an |
AnalyticsMetadata |
Information that supports analytics outcomes with Amazon Pinpoint, including the user's endpoint ID. The endpoint ID is a destination for Amazon Pinpoint push notifications, for example a device identifier, email address, or phone number. |
ContextData |
Contextual data about your user session like the device fingerprint, IP address, or location. Amazon Cognito threat protection evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests. For more information, see Collecting data for threat protection in applications. |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.