View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_set_user_mfa_preference | R Documentation |
Sets the user's multi-factor authentication (MFA) preference, including which MFA options are activated, and if any are preferred. Only one factor can be set as preferred. The preferred MFA factor will be used to authenticate a user if multiple factors are activated. If multiple options are activated and no preference is set, a challenge to choose an MFA option will be returned during sign-in.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_set_user_mfa_preference/ for full documentation.
cognitoidentityprovider_admin_set_user_mfa_preference(
SMSMfaSettings = NULL,
SoftwareTokenMfaSettings = NULL,
EmailMfaSettings = NULL,
WebAuthnMfaSettings = NULL,
Username,
UserPoolId
)
SMSMfaSettings |
User preferences for SMS message MFA. Activates or deactivates SMS MFA and sets it as the preferred MFA method when multiple methods are available. |
SoftwareTokenMfaSettings |
User preferences for time-based one-time password (TOTP) MFA. Activates or deactivates TOTP MFA and sets it as the preferred MFA method when multiple methods are available. |
EmailMfaSettings |
User preferences for email message MFA. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the Essentials tier or higher. |
WebAuthnMfaSettings |
User preferences for passkey MFA. Activates or deactivates passkey MFA for the user. When activated, passkey authentication requires user verification, and passkey sign-in is available when MFA is required. To activate this setting, the |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
UserPoolId |
[required] The ID of the user pool where you want to set a user's MFA preferences. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.