View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_set_user_settings | R Documentation |
This action is no longer supported. You can use it to configure only SMS MFA. You can't use it to configure time-based one-time password (TOTP) software token MFA.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_set_user_settings/ for full documentation.
cognitoidentityprovider_admin_set_user_settings(
UserPoolId,
Username,
MFAOptions
)
UserPoolId |
[required] The ID of the user pool that contains the user whose options you're setting. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
MFAOptions |
[required] You can use this parameter only to set an SMS configuration that uses SMS for delivery. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.