View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_update_user_attributes | R Documentation |
Updates the specified user's attributes. To delete an attribute from your user, submit the attribute in your API request with a blank value.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_update_user_attributes/ for full documentation.
cognitoidentityprovider_admin_update_user_attributes(
UserPoolId,
Username,
UserAttributes,
ClientMetadata = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to update user attributes. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
UserAttributes |
[required] An array of name-value pairs representing user attributes. For custom attributes, you must prepend the If your user pool requires verification before Amazon Cognito updates an attribute value that you specify in this request, Amazon Cognito doesn’t immediately update the value of that attribute. After your user receives and responds to a verification message to verify the new value, Amazon Cognito updates the attribute value. Your user can sign in and receive messages with the original attribute value until they verify the new value. To skip the verification message and update the value of an attribute that requires verification in the same API request, include the |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.