cognitoidentityprovider_complete_web_authn_registration: Completes registration of a passkey authenticator for the...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_complete_web_authn_registrationR Documentation

Completes registration of a passkey authenticator for the currently signed-in user

Description

Completes registration of a passkey authenticator for the currently signed-in user.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_complete_web_authn_registration/ for full documentation.

Usage

cognitoidentityprovider_complete_web_authn_registration(
  AccessToken,
  Credential
)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

Credential

[required] A RegistrationResponseJSON public-key credential response from the user's passkey provider.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.