View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_confirm_forgot_password | R Documentation |
This public API operation accepts a confirmation code that Amazon Cognito sent to a user and accepts a new password for that user.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_confirm_forgot_password/ for full documentation.
cognitoidentityprovider_confirm_forgot_password(
ClientId,
SecretHash = NULL,
Username,
ConfirmationCode,
Password,
AnalyticsMetadata = NULL,
UserContextData = NULL,
ClientMetadata = NULL
)
ClientId |
[required] The ID of the app client where the user wants to reset their password. This parameter is an identifier of the client application that users are resetting their password from, but this operation resets users' irrespective of the app clients they sign in to. |
SecretHash |
A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message. For more information about |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
ConfirmationCode |
[required] The confirmation code that your user pool delivered when your user requested to reset their password. |
Password |
[required] The new password that your user wants to set. |
AnalyticsMetadata |
Information that supports analytics outcomes with Amazon Pinpoint, including the user's endpoint ID. The endpoint ID is a destination for Amazon Pinpoint push notifications, for example a device identifier, email address, or phone number. |
UserContextData |
Contextual data about your user session like the device fingerprint, IP address, or location. Amazon Cognito threat protection evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests. For more information, see Collecting data for threat protection in applications. |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.