View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_create_managed_login_branding | R Documentation |
Creates a new set of branding settings for a user pool style and associates it with an app client. This operation is the programmatic option for the creation of a new style in the branding editor.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_create_managed_login_branding/ for full documentation.
cognitoidentityprovider_create_managed_login_branding(
UserPoolId,
ClientId,
UseCognitoProvidedValues = NULL,
Settings = NULL,
Assets = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to create a new branding style. |
ClientId |
[required] The app client that you want to create the branding style for. Each style is linked to an app client until you delete it. |
UseCognitoProvidedValues |
When true, applies the default branding style options. These default options are managed by Amazon Cognito. You can modify them later in the branding editor. When you specify |
Settings |
A JSON file, encoded as a The following components are not currently implemented and reserved for future use:
[Managed login localization)]: R:Managed%20login%20localization) |
Assets |
An array of image files that you want to apply to functions like backgrounds, logos, and icons. Each object must also indicate whether it is for dark mode, light mode, or browser-adaptive mode. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.