cognitoidentityprovider_create_terms: Creates terms documents for the requested app client

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_create_termsR Documentation

Creates terms documents for the requested app client

Description

Creates terms documents for the requested app client. When Terms and conditions and Privacy policy documents are configured, the app client displays links to them in the sign-up page of managed login for the app client.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_create_terms/ for full documentation.

Usage

cognitoidentityprovider_create_terms(
  UserPoolId,
  ClientId,
  TermsName,
  TermsSource,
  Enforcement,
  Links = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to create terms documents.

ClientId

[required] The ID of the app client where you want to create terms documents. Must be an app client in the requested user pool.

TermsName

[required] A friendly name for the document that you want to create in the current request. Must begin with terms-of-use or privacy-policy as identification of the document type. Provide URLs for both terms-of-use and privacy-policy in separate requests.

TermsSource

[required] This parameter is reserved for future use and currently accepts only one value.

Enforcement

[required] This parameter is reserved for future use and currently accepts only one value.

Links

A map of URLs to languages. For each localized language that will view the requested TermsName, assign a URL. A selection of cognito:default displays for all languages that don't have a language-specific URL.

For example, ⁠"cognito:default": "https://terms.example.com", "cognito:spanish": "https://terms.example.com/es"⁠.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.