View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_create_user_pool | R Documentation |
Creates a new Amazon Cognito user pool. This operation sets basic and advanced configuration options.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_create_user_pool/ for full documentation.
cognitoidentityprovider_create_user_pool(
PoolName,
Policies = NULL,
DeletionProtection = NULL,
LambdaConfig = NULL,
AutoVerifiedAttributes = NULL,
AliasAttributes = NULL,
UsernameAttributes = NULL,
SmsVerificationMessage = NULL,
EmailVerificationMessage = NULL,
EmailVerificationSubject = NULL,
VerificationMessageTemplate = NULL,
SmsAuthenticationMessage = NULL,
MfaConfiguration = NULL,
UserAttributeUpdateSettings = NULL,
DeviceConfiguration = NULL,
EmailConfiguration = NULL,
SmsConfiguration = NULL,
UserPoolTags = NULL,
AdminCreateUserConfig = NULL,
Schema = NULL,
UserPoolAddOns = NULL,
UsernameConfiguration = NULL,
AccountRecoverySetting = NULL,
UserPoolTier = NULL
)
PoolName |
[required] A friendly name for your user pool. |
Policies |
The password policy and sign-in policy in the user pool. The password policy sets options like password complexity requirements and password history. The sign-in policy sets the options available to applications in choice-based authentication. |
DeletionProtection |
When active, When you try to delete a protected user pool in a |
LambdaConfig |
A collection of user pool Lambda triggers. Amazon Cognito invokes triggers at several possible stages of authentication operations. Triggers can modify the outcome of the operations that invoked them. |
AutoVerifiedAttributes |
The attributes that you want your user pool to automatically verify. For more information, see Verifying contact information at sign-up. |
AliasAttributes |
Attributes supported as an alias for this user pool. For more information about alias attributes, see Customizing sign-in attributes. |
UsernameAttributes |
Specifies whether a user can use an email address or phone number as a username when they sign up. For more information, see Customizing sign-in attributes. |
SmsVerificationMessage |
This parameter is no longer used. |
EmailVerificationMessage |
This parameter is no longer used. |
EmailVerificationSubject |
This parameter is no longer used. |
VerificationMessageTemplate |
The template for the verification message that your user pool delivers to users who set an email address or phone number attribute. Set the email message type that corresponds to your |
SmsAuthenticationMessage |
The contents of the SMS message that your user pool sends to users in SMS OTP and MFA authentication. |
MfaConfiguration |
Sets multi-factor authentication (MFA) to be on, off, or optional. When When |
UserAttributeUpdateSettings |
The settings for updates to user attributes. These settings include the property |
DeviceConfiguration |
The device-remembering configuration for a user pool. Device remembering or device tracking is a "Remember me on this device" option for user pools that perform authentication with the device key of a trusted device in the back end, instead of a user-provided MFA code. For more information about device authentication, see Working with user devices in your user pool. A null value indicates that you have deactivated device remembering in your user pool. When you provide a value for any |
EmailConfiguration |
The email configuration of your user pool. The email configuration type sets your preferred sending method, Amazon Web Services Region, and sender for messages from your user pool. |
SmsConfiguration |
The settings for your Amazon Cognito user pool to send SMS messages with Amazon Simple Notification Service. To send SMS messages with Amazon SNS in the Amazon Web Services Region that you want, the Amazon Cognito user pool uses an Identity and Access Management (IAM) role in your Amazon Web Services account. For more information see SMS message settings. |
UserPoolTags |
The tag keys and values to assign to the user pool. A tag is a label that you can use to categorize and manage user pools in different ways, such as by purpose, owner, environment, or other criteria. |
AdminCreateUserConfig |
The configuration for administrative creation of users. Includes the template for the invitation message for new users, the duration of temporary passwords, and permitting self-service sign-up. |
Schema |
An array of attributes for the new user pool. You can add custom attributes and modify the properties of default attributes. The specifications in this parameter set the required attributes in your user pool. For more information, see Working with user attributes. |
UserPoolAddOns |
Contains settings for activation of threat protection, including the operating mode and additional authentication types. To log user security information but take no action, set to For more information, see Adding advanced security to a user pool. To activate this setting, your user pool must be on the Plus tier. |
UsernameConfiguration |
Sets the case sensitivity option for sign-in usernames. When When This configuration is immutable after you set it. |
AccountRecoverySetting |
The available verified method a user can use to recover their password when they call As a best practice, configure both |
UserPoolTier |
The user pool feature plan, or tier. This parameter determines the eligibility of the user pool for features like managed login, access-token customization, and threat protection. Defaults to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.