cognitoidentityprovider_delete_terms: Deletes the terms documents with the requested ID from your...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_delete_termsR Documentation

Deletes the terms documents with the requested ID from your app client

Description

Deletes the terms documents with the requested ID from your app client.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_terms/ for full documentation.

Usage

cognitoidentityprovider_delete_terms(TermsId, UserPoolId)

Arguments

TermsId

[required] The ID of the terms documents that you want to delete.

UserPoolId

[required] The ID of the user pool that contains the terms documents that you want to delete.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.