cognitoidentityprovider_delete_user: Deletes the profile of the currently signed-in user

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_delete_userR Documentation

Deletes the profile of the currently signed-in user

Description

Deletes the profile of the currently signed-in user. A deleted user profile can no longer be used to sign in and can't be restored.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_user/ for full documentation.

Usage

cognitoidentityprovider_delete_user(AccessToken)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.