cognitoidentityprovider_delete_user_attributes: Deletes attributes from the currently signed-in user

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_delete_user_attributesR Documentation

Deletes attributes from the currently signed-in user

Description

Deletes attributes from the currently signed-in user. For example, your application can submit a request to this operation when a user wants to remove their birthdate attribute value.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_user_attributes/ for full documentation.

Usage

cognitoidentityprovider_delete_user_attributes(UserAttributeNames, AccessToken)

Arguments

UserAttributeNames

[required] An array of strings representing the user attribute names you want to delete.

For custom attributes, you must prepend the ⁠custom:⁠ prefix to the attribute name, for example custom:department.

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.