cognitoidentityprovider_delete_web_authn_credential: Deletes a registered passkey, or WebAuthn, authenticator for...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_delete_web_authn_credentialR Documentation

Deletes a registered passkey, or WebAuthn, authenticator for the currently signed-in user

Description

Deletes a registered passkey, or WebAuthn, authenticator for the currently signed-in user.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_web_authn_credential/ for full documentation.

Usage

cognitoidentityprovider_delete_web_authn_credential(AccessToken, CredentialId)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

CredentialId

[required] The unique identifier of the passkey that you want to delete.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.