cognitoidentityprovider_describe_terms: Returns details for the requested terms documents ID

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_describe_termsR Documentation

Returns details for the requested terms documents ID

Description

Returns details for the requested terms documents ID. For more information, see Terms documents.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_describe_terms/ for full documentation.

Usage

cognitoidentityprovider_describe_terms(TermsId, UserPoolId)

Arguments

TermsId

[required] The ID of the terms documents that you want to describe.

UserPoolId

[required] The ID of the user pool that contains the terms documents that you want to describe.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.