cognitoidentityprovider_forget_device: Given a device key, deletes a remembered device as the...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_forget_deviceR Documentation

Given a device key, deletes a remembered device as the currently signed-in user

Description

Given a device key, deletes a remembered device as the currently signed-in user. For more information about device authentication, see Working with user devices in your user pool.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_forget_device/ for full documentation.

Usage

cognitoidentityprovider_forget_device(AccessToken = NULL, DeviceKey)

Arguments

AccessToken

A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

DeviceKey

[required] The unique identifier, or device key, of the device that the user wants to forget.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.