cognitoidentityprovider_get_csv_header: Given a user pool ID, generates a comma-separated value (CSV)...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_get_csv_headerR Documentation

Given a user pool ID, generates a comma-separated value (CSV) list populated with available user attributes in the user pool

Description

Given a user pool ID, generates a comma-separated value (CSV) list populated with available user attributes in the user pool. This list is the header for the CSV file that determines the users in a user import job. Save the content of CSVHeader in the response as a .csv file and populate it with the usernames and attributes of users that you want to import. For more information about CSV user import, see Importing users from a CSV file.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_csv_header/ for full documentation.

Usage

cognitoidentityprovider_get_csv_header(UserPoolId)

Arguments

UserPoolId

[required] The ID of the user pool that you want to import users into.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.