cognitoidentityprovider_get_group: Given a user pool ID and a group name, returns information...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_get_groupR Documentation

Given a user pool ID and a group name, returns information about the user group

Description

Given a user pool ID and a group name, returns information about the user group.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_group/ for full documentation.

Usage

cognitoidentityprovider_get_group(GroupName, UserPoolId)

Arguments

GroupName

[required] The name of the group that you want to get information about.

UserPoolId

[required] The ID of the user pool that contains the group that you want to query.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.