View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_identity_provider_by_identifier | R Documentation |
Given the identifier of an identity provider (IdP), for example examplecorp, returns information about the user pool configuration for that IdP. For more information about IdPs, see Third-party IdP sign-in.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_identity_provider_by_identifier/ for full documentation.
cognitoidentityprovider_get_identity_provider_by_identifier(
UserPoolId,
IdpIdentifier
)
UserPoolId |
[required] The ID of the user pool where you want to get information about the IdP. |
IdpIdentifier |
[required] The identifier that you assigned to your user pool. The identifier is an alternative name for an IdP that is distinct from the IdP name. For example, an IdP with a name of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.