cognitoidentityprovider_get_log_delivery_configuration: Given a user pool ID, returns the logging configuration

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_get_log_delivery_configurationR Documentation

Given a user pool ID, returns the logging configuration

Description

Given a user pool ID, returns the logging configuration. User pools can export message-delivery error and threat-protection activity logs to external Amazon Web Services services. For more information, see Exporting user pool logs.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_log_delivery_configuration/ for full documentation.

Usage

cognitoidentityprovider_get_log_delivery_configuration(UserPoolId)

Arguments

UserPoolId

[required] The ID of the user pool that has the logging configuration that you want to view.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.