View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_tokens_from_refresh_token | R Documentation |
Given a refresh token, issues new ID, access, and optionally refresh tokens for the user who owns the submitted token. This operation issues a new refresh token and invalidates the original refresh token after an optional grace period when refresh token rotation is enabled. If refresh token rotation is disabled, issues new ID and access tokens only.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_tokens_from_refresh_token/ for full documentation.
cognitoidentityprovider_get_tokens_from_refresh_token(
RefreshToken,
ClientId,
ClientSecret = NULL,
DeviceKey = NULL,
ClientMetadata = NULL
)
RefreshToken |
[required] A valid refresh token that can authorize the request for new tokens. When refresh token rotation is active in the requested app client, this token is invalidated after the request is complete and after an optional grace period. |
ClientId |
[required] The app client that issued the refresh token to the user who wants to request new tokens. |
ClientSecret |
The client secret of the requested app client, if the client has a secret. |
DeviceKey |
When you enable device remembering, Amazon Cognito issues a device key that you can use for device authentication that bypasses multi-factor authentication (MFA). To implement For more information about device remembering, see Working with devices. |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.