cognitoidentityprovider_get_user_attribute_verification_code: Given an attribute name, sends a user attribute verification...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_get_user_attribute_verification_codeR Documentation

Given an attribute name, sends a user attribute verification code for the specified attribute name to the currently signed-in user

Description

Given an attribute name, sends a user attribute verification code for the specified attribute name to the currently signed-in user.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_user_attribute_verification_code/ for full documentation.

Usage

cognitoidentityprovider_get_user_attribute_verification_code(
  AccessToken,
  AttributeName,
  ClientMetadata = NULL
)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

AttributeName

[required] The name of the attribute that the user wants to verify, for example email.

ClientMetadata

A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers.

When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a clientMetadata attribute that provides the data that you assigned to the ClientMetadata parameter in your request. In your function code, you can process the clientMetadata value to enhance your workflow for your specific needs.

To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide.

When you use the ClientMetadata parameter, note that Amazon Cognito won't do the following:

  • Store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration doesn't include triggers, the ClientMetadata parameter serves no purpose.

  • Validate the ClientMetadata value.

  • Encrypt the ClientMetadata value. Don't send sensitive information in this parameter.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.