View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_initiate_auth | R Documentation |
Declares an authentication flow and initiates sign-in for a user in the Amazon Cognito user directory. Amazon Cognito might respond with an additional challenge or an AuthenticationResult that contains the outcome of a successful authentication. You can't sign in a user with a federated IdP with initiate_auth. For more information, see Authentication.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_initiate_auth/ for full documentation.
cognitoidentityprovider_initiate_auth(
AuthFlow,
AuthParameters = NULL,
ClientMetadata = NULL,
ClientId,
AnalyticsMetadata = NULL,
UserContextData = NULL,
Session = NULL
)
AuthFlow |
[required] The authentication flow that you want to initiate. Each USER_AUTH The entry point for choice-based authentication with passwords, one-time passwords, and WebAuthn authenticators. Request a preferred authentication type or review available authentication types. From the offered authentication types, select one in a challenge response and then authenticate with that method in an additional challenge response. To activate this setting, your user pool must be in the Essentials tier or higher. USER_SRP_AUTH Username-password authentication with the Secure Remote Password (SRP) protocol. For more information, see Use SRP password verification in custom authentication flow. REFRESH_TOKEN_AUTH and REFRESH_TOKEN Receive new ID and access tokens when you pass a CUSTOM_AUTH Custom authentication with Lambda triggers. For more information, see Custom authentication challenge Lambda triggers. USER_PASSWORD_AUTH Client-side username-password authentication with the password sent directly in the request. For more information about client-side and server-side authentication, see SDK authorization models.
|
AuthParameters |
The authentication parameters. These are inputs corresponding to the The following are some authentication flows and their parameters. Add a USER_AUTH
USER_SRP_AUTH
USER_PASSWORD_AUTH
REFRESH_TOKEN_AUTH/REFRESH_TOKEN
CUSTOM_AUTH
For more information about |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. The
This request also invokes the functions for the following triggers, but doesn't pass
When you use the
|
ClientId |
[required] The ID of the app client that your user wants to sign in to. |
AnalyticsMetadata |
Information that supports analytics outcomes with Amazon Pinpoint, including the user's endpoint ID. The endpoint ID is a destination for Amazon Pinpoint push notifications, for example a device identifier, email address, or phone number. |
UserContextData |
Contextual data about your user session like the device fingerprint, IP address, or location. Amazon Cognito threat protection evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests. For more information, see Collecting data for threat protection in applications. |
Session |
The optional session ID from a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.