cognitoidentityprovider_list_devices: Lists the devices that Amazon Cognito has registered to the...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_devicesR Documentation

Lists the devices that Amazon Cognito has registered to the currently signed-in user

Description

Lists the devices that Amazon Cognito has registered to the currently signed-in user. For more information about device authentication, see Working with user devices in your user pool.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_devices/ for full documentation.

Usage

cognitoidentityprovider_list_devices(
  AccessToken,
  Limit = NULL,
  PaginationToken = NULL
)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

Limit

The maximum number of devices that you want Amazon Cognito to return in the response.

PaginationToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.