cognitoidentityprovider_list_groups: Given a user pool ID, returns user pool groups and their...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_groupsR Documentation

Given a user pool ID, returns user pool groups and their details

Description

Given a user pool ID, returns user pool groups and their details.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_groups/ for full documentation.

Usage

cognitoidentityprovider_list_groups(UserPoolId, Limit = NULL, NextToken = NULL)

Arguments

UserPoolId

[required] The ID of the user pool where you want to list user groups.

Limit

The maximum number of groups that you want Amazon Cognito to return in the response.

NextToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.