cognitoidentityprovider_list_identity_providers: Given a user pool ID, returns information about configured...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_identity_providersR Documentation

Given a user pool ID, returns information about configured identity providers (IdPs)

Description

Given a user pool ID, returns information about configured identity providers (IdPs). For more information about IdPs, see Third-party IdP sign-in.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_identity_providers/ for full documentation.

Usage

cognitoidentityprovider_list_identity_providers(
  UserPoolId,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to list IdPs.

MaxResults

The maximum number of IdPs that you want Amazon Cognito to return in the response.

NextToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.