View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_list_resource_servers | R Documentation |
Given a user pool ID, returns all resource servers and their details. For more information about resource servers, see Access control with resource servers.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_resource_servers/ for full documentation.
cognitoidentityprovider_list_resource_servers(
UserPoolId,
MaxResults = NULL,
NextToken = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to list resource servers. |
MaxResults |
The maximum number of resource servers that you want Amazon Cognito to return in the response. |
NextToken |
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.