cognitoidentityprovider_list_user_import_jobs: Given a user pool ID, returns user import jobs and their...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_user_import_jobsR Documentation

Given a user pool ID, returns user import jobs and their details

Description

Given a user pool ID, returns user import jobs and their details. Import jobs are retained in user pool configuration so that you can stage, stop, start, review, and delete them. For more information about user import, see Importing users from a CSV file.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_user_import_jobs/ for full documentation.

Usage

cognitoidentityprovider_list_user_import_jobs(
  UserPoolId,
  MaxResults,
  PaginationToken = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to list import jobs.

MaxResults

[required] The maximum number of import jobs that you want Amazon Cognito to return in the response.

PaginationToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.