cognitoidentityprovider_list_user_pools: Lists user pools and their details in the current Amazon Web...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_user_poolsR Documentation

Lists user pools and their details in the current Amazon Web Services account

Description

Lists user pools and their details in the current Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_user_pools/ for full documentation.

Usage

cognitoidentityprovider_list_user_pools(NextToken = NULL, MaxResults)

Arguments

NextToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.

MaxResults

[required] The maximum number of user pools that you want Amazon Cognito to return in the response.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.