View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_list_users | R Documentation |
Given a user pool ID, returns a list of users and their basic details in a user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_users/ for full documentation.
cognitoidentityprovider_list_users(
UserPoolId,
AttributesToGet = NULL,
Limit = NULL,
PaginationToken = NULL,
Filter = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to display or search for users. |
AttributesToGet |
A JSON array of user attribute names, for example Use |
Limit |
The maximum number of users that you want Amazon Cognito to return in the response. In some SDK contexts, this operation might return fewer items than you specify in the |
PaginationToken |
This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items. |
Filter |
A filter string of the form
If the filter string is empty, You can only search for the following standard attributes:
Custom attributes aren't searchable. You can also list users with a client-side filter. The server-side filter matches no more than one attribute. For an advanced search, use a client-side filter with the For more information about server-side and client-side filtering, see FilteringCLI output in the Command Line Interface User Guide. For more information, see Searching for Users Using the ListUsers API and Examples of Using the ListUsers API in the Amazon Cognito Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.