cognitoidentityprovider_list_users_in_group: Given a user pool ID and a group name, returns a list of...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_users_in_groupR Documentation

Given a user pool ID and a group name, returns a list of users in the group

Description

Given a user pool ID and a group name, returns a list of users in the group. For more information about user pool groups, see Adding groups to a user pool.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_users_in_group/ for full documentation.

Usage

cognitoidentityprovider_list_users_in_group(
  UserPoolId,
  GroupName,
  Limit = NULL,
  NextToken = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to view the membership of the requested group.

GroupName

[required] The name of the group that you want to query for user membership.

Limit

The maximum number of groups that you want Amazon Cognito to return in the response. In some SDK contexts, this operation might return fewer items than you specify in the Limit parameter without having reached the end of the full list. If the response contains a PaginationToken, then there are more results.

NextToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.