cognitoidentityprovider_list_web_authn_credentials: Generates a list of the currently signed-in user's registered...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_list_web_authn_credentialsR Documentation

Generates a list of the currently signed-in user's registered passkey, or WebAuthn, credentials

Description

Generates a list of the currently signed-in user's registered passkey, or WebAuthn, credentials.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_list_web_authn_credentials/ for full documentation.

Usage

cognitoidentityprovider_list_web_authn_credentials(
  AccessToken,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

NextToken

This API operation returns a limited number of results. The pagination token is an identifier that you can present in an additional API request with the same parameters. When you include the pagination token, Amazon Cognito returns the next set of items after the current list. Subsequent requests return a new pagination token. By use of this token, you can paginate through the full list of items.

MaxResults

The maximum number of the user's passkey credentials that you want to return.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.