View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_resend_confirmation_code | R Documentation |
Resends the code that confirms a new account for a user who has signed up in your user pool. Amazon Cognito sends confirmation codes to the user attribute in the AutoVerifiedAttributes property of your user pool. When you prompt new users for the confirmation code, include a "Resend code" option that generates a call to this API operation.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_resend_confirmation_code/ for full documentation.
cognitoidentityprovider_resend_confirmation_code(
ClientId,
SecretHash = NULL,
UserContextData = NULL,
Username,
AnalyticsMetadata = NULL,
ClientMetadata = NULL
)
ClientId |
[required] The ID of the user pool app client where the user signed up. |
SecretHash |
A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message. For more information about |
UserContextData |
Contextual data about your user session like the device fingerprint, IP address, or location. Amazon Cognito threat protection evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests. For more information, see Collecting data for threat protection in applications. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
AnalyticsMetadata |
Information that supports analytics outcomes with Amazon Pinpoint, including the user's endpoint ID. The endpoint ID is a destination for Amazon Pinpoint push notifications, for example a device identifier, email address, or phone number. |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.