cognitoidentityprovider_revoke_token: Revokes all of the access tokens generated by, and at the...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_revoke_tokenR Documentation

Revokes all of the access tokens generated by, and at the same time as, the specified refresh token

Description

Revokes all of the access tokens generated by, and at the same time as, the specified refresh token. After a token is revoked, you can't use the revoked token to access Amazon Cognito user APIs, or to authorize access to your resource server.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_revoke_token/ for full documentation.

Usage

cognitoidentityprovider_revoke_token(Token, ClientId, ClientSecret = NULL)

Arguments

Token

[required] The refresh token that you want to revoke.

ClientId

[required] The ID of the app client where the token that you want to revoke was issued.

ClientSecret

The client secret of the requested app client, if the client has a secret.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.