cognitoidentityprovider_set_risk_configuration: Configures threat protection for a user pool or app client

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_set_risk_configurationR Documentation

Configures threat protection for a user pool or app client

Description

Configures threat protection for a user pool or app client. Sets configuration for the following.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_risk_configuration/ for full documentation.

Usage

cognitoidentityprovider_set_risk_configuration(
  UserPoolId,
  ClientId = NULL,
  CompromisedCredentialsRiskConfiguration = NULL,
  AccountTakeoverRiskConfiguration = NULL,
  RiskExceptionConfiguration = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to set a risk configuration. If you include UserPoolId in your request, don't include ClientId. When the client ID is null, the same risk configuration is applied to all the clients in the userPool. When you include both ClientId and UserPoolId, Amazon Cognito maps the configuration to the app client only.

ClientId

The ID of the app client where you want to set a risk configuration. If ClientId is null, then the risk configuration is mapped to UserPoolId. When the client ID is null, the same risk configuration is applied to all the clients in the userPool.

When you include a ClientId parameter, Amazon Cognito maps the configuration to the app client. When you include both ClientId and UserPoolId, Amazon Cognito maps the configuration to the app client only.

CompromisedCredentialsRiskConfiguration

The configuration of automated reactions to detected compromised credentials. Includes settings for blocking future sign-in requests and for the types of password-submission events you want to monitor.

AccountTakeoverRiskConfiguration

The settings for automated responses and notification templates for adaptive authentication with threat protection.

RiskExceptionConfiguration

A set of IP-address overrides to threat protection. You can set up IP-address always-block and always-allow lists.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.