cognitoidentityprovider_set_user_pool_mfa_config: Sets user pool multi-factor authentication (MFA) and passkey...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_set_user_pool_mfa_configR Documentation

Sets user pool multi-factor authentication (MFA) and passkey configuration

Description

Sets user pool multi-factor authentication (MFA) and passkey configuration. For more information about user pool MFA, see Adding MFA. For more information about WebAuthn passkeys see Authentication flows.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_user_pool_mfa_config/ for full documentation.

Usage

cognitoidentityprovider_set_user_pool_mfa_config(
  UserPoolId,
  SmsMfaConfiguration = NULL,
  SoftwareTokenMfaConfiguration = NULL,
  EmailMfaConfiguration = NULL,
  MfaConfiguration = NULL,
  WebAuthnConfiguration = NULL
)

Arguments

UserPoolId

[required] The user pool ID.

SmsMfaConfiguration

Configures user pool SMS messages for MFA. Sets the message template and the SMS message sending configuration for Amazon SNS.

SoftwareTokenMfaConfiguration

Configures a user pool for time-based one-time password (TOTP) MFA. Enables or disables TOTP.

EmailMfaConfiguration

Sets configuration for user pool email message MFA and sign-in with one-time passwords (OTPs). Includes the subject and body of the email message template for sign-in and MFA messages. To activate this setting, your user pool must be in the Essentials tier or higher.

MfaConfiguration

Sets multi-factor authentication (MFA) to be on, off, or optional. When ON, all users must set up MFA before they can sign in. When OPTIONAL, your application must make a client-side determination of whether a user wants to register an MFA device. For user pools with adaptive authentication with threat protection, choose OPTIONAL.

When MfaConfiguration is OPTIONAL, managed login doesn't automatically prompt users to set up MFA. Amazon Cognito generates MFA prompts in API responses and in managed login for users who have chosen and configured a preferred MFA factor.

WebAuthnConfiguration

The configuration of your user pool for passkey, or WebAuthn, authentication and registration. Includes relying-party configuration, user-verification requirements, and whether passkeys can satisfy MFA requirements.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.