cognitoidentityprovider_set_user_settings: This action is no longer supported

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_set_user_settingsR Documentation

This action is no longer supported

Description

This action is no longer supported. You can use it to configure only SMS MFA. You can't use it to configure time-based one-time password (TOTP) software token or email MFA.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_user_settings/ for full documentation.

Usage

cognitoidentityprovider_set_user_settings(AccessToken, MFAOptions)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

MFAOptions

[required] You can use this parameter only to set an SMS configuration that uses SMS for delivery.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.