View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_sign_up | R Documentation |
Registers a user with an app client and requests a user name, password, and user attributes in the user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_sign_up/ for full documentation.
cognitoidentityprovider_sign_up(
ClientId,
SecretHash = NULL,
Username,
Password = NULL,
UserAttributes = NULL,
ValidationData = NULL,
AnalyticsMetadata = NULL,
UserContextData = NULL,
ClientMetadata = NULL
)
ClientId |
[required] The ID of the app client where the user wants to sign up. |
SecretHash |
A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message. For more information about |
Username |
[required] The username of the user that you want to sign up. The value of this parameter is typically a username, but can be any alias attribute in your user pool. |
Password |
The user's proposed password. The password must comply with the password requirements of your user pool. Users can sign up without a password when your user pool supports passwordless sign-in with email or SMS OTPs. To create a user with no password, omit this parameter or submit a blank value. You can only create a passwordless user when passwordless sign-in is available. |
UserAttributes |
An array of name-value pairs representing user attributes. For custom attributes, include a |
ValidationData |
Temporary user attributes that contribute to the outcomes of your pre sign-up Lambda trigger. This set of key-value pairs are for custom validation of information that you collect from your users but don't need to retain. Your Lambda function can analyze this additional data and act on it. Your function can automatically confirm and verify select users or perform external API operations like logging user attributes and validation data to Amazon CloudWatch Logs. For more information about the pre sign-up Lambda trigger, see Pre sign-up Lambda trigger. |
AnalyticsMetadata |
Information that supports analytics outcomes with Amazon Pinpoint, including the user's endpoint ID. The endpoint ID is a destination for Amazon Pinpoint push notifications, for example a device identifier, email address, or phone number. |
UserContextData |
Contextual data about your user session like the device fingerprint, IP address, or location. Amazon Cognito threat protection evaluates the risk of an authentication event based on the context that your app generates and passes to Amazon Cognito when it makes API requests. For more information, see Collecting data for threat protection in applications. |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.