cognitoidentityprovider_start_user_import_job: Instructs your user pool to start importing users from a CSV...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_start_user_import_jobR Documentation

Instructs your user pool to start importing users from a CSV file that contains their usernames and attributes

Description

Instructs your user pool to start importing users from a CSV file that contains their usernames and attributes. For more information about importing users from a CSV file, see Importing users from a CSV file.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_start_user_import_job/ for full documentation.

Usage

cognitoidentityprovider_start_user_import_job(UserPoolId, JobId)

Arguments

UserPoolId

[required] The ID of the user pool that you want to start importing users into.

JobId

[required] The ID of a user import job that you previously created.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.