cognitoidentityprovider_start_web_authn_registration: Requests credential creation options from your user pool for...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_start_web_authn_registrationR Documentation

Requests credential creation options from your user pool for the currently signed-in user

Description

Requests credential creation options from your user pool for the currently signed-in user. Returns information about the user pool, the user profile, and authentication requirements. Users must provide this information in their request to enroll your application with their passkey provider.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_start_web_authn_registration/ for full documentation.

Usage

cognitoidentityprovider_start_web_authn_registration(AccessToken)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.