cognitoidentityprovider_untag_resource: Given tag IDs that you previously assigned to a user pool,...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_untag_resourceR Documentation

Given tag IDs that you previously assigned to a user pool, removes them

Description

Given tag IDs that you previously assigned to a user pool, removes them.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_untag_resource/ for full documentation.

Usage

cognitoidentityprovider_untag_resource(ResourceArn, TagKeys)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the user pool that the tags are assigned to.

TagKeys

[required] An array of tag keys that you want to remove from the user pool.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.