cognitoidentityprovider_update_auth_event_feedback: Provides the feedback for an authentication event generated...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_auth_event_feedbackR Documentation

Provides the feedback for an authentication event generated by threat protection features

Description

Provides the feedback for an authentication event generated by threat protection features. The user's response indicates that you think that the event either was from a valid user or was an unwanted authentication attempt. This feedback improves the risk evaluation decision for the user pool as part of Amazon Cognito threat protection. To activate this setting, your user pool must be on the Plus tier.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_auth_event_feedback/ for full documentation.

Usage

cognitoidentityprovider_update_auth_event_feedback(
  UserPoolId,
  Username,
  EventId,
  FeedbackToken,
  FeedbackValue
)

Arguments

UserPoolId

[required] The ID of the user pool where you want to update auth event feedback.

Username

[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If username isn't an alias attribute in your user pool, this value must be the sub of a local user or the username of a user from a third-party IdP.

EventId

[required] The ID of the authentication event that you want to submit feedback for.

FeedbackToken

[required] The feedback token, an encrypted object generated by Amazon Cognito and passed to your user in the notification email message from the event.

FeedbackValue

[required] Your feedback to the authentication event. When you provide a FeedbackValue value of valid, you tell Amazon Cognito that you trust a user session where Amazon Cognito has evaluated some level of risk. When you provide a FeedbackValue value of invalid, you tell Amazon Cognito that you don't trust a user session, or you don't believe that Amazon Cognito evaluated a high-enough risk level.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.