cognitoidentityprovider_update_device_status: Updates the status of a the currently signed-in user's device...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_device_statusR Documentation

Updates the status of a the currently signed-in user's device so that it is marked as remembered or not remembered for the purpose of device authentication

Description

Updates the status of a the currently signed-in user's device so that it is marked as remembered or not remembered for the purpose of device authentication. Device authentication is a "remember me" mechanism that silently completes sign-in from trusted devices with a device key instead of a user-provided MFA code. This operation changes the status of a device without deleting it, so you can enable it again later. For more information about device authentication, see Working with devices.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_device_status/ for full documentation.

Usage

cognitoidentityprovider_update_device_status(
  AccessToken,
  DeviceKey,
  DeviceRememberedStatus = NULL
)

Arguments

AccessToken

[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

DeviceKey

[required] The device key of the device you want to update, for example ⁠us-west-2_a1b2c3d4-5678-90ab-cdef-EXAMPLE11111⁠.

DeviceRememberedStatus

To enable device authentication with the specified device, set to remembered.To disable, set to not_remembered.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.