cognitoidentityprovider_update_group: Given the name of a user pool group, updates any of the...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_groupR Documentation

Given the name of a user pool group, updates any of the properties for precedence, IAM role, or description

Description

Given the name of a user pool group, updates any of the properties for precedence, IAM role, or description. For more information about user pool groups, see Adding groups to a user pool.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_group/ for full documentation.

Usage

cognitoidentityprovider_update_group(
  GroupName,
  UserPoolId,
  Description = NULL,
  RoleArn = NULL,
  Precedence = NULL
)

Arguments

GroupName

[required] The name of the group that you want to update.

UserPoolId

[required] The ID of the user pool that contains the group you want to update.

Description

A new description of the existing group.

RoleArn

The Amazon Resource Name (ARN) of an IAM role that you want to associate with the group. The role assignment contributes to the cognito:roles and cognito:preferred_role claims in group members' tokens.

Precedence

A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower Precedence values take precedence over groups with higher or null Precedence values. If a user belongs to two or more groups, it is the group with the lowest precedence value whose role ARN is given in the user's tokens for the cognito:roles and cognito:preferred_role claims.

Two groups can have the same Precedence value. If this happens, neither group takes precedence over the other. If two groups with the same Precedence have the same role ARN, that role is used in the cognito:preferred_role claim in tokens for users in each group. If the two groups have different role ARNs, the cognito:preferred_role claim isn't set in users' tokens.

The default Precedence value is null. The maximum Precedence value is 2^31-1.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.