View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_managed_login_branding | R Documentation |
Configures the branding settings for a user pool style. This operation is the programmatic option for the configuration of a style in the branding editor.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_managed_login_branding/ for full documentation.
cognitoidentityprovider_update_managed_login_branding(
UserPoolId = NULL,
ManagedLoginBrandingId = NULL,
UseCognitoProvidedValues = NULL,
Settings = NULL,
Assets = NULL
)
UserPoolId |
The ID of the user pool that contains the managed login branding style that you want to update. |
ManagedLoginBrandingId |
The ID of the managed login branding style that you want to update. |
UseCognitoProvidedValues |
When When you specify |
Settings |
A JSON file, encoded as a The following components are not currently implemented and reserved for future use:
[Managed login localization)]: R:Managed%20login%20localization) |
Assets |
An array of image files that you want to apply to roles like backgrounds, logos, and icons. Each object must also indicate whether it is for dark mode, light mode, or browser-adaptive mode. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.