cognitoidentityprovider_update_resource_server: Updates the name and scopes of a resource server

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_resource_serverR Documentation

Updates the name and scopes of a resource server

Description

Updates the name and scopes of a resource server. All other fields are read-only. For more information about resource servers, see Access control with resource servers.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_resource_server/ for full documentation.

Usage

cognitoidentityprovider_update_resource_server(
  UserPoolId,
  Identifier,
  Name,
  Scopes = NULL
)

Arguments

UserPoolId

[required] The ID of the user pool that contains the resource server that you want to update.

Identifier

[required] A unique resource server identifier for the resource server. The identifier can be an API friendly name like solar-system-data. You can also set an API URL like ⁠https://solar-system-data-api.example.com⁠ as your identifier.

Amazon Cognito represents scopes in the access token in the format ⁠$resource-server-identifier/$scope⁠. Longer scope-identifier strings increase the size of your access tokens.

Name

[required] The updated name of the resource server.

Scopes

An array of updated custom scope names and descriptions that you want to associate with your resource server.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.