cognitoidentityprovider_update_terms: Modifies existing terms documents for the requested app...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_termsR Documentation

Modifies existing terms documents for the requested app client

Description

Modifies existing terms documents for the requested app client. When Terms and conditions and Privacy policy documents are configured, the app client displays links to them in the sign-up page of managed login for the app client.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_terms/ for full documentation.

Usage

cognitoidentityprovider_update_terms(
  TermsId,
  UserPoolId,
  TermsName = NULL,
  TermsSource = NULL,
  Enforcement = NULL,
  Links = NULL
)

Arguments

TermsId

[required] The ID of the terms document that you want to update.

UserPoolId

[required] The ID of the user pool that contains the terms that you want to update.

TermsName

The new name that you want to apply to the requested terms documents.

TermsSource

This parameter is reserved for future use and currently accepts only one value.

Enforcement

This parameter is reserved for future use and currently accepts only one value.

Links

A map of URLs to languages. For each localized language that will view the requested TermsName, assign a URL. A selection of cognito:default displays for all languages that don't have a language-specific URL.

For example, ⁠"cognito:default": "https://terms.example.com", "cognito:spanish": "https://terms.example.com/es"⁠.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.