View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_user_attributes | R Documentation |
Updates the currently signed-in user's attributes. To delete an attribute from the user, submit the attribute in your API request with a blank value.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_user_attributes/ for full documentation.
cognitoidentityprovider_update_user_attributes(
UserAttributes,
AccessToken,
ClientMetadata = NULL
)
UserAttributes |
[required] An array of name-value pairs representing user attributes. For custom attributes, you must add a If you have set an attribute to require verification before Amazon Cognito updates its value, this request doesn’t immediately update the value of that attribute. After your user receives and responds to a verification message to verify the new value, Amazon Cognito updates the attribute value. Your user can sign in and receive messages with the original attribute value until they verify the new value. |
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.