cognitoidentityprovider_update_user_pool_domain: A user pool domain hosts managed login, an authorization...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_update_user_pool_domainR Documentation

A user pool domain hosts managed login, an authorization server and web server for authentication in your application

Description

A user pool domain hosts managed login, an authorization server and web server for authentication in your application. This operation updates the branding version for user pool domains between 1 for hosted UI (classic) and 2 for managed login. It also updates the SSL certificate for user pool custom domains.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_user_pool_domain/ for full documentation.

Usage

cognitoidentityprovider_update_user_pool_domain(
  Domain,
  UserPoolId,
  ManagedLoginVersion = NULL,
  CustomDomainConfig = NULL
)

Arguments

Domain

[required] The name of the domain that you want to update. For custom domains, this is the fully-qualified domain name, for example auth.example.com. For prefix domains, this is the prefix alone, such as myprefix.

UserPoolId

[required] The ID of the user pool that is associated with the domain you're updating.

ManagedLoginVersion

A version number that indicates the state of managed login for your domain. Version 1 is hosted UI (classic). Version 2 is the newer managed login with the branding editor. For more information, see Managed login.

CustomDomainConfig

The configuration for a custom domain that hosts managed login for your application. In an update_user_pool_domain request, this parameter specifies an SSL certificate for the managed login hosted webserver. The certificate must be an ACM ARN in us-east-1.

When you create a custom domain, the passkey RP ID defaults to the custom domain. If you had a prefix domain active, this will cause passkey integration for your prefix domain to stop working due to a mismatch in RP ID. To keep the prefix domain passkey integration working, you can explicitly set RP ID to the prefix domain.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.