cognitoidentityprovider_verify_software_token: Registers the current user's time-based one-time password...

View source: R/cognitoidentityprovider_operations.R

cognitoidentityprovider_verify_software_tokenR Documentation

Registers the current user's time-based one-time password (TOTP) authenticator with a code generated in their authenticator app from a private key that's supplied by your user pool

Description

Registers the current user's time-based one-time password (TOTP) authenticator with a code generated in their authenticator app from a private key that's supplied by your user pool. Marks the user's software token MFA status as "verified" if successful. The request takes an access token or a session string, but not both.

See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_verify_software_token/ for full documentation.

Usage

cognitoidentityprovider_verify_software_token(
  AccessToken = NULL,
  Session = NULL,
  UserCode,
  FriendlyDeviceName = NULL
)

Arguments

AccessToken

A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for aws.cognito.signin.user.admin.

Session

The session ID from an associate_software_token request.

UserCode

[required] A TOTP that the user generated in their configured authenticator app.

FriendlyDeviceName

A friendly name for the device that's running the TOTP authenticator.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.