Gets a list of identity pools registered with Cognito.
ListIdentityPoolUsage can only be called with developer credentials. You cannot make this API call with the temporary user credentials provided by Cognito Identity.
cognitosync_list_identity_pool_usage(NextToken, MaxResults)A list with the following syntax:
list(
IdentityPoolUsages = list(
list(
IdentityPoolId = "string",
SyncSessionsCount = 123,
DataStorage = 123,
LastModifiedDate = as.POSIXct(
"2015-01-01"
)
)
),
MaxResults = 123,
Count = 123,
NextToken = "string"
)
A pagination token for obtaining the next page of results.
The maximum number of results to be returned.
svc$list_identity_pool_usage(
NextToken = "string",
MaxResults = 123
)