Registers a device to receive push sync notifications.
This API can only be called with temporary credentials provided by Cognito Identity. You cannot call this API with developer credentials.
cognitosync_register_device(IdentityPoolId, IdentityId, Platform, Token)A list with the following syntax:
list(
DeviceId = "string"
)
[required] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. Here, the ID of the pool that the identity belongs to.
[required] The unique ID for this identity.
[required] The SNS platform type (e.g. GCM, SDM, APNS, APNS_SANDBOX).
[required] The push token.
svc$register_device(
IdentityPoolId = "string",
IdentityId = "string",
Platform = "APNS"|"APNS_SANDBOX"|"GCM"|"ADM",
Token = "string"
)