Adds or overwrites one or more tags for the specified directory. Each directory can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique to each resource.
directoryservice_add_tags_to_resource(ResourceId, Tags)[required] Identifier (ID) for the directory to which to add the tag.
[required] The tags to be assigned to the directory.
svc$add_tags_to_resource(
ResourceId = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)