directoryservice_create_conditional_forwarder: Creates a conditional forwarder associated with your Amazon...

View source: R/directoryservice_operations.R

directoryservice_create_conditional_forwarderR Documentation

Creates a conditional forwarder associated with your Amazon Web Services directory

Description

Creates a conditional forwarder associated with your Amazon Web Services directory. Conditional forwarders are required in order to set up a trust relationship with another domain. The conditional forwarder points to the trusted domain.

See https://www.paws-r-sdk.com/docs/directoryservice_create_conditional_forwarder/ for full documentation.

Usage

directoryservice_create_conditional_forwarder(
  DirectoryId,
  RemoteDomainName,
  DnsIpAddrs = NULL,
  DnsIpv6Addrs = NULL
)

Arguments

DirectoryId

[required] The directory ID of the Amazon Web Services directory for which you are creating the conditional forwarder.

RemoteDomainName

[required] The fully qualified domain name (FQDN) of the remote domain with which you will set up a trust relationship.

DnsIpAddrs

The IP addresses of the remote DNS server associated with RemoteDomainName.

DnsIpv6Addrs

The IPv6 addresses of the remote DNS server associated with RemoteDomainName.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.