View source: R/directoryservice_operations.R
| directoryservice_delete_ad_assessment | R Documentation |
Deletes a directory assessment and all associated data. This operation permanently removes the assessment results, validation reports, and configuration information.
See https://www.paws-r-sdk.com/docs/directoryservice_delete_ad_assessment/ for full documentation.
directoryservice_delete_ad_assessment(AssessmentId)
AssessmentId |
[required] The unique identifier of the directory assessment to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.