directoryservice_describe_ca_enrollment_policy: Retrieves detailed information about the certificate...

View source: R/directoryservice_operations.R

directoryservice_describe_ca_enrollment_policyR Documentation

Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory

Description

Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory. This policy determines how client certificates are automatically enrolled and managed through Amazon Web Services Private Certificate Authority.

See https://www.paws-r-sdk.com/docs/directoryservice_describe_ca_enrollment_policy/ for full documentation.

Usage

directoryservice_describe_ca_enrollment_policy(DirectoryId)

Arguments

DirectoryId

[required] The identifier of the directory for which to retrieve the CA enrollment policy information.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.