View source: R/directoryservice_operations.R
| directoryservice_describe_hybrid_ad_update | R Documentation |
Retrieves information about update activities for a hybrid directory. This operation provides details about configuration changes, administrator account updates, and self-managed instance settings (IDs and DNS IPs).
See https://www.paws-r-sdk.com/docs/directoryservice_describe_hybrid_ad_update/ for full documentation.
directoryservice_describe_hybrid_ad_update(
DirectoryId,
UpdateType = NULL,
NextToken = NULL
)
DirectoryId |
[required] The identifier of the hybrid directory for which to retrieve update information. |
UpdateType |
The type of update activities to retrieve. Valid values include |
NextToken |
The pagination token from a previous request to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.