View source: R/directoryservice_operations.R
| directoryservice_disable_ca_enrollment_policy | R Documentation |
Disables the certificate authority (CA) enrollment policy for the specified directory. This stops automatic certificate enrollment and management for domain-joined clients, but does not affect existing certificates.
See https://www.paws-r-sdk.com/docs/directoryservice_disable_ca_enrollment_policy/ for full documentation.
directoryservice_disable_ca_enrollment_policy(DirectoryId)
DirectoryId |
[required] The identifier of the directory for which to disable the CA enrollment policy. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.