directoryservice_enable_ca_enrollment_policy: Enables certificate authority (CA) enrollment policy for the...

View source: R/directoryservice_operations.R

directoryservice_enable_ca_enrollment_policyR Documentation

Enables certificate authority (CA) enrollment policy for the specified directory

Description

Enables certificate authority (CA) enrollment policy for the specified directory. This allows domain-joined clients to automatically request and receive certificates from the specified Amazon Web Services Private Certificate Authority.

See https://www.paws-r-sdk.com/docs/directoryservice_enable_ca_enrollment_policy/ for full documentation.

Usage

directoryservice_enable_ca_enrollment_policy(DirectoryId, PcaConnectorArn)

Arguments

DirectoryId

[required] The identifier of the directory for which to enable the CA enrollment policy.

PcaConnectorArn

[required] The Amazon Resource Name (ARN) of the Private Certificate Authority (PCA) connector to use for automatic certificate enrollment. This connector must be properly configured and accessible from the directory.

The ARN format is: arn:aws:pca-connector-ad:region:account-id:connector/connector-id


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.