View source: R/directoryservice_operations.R
| directoryservice_list_ad_assessments | R Documentation |
Retrieves a list of directory assessments for the specified directory or all assessments in your account. Use this operation to monitor assessment status and manage multiple assessments.
See https://www.paws-r-sdk.com/docs/directoryservice_list_ad_assessments/ for full documentation.
directoryservice_list_ad_assessments(
DirectoryId = NULL,
NextToken = NULL,
Limit = NULL
)
DirectoryId |
The identifier of the directory for which to list assessments. If not specified, all assessments in your account are returned. |
NextToken |
The pagination token from a previous request to |
Limit |
The maximum number of assessment summaries to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.