View source: R/directoryservice_operations.R
| directoryservice_start_ad_assessment | R Documentation |
Initiates a directory assessment to validate your self-managed AD environment for hybrid domain join. The assessment checks compatibility and connectivity of the self-managed AD environment.
See https://www.paws-r-sdk.com/docs/directoryservice_start_ad_assessment/ for full documentation.
directoryservice_start_ad_assessment(
AssessmentConfiguration = NULL,
DirectoryId = NULL
)
AssessmentConfiguration |
Configuration parameters for the directory assessment, including DNS server information, domain name, Amazon VPC subnet, and Amazon Web Services System Manager managed node details. |
DirectoryId |
The identifier of the directory for which to perform the assessment. This should be an existing directory. If the assessment is not for an existing directory, this parameter should be omitted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.