View source: R/directoryservice_operations.R
| directoryservice_update_hybrid_ad | R Documentation |
Updates the configuration of an existing hybrid directory. You can recover hybrid directory administrator account or modify self-managed instance settings.
See https://www.paws-r-sdk.com/docs/directoryservice_update_hybrid_ad/ for full documentation.
directoryservice_update_hybrid_ad(
DirectoryId,
HybridAdministratorAccountUpdate = NULL,
SelfManagedInstancesSettings = NULL
)
DirectoryId |
[required] The identifier of the hybrid directory to update. |
HybridAdministratorAccountUpdate |
We create a hybrid directory administrator account when we create a hybrid directory. Use To recover your hybrid directory administrator account, we need temporary access to a user in your self-managed AD with administrator permissions in the form of a secret from Amazon Web Services Secrets Manager. We use these credentials once during recovery and don't store them. If your hybrid directory administrator account exists, then you don’t need to use |
SelfManagedInstancesSettings |
Updates to the self-managed AD configuration, including DNS server IP addresses and Amazon Web Services System Manager managed node identifiers. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.