Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/fms_get_violation_details/ for full documentation.
fms_get_violation_details(PolicyId, MemberAccount, ResourceId, ResourceType)[required] The ID of the Firewall Manager policy that you want the details for. This currently only supports security group content audit policies.
[required] The Amazon Web Services account ID that you want the details for.
[required] The ID of the resource that has violations.
[required] The resource type. This is in the format shown in the Amazon Web Services Resource Types Reference.
Supported resource types are: AWS::EC2::Instance,
AWS::EC2::NetworkInterface, AWS::EC2::SecurityGroup,
AWS::NetworkFirewall::FirewallPolicy, and AWS::EC2::Subnet.