View source: R/guardduty_operations.R
| guardduty_create_threat_entity_set | R Documentation |
Creates a new threat entity set. In a threat entity set, you can provide known malicious threat entities for your Amazon Web Services environment. GuardDuty generates findings based on the entries in the threat entity sets. Only users of the administrator account can manage entity sets, which automatically apply to member accounts.
See https://www.paws-r-sdk.com/docs/guardduty_create_threat_entity_set/ for full documentation.
guardduty_create_threat_entity_set(
DetectorId,
Name,
Format,
Location,
ExpectedBucketOwner = NULL,
Activate,
ClientToken = NULL,
Tags = NULL
)
DetectorId |
[required] The unique ID of the detector of the GuardDuty account for which you want to create a threat entity set. To find the |
Name |
[required] A user-friendly name to identify the threat entity set. The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_). |
Format |
[required] The format of the file that contains the threat entity set. |
Location |
[required] The URI of the file that contains the threat entity set. The format of the |
ExpectedBucketOwner |
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. |
Activate |
[required] A boolean value that indicates whether GuardDuty should start using the uploaded threat entity set to generate findings. |
ClientToken |
The idempotency token for the create request. |
Tags |
The tags to be added to a new threat entity set resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.