View source: R/guardduty_operations.R
| guardduty_create_trusted_entity_set | R Documentation |
Creates a new trusted entity set. In the trusted entity set, you can provide IP addresses and domains that you believe are secure for communication in your Amazon Web Services environment. GuardDuty will not generate findings for the entries that are specified in a trusted entity set. At any given time, you can have only one trusted entity set.
See https://www.paws-r-sdk.com/docs/guardduty_create_trusted_entity_set/ for full documentation.
guardduty_create_trusted_entity_set(
DetectorId,
Name,
Format,
Location,
ExpectedBucketOwner = NULL,
Activate,
ClientToken = NULL,
Tags = NULL
)
DetectorId |
[required] The unique ID of the detector of the GuardDuty account for which you want to create a trusted entity set. To find the |
Name |
[required] A user-friendly name to identify the trusted entity set. The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_). |
Format |
[required] The format of the file that contains the trusted entity set. |
Location |
[required] The URI of the file that contains the threat entity set. The format of the |
ExpectedBucketOwner |
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. |
Activate |
[required] A boolean value that indicates whether GuardDuty is to start using the uploaded trusted entity set. |
ClientToken |
The idempotency token for the create request. |
Tags |
The tags to be added to a new trusted entity set resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.