guardduty_delete_threat_entity_set: Deletes the threat entity set that is associated with the...

View source: R/guardduty_operations.R

guardduty_delete_threat_entity_setR Documentation

Deletes the threat entity set that is associated with the specified threatEntitySetId

Description

Deletes the threat entity set that is associated with the specified threatEntitySetId.

See https://www.paws-r-sdk.com/docs/guardduty_delete_threat_entity_set/ for full documentation.

Usage

guardduty_delete_threat_entity_set(DetectorId, ThreatEntitySetId)

Arguments

DetectorId

[required] The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the list_detectors API.

ThreatEntitySetId

[required] The unique ID that helps GuardDuty identify which threat entity set needs to be deleted.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.