guardduty_get_malware_scan: Retrieves the detailed information for a specific malware...

View source: R/guardduty_operations.R

guardduty_get_malware_scanR Documentation

Retrieves the detailed information for a specific malware scan

Description

Retrieves the detailed information for a specific malware scan. Each member account can view the malware scan details for their own account. An administrator can view malware scan details for all accounts in the organization.

See https://www.paws-r-sdk.com/docs/guardduty_get_malware_scan/ for full documentation.

Usage

guardduty_get_malware_scan(ScanId)

Arguments

ScanId

[required] A unique identifier that gets generated when you invoke the API without any error. Each malware scan has a corresponding scan ID. Using this scan ID, you can monitor the status of your malware scan.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.