guardduty_get_threat_entity_set: Retrieves the threat entity set associated with the specified...

View source: R/guardduty_operations.R

guardduty_get_threat_entity_setR Documentation

Retrieves the threat entity set associated with the specified threatEntitySetId

Description

Retrieves the threat entity set associated with the specified threatEntitySetId.

See https://www.paws-r-sdk.com/docs/guardduty_get_threat_entity_set/ for full documentation.

Usage

guardduty_get_threat_entity_set(DetectorId, ThreatEntitySetId)

Arguments

DetectorId

[required] The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the list_detectors API.

ThreatEntitySetId

[required] The unique ID that helps GuardDuty identify the threat entity set.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.