guardduty_get_trusted_entity_set: Retrieves the trusted entity set associated with the...

View source: R/guardduty_operations.R

guardduty_get_trusted_entity_setR Documentation

Retrieves the trusted entity set associated with the specified trustedEntitySetId

Description

Retrieves the trusted entity set associated with the specified trustedEntitySetId.

See https://www.paws-r-sdk.com/docs/guardduty_get_trusted_entity_set/ for full documentation.

Usage

guardduty_get_trusted_entity_set(DetectorId, TrustedEntitySetId)

Arguments

DetectorId

[required] The unique ID of the GuardDuty detector associated with this trusted entity set.

TrustedEntitySetId

[required] The unique ID that helps GuardDuty identify the trusted entity set.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.