guardduty_list_malware_scans: Returns a list of malware scans

View source: R/guardduty_operations.R

guardduty_list_malware_scansR Documentation

Returns a list of malware scans

Description

Returns a list of malware scans. Each member account can view the malware scans for their own accounts. An administrator can view the malware scans for all of its members' accounts.

See https://www.paws-r-sdk.com/docs/guardduty_list_malware_scans/ for full documentation.

Usage

guardduty_list_malware_scans(
  MaxResults = NULL,
  NextToken = NULL,
  FilterCriteria = NULL,
  SortCriteria = NULL
)

Arguments

MaxResults

You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.

NextToken

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing results.

FilterCriteria

Represents the criteria used to filter the malware scan entries.

SortCriteria

Represents the criteria used for sorting malware scan entries.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.