Learn R Programming

paws.security.identity (version 0.1.5)

guardduty_list_tags_for_resource: Lists tags for a resource

Description

Lists tags for a resource. Tagging is currently supported for detectors, finding filters, IP sets, and Threat Intel sets, with a limit of 50 tags per resource. When invoked, this operation returns all assigned tags for a given resource..

Usage

guardduty_list_tags_for_resource(ResourceArn)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) for the given GuardDuty resource

Request syntax

svc$list_tags_for_resource(
  ResourceArn = "string"
)