View source: R/guardduty_operations.R
| guardduty_list_trusted_entity_sets | R Documentation |
Lists the trusted entity sets associated with the specified GuardDuty detector ID. If you use this operation from a member account, the trusted entity sets that are returned as a response, belong to the administrator account.
See https://www.paws-r-sdk.com/docs/guardduty_list_trusted_entity_sets/ for full documentation.
guardduty_list_trusted_entity_sets(
DetectorId,
MaxResults = NULL,
NextToken = NULL
)
DetectorId |
[required] The unique ID of the GuardDuty detector that is associated with this threat entity set. To find the |
MaxResults |
You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. |
NextToken |
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.