guardduty_send_object_malware_scan: Initiates a malware scan for a specific S3 object

View source: R/guardduty_operations.R

guardduty_send_object_malware_scanR Documentation

Initiates a malware scan for a specific S3 object

Description

Initiates a malware scan for a specific S3 object. This API allows you to perform on-demand malware scanning of individual objects in S3 buckets that have Malware Protection for S3 enabled.

See https://www.paws-r-sdk.com/docs/guardduty_send_object_malware_scan/ for full documentation.

Usage

guardduty_send_object_malware_scan(S3Object = NULL)

Arguments

S3Object

The S3 object information for the object you want to scan. The bucket must have a Malware Protection plan configured to use this API.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.