View source: R/guardduty_operations.R
| guardduty_update_filter | R Documentation |
Updates the filter specified by the filter name.
See https://www.paws-r-sdk.com/docs/guardduty_update_filter/ for full documentation.
guardduty_update_filter(
DetectorId,
FilterName,
Description = NULL,
Action = NULL,
Rank = NULL,
FindingCriteria = NULL
)
DetectorId |
[required] The unique ID of the detector that specifies the GuardDuty service where you want to update a filter. To find the |
FilterName |
[required] The name of the filter. |
Description |
The description of the filter. Valid characters include alphanumeric characters, and special characters such as hyphen, period, colon, underscore, parentheses ( [ ]: R:%20 |
Action |
Specifies the action that is to be applied to the findings that match the filter. Default: NOOP |
Rank |
Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings. |
FindingCriteria |
Represents the criteria to be used in the filter for querying findings. The following fields are available for filtering:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.