iam_accept_delegation_request: Accepts a delegation request, granting the requested...

View source: R/iam_operations.R

iam_accept_delegation_requestR Documentation

Accepts a delegation request, granting the requested temporary access

Description

Accepts a delegation request, granting the requested temporary access.

See https://www.paws-r-sdk.com/docs/iam_accept_delegation_request/ for full documentation.

Usage

iam_accept_delegation_request(DelegationRequestId)

Arguments

DelegationRequestId

[required] The unique identifier of the delegation request to accept.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.