View source: R/iam_operations.R
| iam_create_delegation_request | R Documentation |
Creates an IAM delegation request for temporary access delegation.
See https://www.paws-r-sdk.com/docs/iam_create_delegation_request/ for full documentation.
iam_create_delegation_request(
OwnerAccountId = NULL,
Description,
Permissions,
RequestMessage = NULL,
RequestorWorkflowId,
RedirectUrl = NULL,
NotificationChannel,
SessionDuration,
OnlySendByOwner = NULL
)
OwnerAccountId |
The Amazon Web Services account ID this delegation request is targeted to. If the account ID is not known, this parameter can be omitted, resulting in a request that can be associated by any account. If the account ID passed, then the created delegation request can only be associated with an identity of that target account. |
Description |
[required] A description of the delegation request. |
Permissions |
[required] The permissions to be delegated in this delegation request. |
RequestMessage |
A message explaining the reason for the delegation request. Requesters can utilize this field to add a custom note to the delegation request. This field is different from the description such that this is to be utilized for a custom messaging on a case-by-case basis. For example, if the current delegation request is in response to a previous request being rejected, this explanation can be added to the request via this field. |
RequestorWorkflowId |
[required] The workflow ID associated with the requestor. This is the unique identifier on the partner side that can be used to track the progress of the request. IAM maintains a uniqueness check on this workflow id for each request - if a workflow id for an existing request is passed, this API call will fail. |
RedirectUrl |
The URL to redirect to after the delegation request is processed. This URL is used by the IAM console to show a link to the customer to re-load the partner workflow. |
NotificationChannel |
[required] The notification channel for updates about the delegation request. At this time,only SNS topic ARNs are accepted for notification. This topic ARN must have a resource policy granting |
SessionDuration |
[required] The duration for which the delegated session should remain active, in seconds. The active time window for the session starts when the customer calls the |
OnlySendByOwner |
Specifies whether the delegation token should only be sent by the owner. This flag prevents any party other than the owner from calling |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.