iam_disable_outbound_web_identity_federation: Disables the outbound identity federation feature for your...

View source: R/iam_operations.R

iam_disable_outbound_web_identity_federationR Documentation

Disables the outbound identity federation feature for your Amazon Web Services account

Description

Disables the outbound identity federation feature for your Amazon Web Services account. When disabled, IAM principals in the account cannot use the GetWebIdentityToken API to obtain JSON Web Tokens (JWTs) for authentication with external services. This operation does not affect tokens that were issued before the feature was disabled.

See https://www.paws-r-sdk.com/docs/iam_disable_outbound_web_identity_federation/ for full documentation.

Usage

iam_disable_outbound_web_identity_federation()

paws.security.identity documentation built on May 31, 2026, 9:07 a.m.