iam_enable_outbound_web_identity_federation: Enables the outbound identity federation feature for your...

View source: R/iam_operations.R

iam_enable_outbound_web_identity_federationR Documentation

Enables the outbound identity federation feature for your Amazon Web Services account

Description

Enables the outbound identity federation feature for your Amazon Web Services account. When enabled, IAM principals in your account can use the GetWebIdentityToken API to obtain JSON Web Tokens (JWTs) for secure authentication with external services. This operation also generates a unique issuer URL for your Amazon Web Services account.

See https://www.paws-r-sdk.com/docs/iam_enable_outbound_web_identity_federation/ for full documentation.

Usage

iam_enable_outbound_web_identity_federation()

paws.security.identity documentation built on May 31, 2026, 9:07 a.m.