iam_get_delegation_request: Retrieves information about a specific delegation request

View source: R/iam_operations.R

iam_get_delegation_requestR Documentation

Retrieves information about a specific delegation request

Description

Retrieves information about a specific delegation request.

See https://www.paws-r-sdk.com/docs/iam_get_delegation_request/ for full documentation.

Usage

iam_get_delegation_request(
  DelegationRequestId,
  DelegationPermissionCheck = NULL
)

Arguments

DelegationRequestId

[required] The unique identifier of the delegation request to retrieve.

DelegationPermissionCheck

Specifies whether to perform a permission check for the delegation request.

If set to true, the get_delegation_request API call will start a permission check process. This process calculates whether the caller has sufficient permissions to cover the asks from this delegation request.

Setting this parameter to true does not guarantee an answer in the response. See the PermissionCheckStatus and the PermissionCheckResult response attributes for further details.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.