iam_get_human_readable_summary: Retrieves a human readable summary for a given entity

View source: R/iam_operations.R

iam_get_human_readable_summaryR Documentation

Retrieves a human readable summary for a given entity

Description

Retrieves a human readable summary for a given entity. At this time, the only supported entity type is delegation-request

See https://www.paws-r-sdk.com/docs/iam_get_human_readable_summary/ for full documentation.

Usage

iam_get_human_readable_summary(EntityArn, Locale = NULL)

Arguments

EntityArn

[required] Arn of the entity to be summarized. At this time, the only supported entity type is delegation-request

Locale

A string representing the locale to use for the summary generation. The supported locale strings are based on the Supported languages of the Amazon Web Services Management Console .


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.