iam_get_outbound_web_identity_federation_info: Retrieves the configuration information for the outbound...

View source: R/iam_operations.R

iam_get_outbound_web_identity_federation_infoR Documentation

Retrieves the configuration information for the outbound identity federation feature in your Amazon Web Services account

Description

Retrieves the configuration information for the outbound identity federation feature in your Amazon Web Services account. The response includes the unique issuer URL for your Amazon Web Services account and the current enabled/disabled status of the feature. Use this operation to obtain the issuer URL that you need to configure trust relationships with external services.

See https://www.paws-r-sdk.com/docs/iam_get_outbound_web_identity_federation_info/ for full documentation.

Usage

iam_get_outbound_web_identity_federation_info()

paws.security.identity documentation built on May 31, 2026, 9:07 a.m.