View source: R/iam_operations.R
| iam_get_service_last_accessed_details | R Documentation |
Retrieves a service last accessed report that was created using the generate_service_last_accessed_details operation. You can use the JobId parameter in get_service_last_accessed_details to retrieve the status of your report job. When the report is complete, you can retrieve the generated report. The report includes a list of Amazon Web Services services that the resource (user, group, role, or managed policy) can access.
See https://www.paws-r-sdk.com/docs/iam_get_service_last_accessed_details/ for full documentation.
iam_get_service_last_accessed_details(JobId, MaxItems = NULL, Marker = NULL)
JobId |
[required] The ID of the request generated by the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.