View source: R/iam_operations.R
| iam_list_delegation_requests | R Documentation |
Lists delegation requests based on the specified criteria.
See https://www.paws-r-sdk.com/docs/iam_list_delegation_requests/ for full documentation.
iam_list_delegation_requests(OwnerId = NULL, Marker = NULL, MaxItems = NULL)
OwnerId |
The owner ID to filter delegation requests by. |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM may return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.