View source: R/iam_operations.R
| iam_list_entities_for_policy | R Documentation |
Lists all IAM users, groups, and roles that the specified managed policy is attached to.
See https://www.paws-r-sdk.com/docs/iam_list_entities_for_policy/ for full documentation.
iam_list_entities_for_policy(
PolicyArn,
EntityFilter = NULL,
PathPrefix = NULL,
PolicyUsageFilter = NULL,
Marker = NULL,
MaxItems = NULL
)
PolicyArn |
[required] The Amazon Resource Name (ARN) of the IAM policy for which you want the versions. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. |
EntityFilter |
The entity type to use for filtering the results. For example, when |
PathPrefix |
The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all entities. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! ( |
PolicyUsageFilter |
The policy usage method to use for filtering the results. To list only permissions policies, set This parameter is optional. If it is not included, all policies are returned. |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.