View source: R/iam_operations.R
| iam_list_policies_granting_service_access | R Documentation |
Retrieves a list of policies that the IAM identity (user, group, or role) can use to access each specified service.
See https://www.paws-r-sdk.com/docs/iam_list_policies_granting_service_access/ for full documentation.
iam_list_policies_granting_service_access(
Marker = NULL,
Arn,
ServiceNamespaces
)
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
Arn |
[required] The ARN of the IAM identity (user, group, or role) whose policies you want to list. |
ServiceNamespaces |
[required] The service namespace for the Amazon Web Services services whose policies you want to list. To learn the service namespace for a service, see Actions, resources, and condition keys for Amazon Web Services services in the IAM User Guide. Choose the name of the service to view details for that service. In the first paragraph, find the service prefix. For example, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.