View source: R/iam_operations.R
| iam_list_policy_versions | R Documentation |
Lists information about the versions of the specified managed policy, including the version that is currently set as the policy's default version.
See https://www.paws-r-sdk.com/docs/iam_list_policy_versions/ for full documentation.
iam_list_policy_versions(PolicyArn, Marker = NULL, MaxItems = NULL)
PolicyArn |
[required] The Amazon Resource Name (ARN) of the IAM policy for which you want the versions. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.