(Optional) Use this only when paginating results to indicate the maximum
number of items that you want in the response. If additional items exist
beyond the maximum that you specify, the IsTruncated response element
is true.
If you do not include this parameter, it defaults to 100. Note that IAM
might return fewer results, even when more results are available. In
that case, the IsTruncated response element returns true, and
Marker contains a value to include in the subsequent call that tells
the service where to continue from.