View source: R/iam_operations.R
| iam_list_server_certificates | R Documentation |
Lists the server certificates stored in IAM that have the specified path prefix. If none exist, the operation returns an empty list.
See https://www.paws-r-sdk.com/docs/iam_list_server_certificates/ for full documentation.
iam_list_server_certificates(PathPrefix = NULL, Marker = NULL, MaxItems = NULL)
PathPrefix |
The path prefix for filtering the results. For example: This parameter is optional. If it is not included, it defaults to a slash (/), listing all server certificates. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! ( |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.