View source: R/iam_operations.R
| iam_list_ssh_public_keys | R Documentation |
Returns information about the SSH public keys associated with the specified IAM user. If none exists, the operation returns an empty list.
See https://www.paws-r-sdk.com/docs/iam_list_ssh_public_keys/ for full documentation.
iam_list_ssh_public_keys(UserName = NULL, Marker = NULL, MaxItems = NULL)
UserName |
The name of the IAM user to list SSH public keys for. If none is specified, the This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@- |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.