View source: R/iam_operations.R
| iam_list_virtual_mfa_devices | R Documentation |
Lists the virtual MFA devices defined in the Amazon Web Services account by assignment status. If you do not specify an assignment status, the operation returns a list of all virtual MFA devices. Assignment status can be Assigned, Unassigned, or Any.
See https://www.paws-r-sdk.com/docs/iam_list_virtual_mfa_devices/ for full documentation.
iam_list_virtual_mfa_devices(
AssignmentStatus = NULL,
Marker = NULL,
MaxItems = NULL
)
AssignmentStatus |
The status ( |
Marker |
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the |
MaxItems |
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.