View source: R/iam_operations.R
| iam_reject_delegation_request | R Documentation |
Rejects a delegation request, denying the requested temporary access.
See https://www.paws-r-sdk.com/docs/iam_reject_delegation_request/ for full documentation.
iam_reject_delegation_request(DelegationRequestId, Notes = NULL)
DelegationRequestId |
[required] The unique identifier of the delegation request to reject. |
Notes |
Optional notes explaining the reason for rejecting the delegation request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.