iam_send_delegation_token: Sends the exchange token for an accepted delegation request

View source: R/iam_operations.R

iam_send_delegation_tokenR Documentation

Sends the exchange token for an accepted delegation request

Description

Sends the exchange token for an accepted delegation request.

See https://www.paws-r-sdk.com/docs/iam_send_delegation_token/ for full documentation.

Usage

iam_send_delegation_token(DelegationRequestId)

Arguments

DelegationRequestId

[required] The unique identifier of the delegation request for which to send the token.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.