View source: R/iam_operations.R
| iam_update_delegation_request | R Documentation |
Updates an existing delegation request with additional information. When the delegation request is updated, it reaches the PENDING_APPROVAL state.
See https://www.paws-r-sdk.com/docs/iam_update_delegation_request/ for full documentation.
iam_update_delegation_request(DelegationRequestId, Notes = NULL)
DelegationRequestId |
[required] The unique identifier of the delegation request to update. |
Notes |
Additional notes or comments to add to the delegation request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.