- UserName
[required] The name of the user whose password you want to update.
This parameter allows (through its regex pattern) a string of characters
consisting of upper and lowercase alphanumeric characters with no
spaces. You can also include any of the following characters: _+=,.@-
- Password
The new password for the specified IAM user.
The regex pattern used to
validate this parameter is a string of characters consisting of the
following:
Any printable ASCII character ranging from the space character
(\u0020) through the end of the ASCII character range
The printable characters in the Basic Latin and Latin-1 Supplement
character set (through \u00FF)
The special characters tab (\u0009), line feed (\u000A), and
carriage return (\u000D)
However, the format can be further restricted by the account
administrator by setting a password policy on the AWS account. For more
information, see
update_account_password_policy.
- PasswordResetRequired
Allows this new password to be used only once by requiring the specified
IAM user to set a new password on next sign-in.