iamrolesanywhere_create_profile: Creates a profile, a list of the roles that Roles Anywhere...

View source: R/iamrolesanywhere_operations.R

iamrolesanywhere_create_profileR Documentation

Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume

Description

Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume. You use profiles to intersect permissions with IAM managed policies.

See https://www.paws-r-sdk.com/docs/iamrolesanywhere_create_profile/ for full documentation.

Usage

iamrolesanywhere_create_profile(
  name,
  requireInstanceProperties = NULL,
  sessionPolicy = NULL,
  roleArns,
  managedPolicyArns = NULL,
  durationSeconds = NULL,
  enabled = NULL,
  tags = NULL,
  acceptRoleSessionName = NULL
)

Arguments

name

[required] The name of the profile.

requireInstanceProperties

Unused, saved for future use. Will likely specify whether instance properties are required in temporary credential requests with this profile.

sessionPolicy

A session policy that applies to the trust boundary of the vended session credentials.

roleArns

[required] A list of IAM roles that this profile can assume in a temporary credential request.

managedPolicyArns

A list of managed policy ARNs that apply to the vended session credentials.

durationSeconds

Used to determine how long sessions vended using this profile are valid for. See the Expiration section of the CreateSession API documentation page for more details. In requests, if this value is not provided, the default value will be 3600.

enabled

Specifies whether the profile is enabled.

tags

The tags to attach to the profile.

acceptRoleSessionName

Used to determine if a custom role session name will be accepted in a temporary credential request.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.