iamrolesanywhere_create_trust_anchor: Creates a trust anchor to establish trust between IAM Roles...

View source: R/iamrolesanywhere_operations.R

iamrolesanywhere_create_trust_anchorR Documentation

Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA)

Description

Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA). You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.

See https://www.paws-r-sdk.com/docs/iamrolesanywhere_create_trust_anchor/ for full documentation.

Usage

iamrolesanywhere_create_trust_anchor(
  name,
  source,
  enabled = NULL,
  tags = NULL,
  notificationSettings = NULL
)

Arguments

name

[required] The name of the trust anchor.

source

[required] The trust anchor type and its related certificate data.

enabled

Specifies whether the trust anchor is enabled.

tags

The tags to attach to the trust anchor.

notificationSettings

A list of notification settings to be associated to the trust anchor.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.