iamrolesanywhere_put_attribute_mapping: Put an entry in the attribute mapping rules that will be...

View source: R/iamrolesanywhere_operations.R

iamrolesanywhere_put_attribute_mappingR Documentation

Put an entry in the attribute mapping rules that will be enforced by a given profile

Description

Put an entry in the attribute mapping rules that will be enforced by a given profile. A mapping specifies a certificate field and one or more specifiers that have contextual meanings.

See https://www.paws-r-sdk.com/docs/iamrolesanywhere_put_attribute_mapping/ for full documentation.

Usage

iamrolesanywhere_put_attribute_mapping(
  profileId,
  certificateField,
  mappingRules
)

Arguments

profileId

[required] The unique identifier of the profile.

certificateField

[required] Fields (x509Subject, x509Issuer and x509SAN) within X.509 certificates.

mappingRules

[required] A list of mapping entries for every supported specifier or sub-field.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.