iamrolesanywhere_update_crl: Updates the certificate revocation list (CRL)

View source: R/iamrolesanywhere_operations.R

iamrolesanywhere_update_crlR Documentation

Updates the certificate revocation list (CRL)

Description

Updates the certificate revocation list (CRL). A CRL is a list of certificates that have been revoked by the issuing certificate authority (CA). IAM Roles Anywhere validates against the CRL before issuing credentials.

See https://www.paws-r-sdk.com/docs/iamrolesanywhere_update_crl/ for full documentation.

Usage

iamrolesanywhere_update_crl(crlId, name = NULL, crlData = NULL)

Arguments

crlId

[required] The unique identifier of the certificate revocation list (CRL).

name

The name of the Crl.

crlData

The x509 v3 specified certificate revocation list (CRL).


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.