iamrolesanywhere_update_trust_anchor: Updates a trust anchor

View source: R/iamrolesanywhere_operations.R

iamrolesanywhere_update_trust_anchorR Documentation

Updates a trust anchor

Description

Updates a trust anchor. You establish trust between IAM Roles Anywhere and your certificate authority (CA) by configuring a trust anchor. You can define a trust anchor as a reference to an Private Certificate Authority (Private CA) or by uploading a CA certificate. Your Amazon Web Services workloads can authenticate with the trust anchor using certificates issued by the CA in exchange for temporary Amazon Web Services credentials.

See https://www.paws-r-sdk.com/docs/iamrolesanywhere_update_trust_anchor/ for full documentation.

Usage

iamrolesanywhere_update_trust_anchor(trustAnchorId, name = NULL, source = NULL)

Arguments

trustAnchorId

[required] The unique identifier of the trust anchor.

name

The name of the trust anchor.

source

The trust anchor type and its related certificate data.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.