View source: R/identitystore_operations.R
| identitystore_create_user | R Documentation |
Creates a user within the specified identity store.
See https://www.paws-r-sdk.com/docs/identitystore_create_user/ for full documentation.
identitystore_create_user(
IdentityStoreId,
UserName = NULL,
Name = NULL,
DisplayName = NULL,
NickName = NULL,
ProfileUrl = NULL,
Emails = NULL,
Addresses = NULL,
PhoneNumbers = NULL,
UserType = NULL,
Title = NULL,
PreferredLanguage = NULL,
Locale = NULL,
Timezone = NULL,
Photos = NULL,
Website = NULL,
Birthdate = NULL,
Roles = NULL,
Extensions = NULL
)
IdentityStoreId |
[required] The globally unique identifier for the identity store. |
UserName |
A unique string used to identify the user. The length limit is 128 characters. This value can consist of letters, accented characters, symbols, numbers, and punctuation. This value is specified at the time the user is created and stored as an attribute of the user object in the identity store. |
Name |
An object containing the name of the user. When used in IAM Identity Center, this parameter is required. |
DisplayName |
A string containing the name of the user. This value is typically formatted for display when the user is referenced. For example, "John Doe." When used in IAM Identity Center, this parameter is required. |
NickName |
A string containing an alternate name for the user. |
ProfileUrl |
A string containing a URL that might be associated with the user. |
Emails |
A list of |
Addresses |
A list of |
PhoneNumbers |
A list of |
UserType |
A string indicating the type of user. Possible values are left unspecified. The value can vary based on your specific use case. |
Title |
A string containing the title of the user. Possible values are left unspecified. The value can vary based on your specific use case. |
PreferredLanguage |
A string containing the preferred language of the user. For example, "American English" or "en-us." |
Locale |
A string containing the geographical region or location of the user. |
Timezone |
A string containing the time zone of the user. |
Photos |
A list of photos associated with the user. You can add up to 3 photos per user. Each photo can include a value, type, display name, and primary designation. |
Website |
The user's personal website or blog URL. This field allows users to provide a link to their personal or professional website. |
Birthdate |
The user's birthdate in YYYY-MM-DD format. This field supports standard date format for storing personal information. |
Roles |
A list of |
Extensions |
A map with additional attribute extensions for the user. Each map key corresponds to an extension name, while map values represent extension data in |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.