identitystore_update_group: Updates the specified group metadata and attributes in the...

View source: R/identitystore_operations.R

identitystore_update_groupR Documentation

Updates the specified group metadata and attributes in the specified identity store

Description

Updates the specified group metadata and attributes in the specified identity store.

See https://www.paws-r-sdk.com/docs/identitystore_update_group/ for full documentation.

Usage

identitystore_update_group(IdentityStoreId, GroupId, Operations)

Arguments

IdentityStoreId

[required] The globally unique identifier for the identity store.

GroupId

[required] The identifier for a group in the identity store.

Operations

[required] A list of AttributeOperation objects to apply to the requested group. These operations might add, replace, or remove an attribute. For more information on the attributes that can be added, replaced, or removed, see Group.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.