identitystore_update_user: Updates the specified user metadata and attributes in the...

View source: R/identitystore_operations.R

identitystore_update_userR Documentation

Updates the specified user metadata and attributes in the specified identity store

Description

Updates the specified user metadata and attributes in the specified identity store.

See https://www.paws-r-sdk.com/docs/identitystore_update_user/ for full documentation.

Usage

identitystore_update_user(IdentityStoreId, UserId, Operations)

Arguments

IdentityStoreId

[required] The globally unique identifier for the identity store.

UserId

[required] The identifier for a user in the identity store.

Operations

[required] A list of AttributeOperation objects to apply to the requested user. These operations might add, replace, or remove an attribute. For more information on the attributes that can be added, replaced, or removed, see User.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.