inspector2_create_code_security_integration: Creates a code security integration with a source code...

View source: R/inspector2_operations.R

inspector2_create_code_security_integrationR Documentation

Creates a code security integration with a source code repository provider

Description

Creates a code security integration with a source code repository provider.

See https://www.paws-r-sdk.com/docs/inspector2_create_code_security_integration/ for full documentation.

Usage

inspector2_create_code_security_integration(
  name,
  type,
  details = NULL,
  tags = NULL
)

Arguments

name

[required] The name of the code security integration.

type

[required] The type of repository provider for the integration.

details

The integration details specific to the repository provider type.

tags

The tags to apply to the code security integration.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.