View source: R/inspector2_operations.R
| inspector2_create_code_security_scan_configuration | R Documentation |
Creates a scan configuration for code security scanning.
See https://www.paws-r-sdk.com/docs/inspector2_create_code_security_scan_configuration/ for full documentation.
inspector2_create_code_security_scan_configuration(
name,
level,
configuration,
scopeSettings = NULL,
tags = NULL
)
name |
[required] The name of the scan configuration. |
level |
[required] The security level for the scan configuration. |
configuration |
[required] The configuration settings for the code security scan. |
scopeSettings |
The scope settings that define which repositories will be scanned. Include this parameter to create a default scan configuration. Otherwise Amazon Inspector creates a general scan configuration. A default scan configuration automatically applies to all existing and future projects imported into Amazon Inspector. Use the |
tags |
The tags to apply to the scan configuration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.