inspector2_create_sbom_export: Creates a software bill of materials (SBOM) report

View source: R/inspector2_operations.R

inspector2_create_sbom_exportR Documentation

Creates a software bill of materials (SBOM) report

Description

Creates a software bill of materials (SBOM) report.

See https://www.paws-r-sdk.com/docs/inspector2_create_sbom_export/ for full documentation.

Usage

inspector2_create_sbom_export(
  resourceFilterCriteria = NULL,
  reportFormat,
  s3Destination
)

Arguments

resourceFilterCriteria

The resource filter criteria for the software bill of materials (SBOM) report.

reportFormat

[required] The output format for the software bill of materials (SBOM) report.

s3Destination

[required] Contains details of the Amazon S3 bucket and KMS key used to export findings.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.