inspector2_enable_delegated_admin_account: Enables the Amazon Inspector delegated administrator for your...

View source: R/inspector2_operations.R

inspector2_enable_delegated_admin_accountR Documentation

Enables the Amazon Inspector delegated administrator for your Organizations organization

Description

Enables the Amazon Inspector delegated administrator for your Organizations organization.

See https://www.paws-r-sdk.com/docs/inspector2_enable_delegated_admin_account/ for full documentation.

Usage

inspector2_enable_delegated_admin_account(
  delegatedAdminAccountId,
  clientToken = NULL
)

Arguments

delegatedAdminAccountId

[required] The Amazon Web Services account ID of the Amazon Inspector delegated administrator.

clientToken

The idempotency token for the request.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.