View source: R/inspector2_operations.R
| inspector2_get_cis_scan_result_details | R Documentation |
Retrieves CIS scan result details.
See https://www.paws-r-sdk.com/docs/inspector2_get_cis_scan_result_details/ for full documentation.
inspector2_get_cis_scan_result_details(
scanArn,
targetResourceId,
accountId,
filterCriteria = NULL,
sortBy = NULL,
sortOrder = NULL,
nextToken = NULL,
maxResults = NULL
)
scanArn |
[required] The scan ARN. |
targetResourceId |
[required] The target resource ID. |
accountId |
[required] The account ID. |
filterCriteria |
The filter criteria. |
sortBy |
The sort by order. |
sortOrder |
The sort order. |
nextToken |
The pagination token from a previous request that's used to retrieve the next page of results. |
maxResults |
The maximum number of CIS scan result details to be returned in a single page of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.