inspector2_get_clusters_for_image: Returns a list of clusters and metadata associated with an...

View source: R/inspector2_operations.R

inspector2_get_clusters_for_imageR Documentation

Returns a list of clusters and metadata associated with an image

Description

Returns a list of clusters and metadata associated with an image.

See https://www.paws-r-sdk.com/docs/inspector2_get_clusters_for_image/ for full documentation.

Usage

inspector2_get_clusters_for_image(filter, maxResults = NULL, nextToken = NULL)

Arguments

filter

[required] The resource Id for the Amazon ECR image.

maxResults

The maximum number of results to be returned in a single page of results.

nextToken

The pagination token from a previous request used to retrieve the next page of results.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.