View source: R/inspector2_operations.R
| inspector2_list_account_permissions | R Documentation |
Lists the permissions an account has to configure Amazon Inspector. If the account is a member account or standalone account with resources managed by an Organizations policy, the operation returns fewer permissions.
See https://www.paws-r-sdk.com/docs/inspector2_list_account_permissions/ for full documentation.
inspector2_list_account_permissions(
service = NULL,
maxResults = NULL,
nextToken = NULL
)
service |
The service scan type to check permissions for. |
maxResults |
The maximum number of results the response can return. If your request would return more than the maximum the response will return a |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. If your response returns more than the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.