inspector2_list_code_securi_scan_config_associ: Lists the associations between code repositories and Amazon...

inspector2_list_code_security_scan_configuration_associationsR Documentation

Lists the associations between code repositories and Amazon Inspector code security scan configurations

Description

Lists the associations between code repositories and Amazon Inspector code security scan configurations.

See https://www.paws-r-sdk.com/docs/inspector2_list_code_security_scan_configuration_associations/ for full documentation.

Usage

inspector2_list_code_security_scan_configuration_associations(
  scanConfigurationArn,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

scanConfigurationArn

[required] The Amazon Resource Name (ARN) of the scan configuration to list associations for.

nextToken

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

maxResults

The maximum number of results to return in the response. If your request would return more than the maximum the response will return a nextToken value, use this value when you call the action again to get the remaining results.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.