inspector2_list_code_security_scan_configurations: Lists all code security scan configurations in your account

View source: R/inspector2_operations.R

inspector2_list_code_security_scan_configurationsR Documentation

Lists all code security scan configurations in your account

Description

Lists all code security scan configurations in your account.

See https://www.paws-r-sdk.com/docs/inspector2_list_code_security_scan_configurations/ for full documentation.

Usage

inspector2_list_code_security_scan_configurations(
  nextToken = NULL,
  maxResults = NULL
)

Arguments

nextToken

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

maxResults

The maximum number of results to return in a single call.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.