View source: R/inspector2_operations.R
| inspector2_list_coverage | R Documentation |
Lists coverage details for your environment.
See https://www.paws-r-sdk.com/docs/inspector2_list_coverage/ for full documentation.
inspector2_list_coverage(
maxResults = NULL,
nextToken = NULL,
filterCriteria = NULL
)
maxResults |
The maximum number of results the response can return. If your request would return more than the maximum the response will return a |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. If your response returns more than the |
filterCriteria |
An object that contains details on the filters to apply to the coverage data for your environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.