View source: R/inspector2_operations.R
| inspector2_list_finding_aggregations | R Documentation |
Lists aggregated finding data for your environment based on specific criteria.
See https://www.paws-r-sdk.com/docs/inspector2_list_finding_aggregations/ for full documentation.
inspector2_list_finding_aggregations(
aggregationType,
nextToken = NULL,
maxResults = NULL,
accountIds = NULL,
aggregationRequest = NULL
)
aggregationType |
[required] The type of the aggregation request. |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. If your response returns more than the |
maxResults |
The maximum number of results the response can return. If your request would return more than the maximum the response will return a |
accountIds |
The Amazon Web Services account IDs to retrieve finding aggregation data for. |
aggregationRequest |
Details of the aggregation request that is used to filter your aggregation results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.