View source: R/inspector2_operations.R
| inspector2_list_usage_totals | R Documentation |
Lists the Amazon Inspector usage totals over the last 30 days.
See https://www.paws-r-sdk.com/docs/inspector2_list_usage_totals/ for full documentation.
inspector2_list_usage_totals(
maxResults = NULL,
nextToken = NULL,
accountIds = NULL
)
maxResults |
The maximum number of results the response can return. If your request would return more than the maximum the response will return a |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. If your response returns more than the |
accountIds |
The Amazon Web Services account IDs to retrieve usage totals for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.