View source: R/inspector2_operations.R
| inspector2_start_code_security_scan | R Documentation |
Initiates a code security scan on a specified repository.
See https://www.paws-r-sdk.com/docs/inspector2_start_code_security_scan/ for full documentation.
inspector2_start_code_security_scan(clientToken = NULL, resource)
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
resource |
[required] The resource identifier for the code repository to scan. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.