View source: R/kms_operations.R
| kms_decrypt | R Documentation |
Decrypts ciphertext that was encrypted by a KMS key using any of the following operations:
See https://www.paws-r-sdk.com/docs/kms_decrypt/ for full documentation.
kms_decrypt(
CiphertextBlob = NULL,
EncryptionContext = NULL,
GrantTokens = NULL,
KeyId = NULL,
EncryptionAlgorithm = NULL,
Recipient = NULL,
DryRun = NULL,
DryRunModifiers = NULL
)
CiphertextBlob |
Ciphertext to be decrypted. The blob includes metadata. This parameter is required in all cases except when |
EncryptionContext |
Specifies the encryption context to use when decrypting the data. An encryption context is valid only for cryptographic operations with a symmetric encryption KMS key. The standard asymmetric encryption algorithms and HMAC algorithms that KMS uses do not support an encryption context. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is supported only on operations with symmetric encryption KMS keys. On operations with symmetric encryption KMS keys, an encryption context is optional, but it is strongly recommended. For more information, see Encryption context in the Key Management Service Developer Guide. |
GrantTokens |
A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide. |
KeyId |
Specifies the KMS key that KMS uses to decrypt the ciphertext. Enter a key ID of the KMS key that was used to encrypt the ciphertext. If you identify a different KMS key, the This parameter is required only when the ciphertext was encrypted under an asymmetric KMS key or when To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with For example:
To get the key ID and key ARN for a KMS key, use |
EncryptionAlgorithm |
Specifies the encryption algorithm that will be used to decrypt the ciphertext. Specify the same algorithm that was used to encrypt the data. If you specify a different algorithm, the This parameter is required only when the ciphertext was encrypted under an asymmetric KMS key. The default value, |
Recipient |
A signed attestation document from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document. The only valid encryption algorithm is This parameter supports the Amazon Web Services Nitro Enclaves SDK or any Amazon Web Services SDK for Amazon Web Services Nitro Enclaves. It supports any Amazon Web Services SDK for Amazon Web Services NitroTPM. When you use this parameter, instead of returning the plaintext data, KMS encrypts the plaintext data with the public key in the attestation document, and returns the resulting ciphertext in the For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide. |
DryRun |
Checks if your request will succeed. To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide. |
DryRunModifiers |
Specifies the modifiers to apply to the dry run operation. When set to To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.