View source: R/kms_operations.R
| kms_derive_shared_secret | R Documentation |
Derives a shared secret using a key agreement algorithm.
See https://www.paws-r-sdk.com/docs/kms_derive_shared_secret/ for full documentation.
kms_derive_shared_secret(
KeyId,
KeyAgreementAlgorithm,
PublicKey,
GrantTokens = NULL,
DryRun = NULL,
Recipient = NULL
)
KeyId |
[required] Identifies an asymmetric NIST-standard ECC or SM2 (China Regions only) KMS key. KMS uses the private key in the specified key pair to derive the shared secret. The key usage of the KMS key must be To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with For example:
To get the key ID and key ARN for a KMS key, use |
KeyAgreementAlgorithm |
[required] Specifies the key agreement algorithm used to derive the shared secret. The only valid value is |
PublicKey |
[required] Specifies the public key in your peer's NIST-standard elliptic curve (ECC) or SM2 (China Regions only) key pair. The public key must be a DER-encoded X.509 public key, also known as
If you use Amazon Web Services CLI version 1, you must provide the DER-encoded X.509 public key in a file. Otherwise, the Amazon Web Services CLI Base64-encodes the public key a second time, resulting in a You can specify the public key as binary data in a file using fileb ( |
GrantTokens |
A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide. |
DryRun |
Checks if your request will succeed. To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide. |
Recipient |
A signed attestation document from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document. The only valid encryption algorithm is This parameter only supports attestation documents for Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM. To call DeriveSharedSecret generate an attestation document use either Amazon Web Services Nitro Enclaves SDK for an Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM tools for Amazon Web Services NitroTPM. Then use the Recipient parameter from any Amazon Web Services SDK to provide the attestation document for the attested environment. When you use this parameter, instead of returning a plaintext copy of the shared secret, KMS encrypts the plaintext shared secret under the public key in the attestation document, and returns the resulting ciphertext in the For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.