View source: R/kms_operations.R
| kms_generate_data_key | R Documentation |
Returns a unique symmetric data key for use outside of KMS. This operation returns a plaintext copy of the data key and a copy that is encrypted under a symmetric encryption KMS key that you specify. The bytes in the plaintext key are random; they are not related to the caller or the KMS key. You can use the plaintext key to encrypt your data outside of KMS and store the encrypted data key with the encrypted data.
See https://www.paws-r-sdk.com/docs/kms_generate_data_key/ for full documentation.
kms_generate_data_key(
KeyId,
EncryptionContext = NULL,
NumberOfBytes = NULL,
KeySpec = NULL,
GrantTokens = NULL,
Recipient = NULL,
DryRun = NULL
)
KeyId |
[required] Specifies the symmetric encryption KMS key that encrypts the data key. You cannot specify an asymmetric KMS key or a KMS key in a custom key store. To get the type and origin of your KMS key, use the To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with For example:
To get the key ID and key ARN for a KMS key, use |
EncryptionContext |
Specifies the encryption context that will be used when encrypting the data key. Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is supported only on operations with symmetric encryption KMS keys. On operations with symmetric encryption KMS keys, an encryption context is optional, but it is strongly recommended. For more information, see Encryption context in the Key Management Service Developer Guide. |
NumberOfBytes |
Specifies the length of the data key in bytes. For example, use the value 64 to generate a 512-bit data key (64 bytes is 512 bits). For 128-bit (16-byte) and 256-bit (32-byte) data keys, use the You must specify either the |
KeySpec |
Specifies the length of the data key. Use You must specify either the |
GrantTokens |
A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token and Using a grant token in the Key Management Service Developer Guide. |
Recipient |
A signed attestation document from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document. The only valid encryption algorithm is This parameter supports the Amazon Web Services Nitro Enclaves SDK or any Amazon Web Services SDK for Amazon Web Services Nitro Enclaves. It supports any Amazon Web Services SDK for Amazon Web Services NitroTPM. When you use this parameter, instead of returning the plaintext data key, KMS encrypts the plaintext data key under the public key in the attestation document, and returns the resulting ciphertext in the For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide. |
DryRun |
Checks if your request will succeed. To learn more about how to use this parameter, see Testing your permissions in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.