View source: R/kms_operations.R
| kms_generate_random | R Documentation |
Returns a random byte string that is cryptographically secure.
See https://www.paws-r-sdk.com/docs/kms_generate_random/ for full documentation.
kms_generate_random(
NumberOfBytes = NULL,
CustomKeyStoreId = NULL,
Recipient = NULL
)
NumberOfBytes |
The length of the random byte string. This parameter is required. |
CustomKeyStoreId |
Generates the random byte string in the CloudHSM cluster that is associated with the specified CloudHSM key store. To find the ID of a custom key store, use the External key store IDs are not valid for this parameter. If you specify the ID of an external key store, |
Recipient |
A signed attestation document from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document. The only valid encryption algorithm is This parameter supports the Amazon Web Services Nitro Enclaves SDK or any Amazon Web Services SDK for Amazon Web Services Nitro Enclaves. It supports any Amazon Web Services SDK for Amazon Web Services NitroTPM. When you use this parameter, instead of returning plaintext bytes, KMS encrypts the plaintext bytes under the public key in the attestation document, and returns the resulting ciphertext in the For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see Cryptographic attestation support in KMS in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.