kms_get_key_last_usage: Returns usage information about the last successful...

View source: R/kms_operations.R

kms_get_key_last_usageR Documentation

Returns usage information about the last successful cryptographic operation performed with a specified KMS key, including the operation type, timestamp, and associated CloudTrail event ID

Description

Returns usage information about the last successful cryptographic operation performed with a specified KMS key, including the operation type, timestamp, and associated CloudTrail event ID.

See https://www.paws-r-sdk.com/docs/kms_get_key_last_usage/ for full documentation.

Usage

kms_get_key_last_usage(KeyId)

Arguments

KeyId

[required] Identifies the KMS key to get usage information for. To specify a KMS key, use its key ID or key ARN. Alias names are not supported.

Specify the key ID or key ARN of the KMS key.

For example:

  • Key ID: ⁠1234abcd-12ab-34cd-56ef-1234567890ab⁠

  • Key ARN: ⁠arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab⁠

To get the key ID and key ARN for a KMS key, use list_keys or describe_key.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.