kms_import_key_material: Imports or reimports key material into an existing KMS key...

View source: R/kms_operations.R

kms_import_key_materialR Documentation

Imports or reimports key material into an existing KMS key that was created without key material

Description

Imports or reimports key material into an existing KMS key that was created without key material. You can also use this operation to set or update the expiration model and expiration date of the imported key material.

See https://www.paws-r-sdk.com/docs/kms_import_key_material/ for full documentation.

Usage

kms_import_key_material(
  KeyId,
  ImportToken,
  EncryptedKeyMaterial,
  ValidTo = NULL,
  ExpirationModel = NULL,
  ImportType = NULL,
  KeyMaterialDescription = NULL,
  KeyMaterialId = NULL
)

Arguments

KeyId

[required] The identifier of the KMS key that will be associated with the imported key material. This must be the same KMS key specified in the KeyID parameter of the corresponding get_parameters_for_import request. The Origin of the KMS key must be EXTERNAL and its KeyState must be PendingImport.

The KMS key can be a symmetric encryption KMS key, HMAC KMS key, asymmetric encryption KMS key, or asymmetric signing KMS key, including a multi-Region key of any supported type. You cannot perform this operation on a KMS key in a custom key store, or on a KMS key in a different Amazon Web Services account.

Specify the key ID or key ARN of the KMS key.

For example:

  • Key ID: ⁠1234abcd-12ab-34cd-56ef-1234567890ab⁠

  • Key ARN: ⁠arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab⁠

To get the key ID and key ARN for a KMS key, use list_keys or describe_key.

ImportToken

[required] The import token that you received in the response to a previous get_parameters_for_import request. It must be from the same response that contained the public key that you used to encrypt the key material.

EncryptedKeyMaterial

[required] The encrypted key material to import. The key material must be encrypted under the public wrapping key that get_parameters_for_import returned, using the wrapping algorithm that you specified in the same get_parameters_for_import request.

ValidTo

The date and time when the imported key material expires. This parameter is required when the value of the ExpirationModel parameter is KEY_MATERIAL_EXPIRES. Otherwise it is not valid.

The value of this parameter must be a future date and time. The maximum value is 365 days from the request date.

When the key material expires, KMS deletes the key material from the KMS key. Without its key material, the KMS key is unusable. To use the KMS key in cryptographic operations, you must reimport the same key material.

You cannot change the ExpirationModel or ValidTo values for the current import after the request completes. To change either value, you must delete (delete_imported_key_material) and reimport the key material.

ExpirationModel

Specifies whether the key material expires. The default is KEY_MATERIAL_EXPIRES. For help with this choice, see Setting an expiration time in the Key Management Service Developer Guide.

When the value of ExpirationModel is KEY_MATERIAL_EXPIRES, you must specify a value for the ValidTo parameter. When value is KEY_MATERIAL_DOES_NOT_EXPIRE, you must omit the ValidTo parameter.

You cannot change the ExpirationModel or ValidTo values for the current import after the request completes. To change either value, you must reimport the key material.

ImportType

Indicates whether the key material being imported is previously associated with this KMS key or not. This parameter is optional and only usable with symmetric encryption keys. If no key material has ever been imported into the KMS key, and this parameter is omitted, the parameter defaults to NEW_KEY_MATERIAL. After the first key material is imported, if this parameter is omitted then the parameter defaults to EXISTING_KEY_MATERIAL.

For multi-Region keys, you must first import new key material into the primary Region key. You should use the NEW_KEY_MATERIAL import type when importing key material into the primary Region key. Then, you can import the same key material into the replica Region key. The import type for the replica Region key should be EXISTING_KEY_MATERIAL.

KeyMaterialDescription

Description for the key material being imported. This parameter is optional and only usable with symmetric encryption keys. If you do not specify a key material description, KMS retains the value you specified when you last imported the same key material into this KMS key.

KeyMaterialId

Identifies the key material being imported. This parameter is optional and only usable with symmetric encryption keys. You cannot specify a key material ID with ImportType set to NEW_KEY_MATERIAL. Whenever you import key material into a symmetric encryption key, KMS assigns a unique identifier to the key material based on the KMS key ID and the imported key material. When you re-import key material with a specified key material ID, KMS:

  • Computes the identifier for the key material

  • Matches the computed identifier against the specified key material ID

  • Verifies that the key material ID is already associated with the KMS key

To get the list of key material IDs associated with a KMS key, use list_key_rotations.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.