View source: R/pcaconnectorad_operations.R
| pcaconnectorad_list_connectors | R Documentation |
Lists the connectors that you created by using the https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector action.
See https://www.paws-r-sdk.com/docs/pcaconnectorad_list_connectors/ for full documentation.
pcaconnectorad_list_connectors(MaxResults = NULL, NextToken = NULL)
MaxResults |
Use this parameter when paginating results to specify the maximum number of items to return in the response on each page. If additional items exist beyond the number you specify, the |
NextToken |
Use this parameter when paginating results in a subsequent request after you receive a response with truncated results. Set it to the value of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.