View source: R/pcaconnectorad_operations.R
| pcaconnectorad_list_templates | R Documentation |
Lists the templates, if any, that are associated with a connector.
See https://www.paws-r-sdk.com/docs/pcaconnectorad_list_templates/ for full documentation.
pcaconnectorad_list_templates(
ConnectorArn,
MaxResults = NULL,
NextToken = NULL
)
ConnectorArn |
[required] The Amazon Resource Name (ARN) that was returned when you called |
MaxResults |
Use this parameter when paginating results to specify the maximum number of items to return in the response on each page. If additional items exist beyond the number you specify, the |
NextToken |
Use this parameter when paginating results in a subsequent request after you receive a response with truncated results. Set it to the value of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.