secretsmanager_stop_replication_to_replica: Removes the link between the replica secret and the primary...

View source: R/secretsmanager_operations.R

secretsmanager_stop_replication_to_replicaR Documentation

Removes the link between the replica secret and the primary secret and promotes the replica to a primary secret in the replica Region

Description

Removes the link between the replica secret and the primary secret and promotes the replica to a primary secret in the replica Region.

See https://www.paws-r-sdk.com/docs/secretsmanager_stop_replication_to_replica/ for full documentation.

Usage

secretsmanager_stop_replication_to_replica(SecretId)

Arguments

SecretId

[required] The name of the secret or the replica ARN. The replica ARN is the same as the original primary secret ARN expect the Region is changed to the replica Region.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.