securityhub_batch_update_standards_control_associations: For a batch of security controls and standards, this...

View source: R/securityhub_operations.R

securityhub_batch_update_standards_control_associationsR Documentation

For a batch of security controls and standards, this operation updates the enablement status of a control in a standard

Description

For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.

See https://www.paws-r-sdk.com/docs/securityhub_batch_update_standards_control_associations/ for full documentation.

Usage

securityhub_batch_update_standards_control_associations(
  StandardsControlAssociationUpdates
)

Arguments

StandardsControlAssociationUpdates

[required] Updates the enablement status of a security control in a specified standard.

Calls to this operation return a RESOURCE_NOT_FOUND_EXCEPTION error when the standard subscription for the control has StandardsControlsUpdatable value NOT_READY_FOR_UPDATES.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.