securityhub_create_aggregator_v2: Enables aggregation across Amazon Web Services Regions

View source: R/securityhub_operations.R

securityhub_create_aggregator_v2R Documentation

Enables aggregation across Amazon Web Services Regions

Description

Enables aggregation across Amazon Web Services Regions.

See https://www.paws-r-sdk.com/docs/securityhub_create_aggregator_v2/ for full documentation.

Usage

securityhub_create_aggregator_v2(
  RegionLinkingMode,
  LinkedRegions = NULL,
  Tags = NULL,
  ClientToken = NULL
)

Arguments

RegionLinkingMode

[required] Determines how Regions are linked to an Aggregator V2.

LinkedRegions

The list of Regions that are linked to the aggregation Region.

Tags

A list of key-value pairs to be applied to the AggregatorV2.

ClientToken

A unique identifier used to ensure idempotency.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.