securityhub_create_members: Creates a member association in Security Hub CSPM between the...

View source: R/securityhub_operations.R

securityhub_create_membersR Documentation

Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account

Description

Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account. If you are integrated with Organizations, then the administrator account is designated by the organization management account.

See https://www.paws-r-sdk.com/docs/securityhub_create_members/ for full documentation.

Usage

securityhub_create_members(AccountDetails)

Arguments

AccountDetails

[required] The list of accounts to associate with the Security Hub CSPM administrator account. For each account, the list includes the account ID and optionally the email address.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.