securityhub_create_ticket_v2: Grants permission to create a ticket in the chosen ITSM based...

View source: R/securityhub_operations.R

securityhub_create_ticket_v2R Documentation

Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID

Description

Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.

See https://www.paws-r-sdk.com/docs/securityhub_create_ticket_v2/ for full documentation.

Usage

securityhub_create_ticket_v2(
  ConnectorId,
  FindingMetadataUid,
  ClientToken = NULL,
  Mode = NULL
)

Arguments

ConnectorId

[required] The UUID of the connectorV2 to identify connectorV2 resource.

FindingMetadataUid

[required] The the unique ID for the finding.

ClientToken

The client idempotency token.

Mode

The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.