View source: R/securityhub_operations.R
| securityhub_decline_invitations | R Documentation |
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts. For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
See https://www.paws-r-sdk.com/docs/securityhub_decline_invitations/ for full documentation.
securityhub_decline_invitations(AccountIds)
AccountIds |
[required] The list of prospective member account IDs for which to decline an invitation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.