securityhub_delete_members: Deletes the specified member accounts from Security Hub CSPM

View source: R/securityhub_operations.R

securityhub_delete_membersR Documentation

Deletes the specified member accounts from Security Hub CSPM

Description

Deletes the specified member accounts from Security Hub CSPM.

See https://www.paws-r-sdk.com/docs/securityhub_delete_members/ for full documentation.

Usage

securityhub_delete_members(AccountIds)

Arguments

AccountIds

[required] The list of account IDs for the member accounts to delete.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.