securityhub_describe_products_v2: Gets information about the product integration

View source: R/securityhub_operations.R

securityhub_describe_products_v2R Documentation

Gets information about the product integration

Description

Gets information about the product integration.

See https://www.paws-r-sdk.com/docs/securityhub_describe_products_v2/ for full documentation.

Usage

securityhub_describe_products_v2(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

MaxResults

The maximum number of results to return.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.