View source: R/securityhub_operations.R
| securityhub_disable_organization_admin_account | R Documentation |
Disables a Security Hub CSPM administrator account. Can only be called by the organization management account.
See https://www.paws-r-sdk.com/docs/securityhub_disable_organization_admin_account/ for full documentation.
securityhub_disable_organization_admin_account(AdminAccountId, Feature = NULL)
AdminAccountId |
[required] The Amazon Web Services account identifier of the Security Hub CSPM administrator account. |
Feature |
The feature for which the delegated admin account is disabled. Defaults to Security Hub CSPM if not specified. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.