View source: R/securityhub_operations.R
| securityhub_disable_security_hub | R Documentation |
Disables Security Hub CSPM in your account only in the current Amazon Web Services Region. To disable Security Hub CSPM in all Regions, you must submit one request per Region where you have enabled Security Hub CSPM.
See https://www.paws-r-sdk.com/docs/securityhub_disable_security_hub/ for full documentation.
securityhub_disable_security_hub()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.