securityhub_disable_security_hub_v2: Disable the service for the current Amazon Web Services...

View source: R/securityhub_operations.R

securityhub_disable_security_hub_v2R Documentation

Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region

Description

Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.

See https://www.paws-r-sdk.com/docs/securityhub_disable_security_hub_v2/ for full documentation.

Usage

securityhub_disable_security_hub_v2()

paws.security.identity documentation built on May 31, 2026, 9:07 a.m.