securityhub_enable_import_findings_for_product: Enables the integration of a partner product with Security Hub
Usage
securityhub_enable_import_findings_for_product(ProductArn)
Arguments
- ProductArn
[required] The ARN of the product to enable the integration for.