securityhub_enable_organization_admin_account: Designates the Security Hub CSPM administrator account for an...

View source: R/securityhub_operations.R

securityhub_enable_organization_admin_accountR Documentation

Designates the Security Hub CSPM administrator account for an organization

Description

Designates the Security Hub CSPM administrator account for an organization. Can only be called by the organization management account.

See https://www.paws-r-sdk.com/docs/securityhub_enable_organization_admin_account/ for full documentation.

Usage

securityhub_enable_organization_admin_account(AdminAccountId, Feature = NULL)

Arguments

AdminAccountId

[required] The Amazon Web Services account identifier of the account to designate as the Security Hub CSPM administrator account.

Feature

The feature for which the delegated admin account is enabled. Defaults to Security Hub CSPM if not specified.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.