View source: R/securityhub_operations.R
| securityhub_enable_security_hub | R Documentation |
Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request.
See https://www.paws-r-sdk.com/docs/securityhub_enable_security_hub/ for full documentation.
securityhub_enable_security_hub(
Tags = NULL,
EnableDefaultStandards = NULL,
ControlFindingGenerator = NULL
)
Tags |
The tags to add to the hub resource when you enable Security Hub CSPM. |
EnableDefaultStandards |
Whether to enable the security standards that Security Hub CSPM has designated as automatically enabled. If you don't provide a value for |
ControlFindingGenerator |
This field, used when enabling Security Hub CSPM, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to If the value for this field is set to The value for this field in a member account matches the value in the administrator account. For accounts that aren't part of an organization, the default value of this field is |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.