securityhub_enable_security_hub_v2: Enables the service in account for the current Amazon Web...

View source: R/securityhub_operations.R

securityhub_enable_security_hub_v2R Documentation

Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region

Description

Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.

See https://www.paws-r-sdk.com/docs/securityhub_enable_security_hub_v2/ for full documentation.

Usage

securityhub_enable_security_hub_v2(Tags = NULL)

Arguments

Tags

The tags to add to the hub V2 resource when you enable Security Hub.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.