View source: R/securityhub_operations.R
| securityhub_get_finding_statistics_v2 | R Documentation |
Returns aggregated statistical data about findings.
See https://www.paws-r-sdk.com/docs/securityhub_get_finding_statistics_v2/ for full documentation.
securityhub_get_finding_statistics_v2(
GroupByRules,
Scopes = NULL,
SortOrder = NULL,
MaxStatisticResults = NULL
)
GroupByRules |
[required] Specifies how security findings should be aggregated and organized in the statistical analysis. It can accept up to 5 |
Scopes |
Limits the results to findings from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own findings. You can specify up to 10 entries in |
SortOrder |
Orders the aggregation count in descending or ascending order. Descending order is the default. |
MaxStatisticResults |
The maximum number of results to be returned. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.