securityhub_get_findings_trends_v2: Returns findings trend data based on the specified criteria

View source: R/securityhub_operations.R

securityhub_get_findings_trends_v2R Documentation

Description

Returns findings trend data based on the specified criteria. This operation helps you analyze patterns and changes in findings over time.

See https://www.paws-r-sdk.com/docs/securityhub_get_findings_trends_v2/ for full documentation.

Usage

securityhub_get_findings_trends_v2(
  Filters = NULL,
  StartTime,
  EndTime,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

Filters

The filters to apply to the findings trend data.

StartTime

[required] The starting timestamp for the time period to analyze findings trends, in ISO 8601 format.

EndTime

[required] The ending timestamp for the time period to analyze findings trends, in ISO 8601 format.

NextToken

The token to use for paginating results. This value is returned in the response if more results are available.

MaxResults

The maximum number of trend data points to return in a single response.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.