securityhub_get_recommended_policy_v2: Retrieves the recommended policy to remediate a Security Hub...

View source: R/securityhub_operations.R

securityhub_get_recommended_policy_v2R Documentation

Description

Retrieves the recommended policy to remediate a Security Hub finding. get_recommended_policy_v2 only supports findings for unused permissions.

See https://www.paws-r-sdk.com/docs/securityhub_get_recommended_policy_v2/ for full documentation.

Usage

securityhub_get_recommended_policy_v2(
  MetadataUid,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

MetadataUid

[required] The unique identifier (ID) of Security Hub OCSF findings found under the metadata.uid field of the finding.

NextToken

The token used to paginate the RecommendationSteps list returned. On your first call to get_recommended_policy_v2, omit this parameter or set it to NULL. For subsequent calls, use the NextToken value returned in the previous response to retrieve the next page of results.

MaxResults

The maximum number of recommendation steps to return.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.