securityhub_get_resources_statistics_v2: Retrieves statistical information about Amazon Web Services...

View source: R/securityhub_operations.R

securityhub_get_resources_statistics_v2R Documentation

Retrieves statistical information about Amazon Web Services resources and their associated security findings

Description

Retrieves statistical information about Amazon Web Services resources and their associated security findings.

See https://www.paws-r-sdk.com/docs/securityhub_get_resources_statistics_v2/ for full documentation.

Usage

securityhub_get_resources_statistics_v2(
  GroupByRules,
  Scopes = NULL,
  SortOrder = NULL,
  MaxStatisticResults = NULL
)

Arguments

GroupByRules

[required] How resource statistics should be aggregated and organized in the response.

Scopes

Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an AccessDeniedException.

This parameter is optional. If you omit it, the delegated administrator sees statistics from all accounts across the entire organization. Other accounts see only statistics for their own resources.

You can specify up to 10 entries in Scopes.AwsOrganizations. If multiple entries are specified, the entries are combined using OR logic.

SortOrder

Sorts aggregated statistics.

MaxStatisticResults

The maximum number of results to be returned.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.