securityhub_list_aggregators_v2: Retrieves a list of V2 aggregators

View source: R/securityhub_operations.R

securityhub_list_aggregators_v2R Documentation

Retrieves a list of V2 aggregators

Description

Retrieves a list of V2 aggregators.

See https://www.paws-r-sdk.com/docs/securityhub_list_aggregators_v2/ for full documentation.

Usage

securityhub_list_aggregators_v2(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

The token required for pagination. On your first call, set the value of this parameter to NULL. For subsequent calls, to continue listing data, set the value of this parameter to the value returned in the previous response.

MaxResults

The maximum number of results to return.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.