View source: R/securityhub_operations.R
| securityhub_list_configuration_policies | R Documentation |
Lists the configuration policies that the Security Hub CSPM delegated administrator has created for your organization. Only the delegated administrator can invoke this operation from the home Region.
See https://www.paws-r-sdk.com/docs/securityhub_list_configuration_policies/ for full documentation.
securityhub_list_configuration_policies(NextToken = NULL, MaxResults = NULL)
NextToken |
The NextToken value that's returned from a previous paginated |
MaxResults |
The maximum number of results that's returned by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.