Learn R Programming

paws.security.identity (version 0.1.5)

securityhub_list_enabled_products_for_import: Lists all findings-generating solutions (products) whose findings you have subscribed to receive in Security Hub

Description

Lists all findings-generating solutions (products) whose findings you have subscribed to receive in Security Hub.

Usage

securityhub_list_enabled_products_for_import(NextToken, MaxResults)

Arguments

NextToken

Paginates results. On your first call to the ListEnabledProductsForImport operation, set the value of this parameter to NULL. For subsequent calls to the operation, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

MaxResults

The maximum number of items that you want in the response.

Request syntax

svc$list_enabled_products_for_import(
  NextToken = "string",
  MaxResults = 123
)