View source: R/securityhub_operations.R
| securityhub_list_organization_admin_accounts | R Documentation |
Lists the Security Hub CSPM administrator accounts. Can only be called by the organization management account.
See https://www.paws-r-sdk.com/docs/securityhub_list_organization_admin_accounts/ for full documentation.
securityhub_list_organization_admin_accounts(
MaxResults = NULL,
NextToken = NULL,
Feature = NULL
)
MaxResults |
The maximum number of items to return in the response. |
NextToken |
The token that is required for pagination. On your first call to the |
Feature |
The feature where the delegated administrator account is listed. Defaults to Security Hub CSPM if not specified. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.