View source: R/securityhub_operations.R
| securityhub_list_security_control_definitions | R Documentation |
Lists all of the security controls that apply to a specified standard.
See https://www.paws-r-sdk.com/docs/securityhub_list_security_control_definitions/ for full documentation.
securityhub_list_security_control_definitions(
StandardsArn = NULL,
NextToken = NULL,
MaxResults = NULL
)
StandardsArn |
The Amazon Resource Name (ARN) of the standard that you want to view controls for. |
NextToken |
Optional pagination parameter. |
MaxResults |
An optional parameter that limits the total results of the API response to the specified number. If this parameter isn't provided in the request, the results include the first 25 security controls that apply to the specified standard. The results also include a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.