Learn R Programming

paws.security.identity (version 0.1.5)

securityhub_list_tags_for_resource: Returns a list of tags associated with a resource

Description

Returns a list of tags associated with a resource.

Usage

securityhub_list_tags_for_resource(ResourceArn)

Arguments

ResourceArn

[required] The ARN of the resource to retrieve tags for.

Request syntax

svc$list_tags_for_resource(
  ResourceArn = "string"
)