securityhub_register_connector_v2: Grants permission to complete the authorization based on...

View source: R/securityhub_operations.R

securityhub_register_connector_v2R Documentation

Grants permission to complete the authorization based on input parameters

Description

Grants permission to complete the authorization based on input parameters.

See https://www.paws-r-sdk.com/docs/securityhub_register_connector_v2/ for full documentation.

Usage

securityhub_register_connector_v2(AuthCode, AuthState)

Arguments

AuthCode

[required] The authCode retrieved from authUrl to complete the OAuth 2.0 authorization code flow.

AuthState

[required] The authState retrieved from authUrl to complete the OAuth 2.0 authorization code flow.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.