securityhub_update_aggregator_v2: Udpates the configuration for the Aggregator V2

View source: R/securityhub_operations.R

securityhub_update_aggregator_v2R Documentation

Udpates the configuration for the Aggregator V2

Description

Udpates the configuration for the Aggregator V2.

See https://www.paws-r-sdk.com/docs/securityhub_update_aggregator_v2/ for full documentation.

Usage

securityhub_update_aggregator_v2(
  AggregatorV2Arn,
  RegionLinkingMode,
  LinkedRegions = NULL
)

Arguments

AggregatorV2Arn

[required] The ARN of the Aggregator V2.

RegionLinkingMode

[required] Determines how Amazon Web Services Regions should be linked to the Aggregator V2.

LinkedRegions

A list of Amazon Web Services Regions linked to the aggegation Region.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.