securityhub_update_automation_rule_v2: Updates a V2 automation rule

View source: R/securityhub_operations.R

securityhub_update_automation_rule_v2R Documentation

Updates a V2 automation rule

Description

Updates a V2 automation rule.

See https://www.paws-r-sdk.com/docs/securityhub_update_automation_rule_v2/ for full documentation.

Usage

securityhub_update_automation_rule_v2(
  Identifier,
  RuleStatus = NULL,
  RuleOrder = NULL,
  Description = NULL,
  RuleName = NULL,
  Criteria = NULL,
  Actions = NULL
)

Arguments

Identifier

[required] The ARN of the automation rule.

RuleStatus

The status of the automation rule.

RuleOrder

Represents a value for the rule priority.

Description

A description of the automation rule.

RuleName

The name of the automation rule.

Criteria

The filtering type and configuration of the automation rule.

Actions

A list of actions to be performed when the rule criteria is met.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.