View source: R/securityhub_operations.R
| securityhub_update_organization_configuration | R Documentation |
Updates the configuration of your organization in Security Hub CSPM. Only the Security Hub CSPM administrator account can invoke this operation.
See https://www.paws-r-sdk.com/docs/securityhub_update_organization_configuration/ for full documentation.
securityhub_update_organization_configuration(
AutoEnable,
AutoEnableStandards = NULL,
OrganizationConfiguration = NULL
)
AutoEnable |
[required] Whether to automatically enable Security Hub CSPM in new member accounts when they join the organization. If set to If the |
AutoEnableStandards |
Whether to automatically enable Security Hub CSPM default standards in new member accounts when they join the organization. The default value of this parameter is equal to If equal to If the |
OrganizationConfiguration |
Provides information about the way an organization is configured in Security Hub CSPM. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.