View source: R/shield_operations.R
| shield_list_resources_in_protection_group | R Documentation |
Retrieves the resources that are included in the protection group.
See https://www.paws-r-sdk.com/docs/shield_list_resources_in_protection_group/ for full documentation.
shield_list_resources_in_protection_group(
ProtectionGroupId,
NextToken = NULL,
MaxResults = NULL
)
ProtectionGroupId |
[required] The name of the protection group. You use this to identify the protection group in lists and to manage the protection group, for example to update, delete, or describe it. |
NextToken |
When you request a list of objects from Shield Advanced, if the response does not include all of the remaining available objects, Shield Advanced includes a You can indicate the maximum number of objects that you want Shield Advanced to return for a single call with the Whenever more objects remain that Shield Advanced has not yet returned to you, the response will include a On your first call to a list operation, leave this setting empty. |
MaxResults |
The greatest number of objects that you want Shield Advanced to return to the list request. Shield Advanced might return fewer objects than you indicate in this setting, even if more objects are available. If there are more objects remaining, Shield Advanced will always also return a The default setting is 20. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.