ssoadmin_add_region: Adds a Region to an IAM Identity Center instance

View source: R/ssoadmin_operations.R

ssoadmin_add_regionR Documentation

Adds a Region to an IAM Identity Center instance

Description

Adds a Region to an IAM Identity Center instance. This operation initiates an asynchronous workflow to replicate the IAM Identity Center instance to the target Region. The Region status is set to ADDING at first and changes to ACTIVE when the workflow completes.

See https://www.paws-r-sdk.com/docs/ssoadmin_add_region/ for full documentation.

Usage

ssoadmin_add_region(InstanceArn, RegionName)

Arguments

InstanceArn

[required] The Amazon Resource Name (ARN) of the IAM Identity Center instance to replicate to the target Region.

RegionName

[required] The name of the Amazon Web Services Region to add to the IAM Identity Center instance. The Region name must be 1-32 characters long and follow the pattern of Amazon Web Services Region names (for example, us-east-1).


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.