ssoadmin_create_application: Creates an OAuth 2

View source: R/ssoadmin_operations.R

ssoadmin_create_applicationR Documentation

Creates an OAuth 2

Description

Creates an OAuth 2.0 customer managed application in IAM Identity Center for the given application provider.

See https://www.paws-r-sdk.com/docs/ssoadmin_create_application/ for full documentation.

Usage

ssoadmin_create_application(
  InstanceArn,
  ApplicationProviderArn,
  Name,
  Description = NULL,
  PortalOptions = NULL,
  Tags = NULL,
  Status = NULL,
  ClientToken = NULL
)

Arguments

InstanceArn

[required] The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

ApplicationProviderArn

[required] The ARN of the application provider under which the operation will run.

Name

[required] The name of the .

Description

The description of the .

PortalOptions

A structure that describes the options for the portal associated with an application.

Tags

Specifies tags to be attached to the application.

Status

Specifies whether the application is enabled or disabled.

ClientToken

Specifies a unique, case-sensitive ID that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value.

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotentParameterMismatch error.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.