View source: R/ssoadmin_operations.R
| ssoadmin_list_account_assignments_for_principal | R Documentation |
Retrieves a list of the IAM Identity Center associated Amazon Web Services accounts that the principal has access to. This action must be called from the management account containing your organization instance of IAM Identity Center. This action is not valid for account instances of IAM Identity Center.
See https://www.paws-r-sdk.com/docs/ssoadmin_list_account_assignments_for_principal/ for full documentation.
ssoadmin_list_account_assignments_for_principal(
InstanceArn,
PrincipalId,
PrincipalType,
Filter = NULL,
NextToken = NULL,
MaxResults = NULL
)
InstanceArn |
[required] Specifies the ARN of the instance of IAM Identity Center that contains the principal. |
PrincipalId |
[required] Specifies the principal for which you want to retrieve the list of account assignments. |
PrincipalType |
[required] Specifies the type of the principal. |
Filter |
Specifies an Amazon Web Services account ID number. Results are filtered to only those that match this ID number. |
NextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
MaxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.