View source: R/ssoadmin_operations.R
| ssoadmin_list_application_assignments_for_principal | R Documentation |
Lists the applications to which a specified principal is assigned. You must provide a filter when calling this action from a member account against your organization instance of IAM Identity Center. A filter is not required when called from the management account against an organization instance of IAM Identity Center, or from a member account against an account instance of IAM Identity Center in the same account.
See https://www.paws-r-sdk.com/docs/ssoadmin_list_application_assignments_for_principal/ for full documentation.
ssoadmin_list_application_assignments_for_principal(
InstanceArn,
PrincipalId,
PrincipalType,
Filter = NULL,
NextToken = NULL,
MaxResults = NULL
)
InstanceArn |
[required] Specifies the instance of IAM Identity Center that contains principal and applications. |
PrincipalId |
[required] Specifies the unique identifier of the principal for which you want to retrieve its assignments. |
PrincipalType |
[required] Specifies the type of the principal for which you want to retrieve its assignments. |
Filter |
Filters the output to include only assignments associated with the application that has the specified ARN. |
NextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
MaxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.