View source: R/ssoadmin_operations.R
| ssoadmin_list_applications | R Documentation |
Lists all applications associated with the instance of IAM Identity Center. When listing applications for an organization instance in the management account, member accounts must use the applicationAccount parameter to filter the list to only applications created from that account. When listing applications for an account instance in the same member account, a filter is not required.
See https://www.paws-r-sdk.com/docs/ssoadmin_list_applications/ for full documentation.
ssoadmin_list_applications(
InstanceArn,
MaxResults = NULL,
NextToken = NULL,
Filter = NULL
)
InstanceArn |
[required] The ARN of the IAM Identity Center application under which the operation will run. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference. |
MaxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the |
NextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
Filter |
Filters response results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.