View source: R/ssoadmin_operations.R
| ssoadmin_list_regions | R Documentation |
Lists all enabled Regions of an IAM Identity Center instance, including those that are being added or removed. This operation returns Regions with ACTIVE, ADDING, or REMOVING status.
See https://www.paws-r-sdk.com/docs/ssoadmin_list_regions/ for full documentation.
ssoadmin_list_regions(InstanceArn, MaxResults = NULL, NextToken = NULL)
InstanceArn |
[required] The Amazon Resource Name (ARN) of the IAM Identity Center instance. |
MaxResults |
The maximum number of results to return in a single call. Default is 100. |
NextToken |
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.