ssoadmin_put_application_access_scope: Adds or updates the list of authorized targets for an IAM...

View source: R/ssoadmin_operations.R

ssoadmin_put_application_access_scopeR Documentation

Adds or updates the list of authorized targets for an IAM Identity Center access scope for an application

Description

Adds or updates the list of authorized targets for an IAM Identity Center access scope for an application.

See https://www.paws-r-sdk.com/docs/ssoadmin_put_application_access_scope/ for full documentation.

Usage

ssoadmin_put_application_access_scope(
  Scope,
  AuthorizedTargets = NULL,
  ApplicationArn
)

Arguments

Scope

[required] Specifies the name of the access scope to be associated with the specified targets.

AuthorizedTargets

Specifies an array list of ARNs that represent the authorized targets for this access scope.

ApplicationArn

[required] Specifies the ARN of the application with the access scope with the targets to add or update.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.