ssoadmin_put_application_grant: Creates a configuration for an application to use grants

View source: R/ssoadmin_operations.R

ssoadmin_put_application_grantR Documentation

Creates a configuration for an application to use grants

Description

Creates a configuration for an application to use grants. Conceptually grants are authorization to request actions related to tokens. This configuration will be used when parties are requesting and receiving tokens during the trusted identity propagation process. For more information on the IAM Identity Center supported grant workflows, see SAML 2.0 and OAuth 2.0.

See https://www.paws-r-sdk.com/docs/ssoadmin_put_application_grant/ for full documentation.

Usage

ssoadmin_put_application_grant(ApplicationArn, GrantType, Grant)

Arguments

ApplicationArn

[required] Specifies the ARN of the application to update.

GrantType

[required] Specifies the type of grant to update.

Grant

[required] Specifies a structure that describes the grant to update.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.