sts_get_delegated_access_token: Exchanges a trade-in token for temporary Amazon Web Services...

View source: R/sts_operations.R

sts_get_delegated_access_tokenR Documentation

Exchanges a trade-in token for temporary Amazon Web Services credentials with the permissions associated with the assumed principal

Description

Exchanges a trade-in token for temporary Amazon Web Services credentials with the permissions associated with the assumed principal. This operation allows you to obtain credentials for a specific principal based on a trade-in token, enabling delegation of access to Amazon Web Services resources.

See https://www.paws-r-sdk.com/docs/sts_get_delegated_access_token/ for full documentation.

Usage

sts_get_delegated_access_token(TradeInToken)

Arguments

TradeInToken

[required] The token to exchange for temporary Amazon Web Services credentials. This token must be valid and unexpired at the time of the request.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.