View source: R/verifiedpermissions_operations.R
| verifiedpermissions_batch_is_authorized_with_token | R Documentation |
Makes a series of decisions about multiple authorization requests for one token. The principal in this request comes from an external identity source in the form of an identity or access token, formatted as a JSON web token (JWT). The information in the parameters can also define additional context that Verified Permissions can include in the evaluations.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_batch_is_authorized_with_token/ for full documentation.
verifiedpermissions_batch_is_authorized_with_token(
policyStoreId,
identityToken = NULL,
accessToken = NULL,
entities = NULL,
requests
)
policyStoreId |
[required] Specifies the ID of the policy store. Policies in this policy store will be used to make an authorization decision for the input. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
identityToken |
Specifies an identity (ID) token for the principal that you want to authorize in each request. This token is provided to you by the identity provider (IdP) associated with the specified identity source. You must specify either an Must be an ID token. Verified Permissions returns an error if the |
accessToken |
Specifies an access token for the principal that you want to authorize in each request. This token is provided to you by the identity provider (IdP) associated with the specified identity source. You must specify either an Must be an access token. Verified Permissions returns an error if the |
entities |
(Optional) Specifies the list of resources and their associated attributes that Verified Permissions can examine when evaluating the policies. These additional entities and their attributes can be referenced and checked by conditional elements in the policies in the specified policy store. You can't include principals in this parameter, only resource and action entities. This parameter can't include any entities of a type that matches the user or group entity types that you defined in your identity source.
|
requests |
[required] An array of up to 30 requests that you want Verified Permissions to evaluate. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.