verifiedpermissions_create_policy_store_alias: Creates a policy store alias for the specified policy store

View source: R/verifiedpermissions_operations.R

verifiedpermissions_create_policy_store_aliasR Documentation

Creates a policy store alias for the specified policy store

Description

Creates a policy store alias for the specified policy store. A policy store alias is an alternative identifier that you can use to reference a policy store in API operations.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_create_policy_store_alias/ for full documentation.

Usage

verifiedpermissions_create_policy_store_alias(aliasName, policyStoreId)

Arguments

aliasName

[required] Specifies the name of the policy store alias to create. The name must be unique within your Amazon Web Services account and Amazon Web Services Region.

The alias name must always be prefixed with ⁠policy-store-alias/⁠.

policyStoreId

[required] Specifies the ID of the policy store to associate with the alias.

The associated policy store must be specified using its ID. The alias name cannot be used.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.