verifiedpermissions_delete_policy: Deletes the specified policy from the policy store

View source: R/verifiedpermissions_operations.R

verifiedpermissions_delete_policyR Documentation

Deletes the specified policy from the policy store

Description

Deletes the specified policy from the policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy/ for full documentation.

Usage

verifiedpermissions_delete_policy(policyStoreId, policyId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that contains the policy that you want to delete.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.

policyId

[required] Specifies the ID of the policy that you want to delete.

You can use the policy name in place of the policy ID. When using a name, prefix it with ⁠name/⁠. For example:

  • ID: SPEXAMPLEabcdefg111111

  • Name: name/example-policy


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.