verifiedpermissions_delete_policy_store: Deletes the specified policy store

View source: R/verifiedpermissions_operations.R

verifiedpermissions_delete_policy_storeR Documentation

Deletes the specified policy store

Description

Deletes the specified policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy_store/ for full documentation.

Usage

verifiedpermissions_delete_policy_store(policyStoreId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that you want to delete.

To specify a policy store, the alias name cannot be used. Only the ID can be used.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.