verifiedpermissions_delete_policy_store_alias: Deletes the specified policy store alias

View source: R/verifiedpermissions_operations.R

verifiedpermissions_delete_policy_store_aliasR Documentation

Deletes the specified policy store alias

Description

Deletes the specified policy store alias.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy_store_alias/ for full documentation.

Usage

verifiedpermissions_delete_policy_store_alias(aliasName, deletionMode = NULL)

Arguments

aliasName

[required] Specifies the name of the policy store alias that you want to delete.

The alias name must always be prefixed with ⁠policy-store-alias/⁠.

deletionMode

Specifies the deletion mode for the policy store alias. The valid values are:

  • SoftDelete – The policy store alias enters the PendingDeletion state. This is the default behavior when no deletionMode is specified.

  • HardDelete – The policy store alias is immediately deleted, bypassing the PendingDeletion state.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.