verifiedpermissions_delete_policy_template: Deletes the specified policy template from the policy store

View source: R/verifiedpermissions_operations.R

verifiedpermissions_delete_policy_templateR Documentation

Deletes the specified policy template from the policy store

Description

Deletes the specified policy template from the policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy_template/ for full documentation.

Usage

verifiedpermissions_delete_policy_template(policyStoreId, policyTemplateId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that contains the policy template that you want to delete.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.

policyTemplateId

[required] Specifies the ID of the policy template that you want to delete.

You can use the policy template name in place of the policy template ID. When using a name, prefix it with ⁠name/⁠. For example:

  • ID: PTEXAMPLEabcdefg111111

  • Name: name/example-policy-template


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.