verifiedpermissions_get_identity_source: Retrieves the details about the specified identity source

View source: R/verifiedpermissions_operations.R

verifiedpermissions_get_identity_sourceR Documentation

Retrieves the details about the specified identity source

Description

Retrieves the details about the specified identity source.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_identity_source/ for full documentation.

Usage

verifiedpermissions_get_identity_source(policyStoreId, identitySourceId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that contains the identity source you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.

identitySourceId

[required] Specifies the ID of the identity source you want information about.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.