View source: R/verifiedpermissions_operations.R
| verifiedpermissions_get_policy | R Documentation |
Retrieves information about the specified policy.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_policy/ for full documentation.
verifiedpermissions_get_policy(policyStoreId, policyId)
policyStoreId |
[required] Specifies the ID of the policy store that contains the policy that you want information about. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
policyId |
[required] Specifies the ID of the policy you want information about. You can use the policy name in place of the policy ID. When using a name, prefix it with
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.