View source: R/verifiedpermissions_operations.R
| verifiedpermissions_get_policy_store | R Documentation |
Retrieves details about a policy store.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_policy_store/ for full documentation.
verifiedpermissions_get_policy_store(policyStoreId, tags = NULL)
policyStoreId |
[required] Specifies the policy store that you want information about. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
tags |
Specifies whether to return the tags that are attached to the policy store. If this parameter is included in the API call, the tags are returned, otherwise they are not returned. If this parameter is included in the API call but there are no tags attached to the policy store, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.