verifiedpermissions_get_policy_store_alias: Retrieves details about the specified policy store alias

View source: R/verifiedpermissions_operations.R

verifiedpermissions_get_policy_store_aliasR Documentation

Retrieves details about the specified policy store alias

Description

Retrieves details about the specified policy store alias.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_policy_store_alias/ for full documentation.

Usage

verifiedpermissions_get_policy_store_alias(aliasName)

Arguments

aliasName

[required] Specifies the name of the policy store alias that you want information about.

The alias name must always be prefixed with ⁠policy-store-alias/⁠.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.