verifiedpermissions_get_policy_template: Retrieve the details for the specified policy template in the...

View source: R/verifiedpermissions_operations.R

verifiedpermissions_get_policy_templateR Documentation

Retrieve the details for the specified policy template in the specified policy store

Description

Retrieve the details for the specified policy template in the specified policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_policy_template/ for full documentation.

Usage

verifiedpermissions_get_policy_template(policyStoreId, policyTemplateId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that contains the policy template that you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.

policyTemplateId

[required] Specifies the ID of the policy template that you want information about.

You can use the policy template name in place of the policy template ID. When using a name, prefix it with ⁠name/⁠. For example:

  • ID: PTEXAMPLEabcdefg111111

  • Name: name/example-policy-template


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.