verifiedpermissions_get_schema: Retrieve the details for the specified schema in the...

View source: R/verifiedpermissions_operations.R

verifiedpermissions_get_schemaR Documentation

Retrieve the details for the specified schema in the specified policy store

Description

Retrieve the details for the specified schema in the specified policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_schema/ for full documentation.

Usage

verifiedpermissions_get_schema(policyStoreId)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that contains the schema.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.