View source: R/verifiedpermissions_operations.R
| verifiedpermissions_list_identity_sources | R Documentation |
Returns a paginated list of all of the identity sources defined in the specified policy store.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_list_identity_sources/ for full documentation.
verifiedpermissions_list_identity_sources(
policyStoreId,
nextToken = NULL,
maxResults = NULL,
filters = NULL
)
policyStoreId |
[required] Specifies the ID of the policy store that contains the identity sources that you want to list. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
nextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
maxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the If you do not specify this parameter, the operation defaults to 10 identity sources per response. You can specify a maximum of 50 identity sources per response. |
filters |
Specifies characteristics of an identity source that you can use to limit the output to matching identity sources. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.