View source: R/verifiedpermissions_operations.R
| verifiedpermissions_list_policy_store_aliases | R Documentation |
Returns a paginated list of all policy store aliases in the calling Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_list_policy_store_aliases/ for full documentation.
verifiedpermissions_list_policy_store_aliases(
nextToken = NULL,
maxResults = NULL,
filter = NULL
)
nextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
maxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the If you do not specify this parameter, the operation defaults to 5 policy store aliases per response. You can specify a maximum of 50 policy store aliases per response. |
filter |
Specifies a filter to narrow the results. You can filter by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.