View source: R/verifiedpermissions_operations.R
| verifiedpermissions_list_policy_templates | R Documentation |
Returns a paginated list of all policy templates in the specified policy store.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_list_policy_templates/ for full documentation.
verifiedpermissions_list_policy_templates(
policyStoreId,
nextToken = NULL,
maxResults = NULL
)
policyStoreId |
[required] Specifies the ID of the policy store that contains the policy templates you want to list. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
nextToken |
Specifies that you want to receive the next page of results. Valid only if you received a |
maxResults |
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the If you do not specify this parameter, the operation defaults to 10 policy templates per response. You can specify a maximum of 50 policy templates per response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.