verifiedpermissions_untag_resource: Removes one or more tags from the specified Amazon Verified...

View source: R/verifiedpermissions_operations.R

verifiedpermissions_untag_resourceR Documentation

Removes one or more tags from the specified Amazon Verified Permissions resource

Description

Removes one or more tags from the specified Amazon Verified Permissions resource. In Verified Permissions, policy stores can be tagged.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_untag_resource/ for full documentation.

Usage

verifiedpermissions_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] The ARN of the resource from which you are removing tags.

tagKeys

[required] The list of tag keys to remove from the resource.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.