View source: R/verifiedpermissions_operations.R
| verifiedpermissions_update_policy | R Documentation |
Modifies a Cedar static policy in the specified policy store. You can change only certain elements of the UpdatePolicyDefinition parameter. You can directly update only static policies. To change a template-linked policy, you must update the template instead, using update_policy_template.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_update_policy/ for full documentation.
verifiedpermissions_update_policy(
policyStoreId,
policyId,
definition = NULL,
name = NULL
)
policyStoreId |
[required] Specifies the ID of the policy store that contains the policy that you want to update. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
policyId |
[required] Specifies the ID of the policy that you want to update. To find this value, you can use You can use the policy name in place of the policy ID. When using a name, prefix it with
|
definition |
Specifies the updated policy content that you want to replace on the specified policy. The content must be valid Cedar policy language text. If you don't specify this parameter, the existing policy definition remains unchanged. You can change only the following elements from the policy definition:
You can't change the following elements:
|
name |
Specifies a name for the policy that is unique among all policies within the policy store. You can use the name in place of the policy ID in API operations that reference the policy. The name must be prefixed with If you don't include the name in an update request, the existing name is unchanged. To remove a name, set it to an empty string ( If you specify a name that is already associated with another policy in the policy store, you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.