verifiedpermissions_update_policy_store: Modifies the validation setting for a policy store

View source: R/verifiedpermissions_operations.R

verifiedpermissions_update_policy_storeR Documentation

Modifies the validation setting for a policy store

Description

Modifies the validation setting for a policy store.

See https://www.paws-r-sdk.com/docs/verifiedpermissions_update_policy_store/ for full documentation.

Usage

verifiedpermissions_update_policy_store(
  policyStoreId,
  validationSettings,
  deletionProtection = NULL,
  description = NULL
)

Arguments

policyStoreId

[required] Specifies the ID of the policy store that you want to update

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ⁠policy-store-alias/⁠. For example:

  • ID: PSEXAMPLEabcdefg111111

  • Alias name: policy-store-alias/example-policy-store

To view aliases, use list_policy_store_aliases.

validationSettings

[required] A structure that defines the validation settings that want to enable for the policy store.

deletionProtection

Specifies whether the policy store can be deleted. If enabled, the policy store can't be deleted.

When you call update_policy_store, this parameter is unchanged unless explicitly included in the call.

description

Descriptive text that you can provide to help with identification of the current policy store.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.