View source: R/verifiedpermissions_operations.R
| verifiedpermissions_update_policy_template | R Documentation |
Updates the specified policy template. You can update only the description and the some elements of the policyBody.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_update_policy_template/ for full documentation.
verifiedpermissions_update_policy_template(
policyStoreId,
policyTemplateId,
description = NULL,
statement,
name = NULL
)
policyStoreId |
[required] Specifies the ID of the policy store that contains the policy template that you want to update. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
policyTemplateId |
[required] Specifies the ID of the policy template that you want to update. You can use the policy template name in place of the policy template ID. When using a name, prefix it with
|
description |
Specifies a new description to apply to the policy template. |
statement |
[required] Specifies new statement content written in Cedar policy language to replace the current body of the policy template. You can change only the following elements of the policy body:
You can't change the following elements:
|
name |
Specifies a name for the policy template that is unique among all policy templates within the policy store. You can use the name in place of the policy template ID in API operations that reference the policy template. The name must be prefixed with If you don't include the name in an update request, the existing name is unchanged. To remove a name, set it to an empty string ( If you specify a name that is already associated with another policy template in the policy store, you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.