wafv2_get_web_acl: Retrieves the specified WebACL

View source: R/wafv2_operations.R

wafv2_get_web_aclR Documentation

Retrieves the specified WebACL

Description

Retrieves the specified WebACL.

See https://www.paws-r-sdk.com/docs/wafv2_get_web_acl/ for full documentation.

Usage

wafv2_get_web_acl(Name = NULL, Scope = NULL, Id = NULL, ARN = NULL)

Arguments

Name

The name of the web ACL. You cannot change the name of a web ACL after you create it.

Scope

Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Id

The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

ARN

The Amazon Resource Name (ARN) of the web ACL that you want to retrieve.


paws.security.identity documentation built on May 31, 2026, 9:07 a.m.