View source: R/acm_operations.R
| acm_create_acme_domain_validation | R Documentation |
Creates a domain validation for an ACME endpoint. Domain validations authorize the endpoint to issue certificates for specified domain names. You configure prevalidation to prove domain ownership.
See https://www.paws-r-sdk.com/docs/acm_create_acme_domain_validation/ for full documentation.
acm_create_acme_domain_validation(
IdempotencyToken = NULL,
AcmeEndpointArn,
DomainName,
PrevalidationOptions,
Tags = NULL
)
IdempotencyToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
AcmeEndpointArn |
[required] The Amazon Resource Name (ARN) of the ACME endpoint. |
DomainName |
[required] The domain name to validate. |
PrevalidationOptions |
[required] The prevalidation options for the domain. |
Tags |
One or more tags to associate with the domain validation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.