View source: R/acm_operations.R
| acm_create_acme_endpoint | R Documentation |
Creates an ACME endpoint, which is a managed ACME server with a unique endpoint URL. After creation, ACME clients can use the endpoint URL to automate certificate issuance using the ACME protocol.
See https://www.paws-r-sdk.com/docs/acm_create_acme_endpoint/ for full documentation.
acm_create_acme_endpoint(
IdempotencyToken = NULL,
AuthorizationBehavior,
Contact = NULL,
CertificateAuthority,
Tags = NULL,
CertificateTags = NULL
)
IdempotencyToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
AuthorizationBehavior |
[required] The authorization behavior for the ACME endpoint. |
Contact |
Specifies whether ACME clients must provide contact information during account registration. |
CertificateAuthority |
[required] The type of certificate authority to use for issuing certificates through this ACME endpoint. |
Tags |
One or more tags to associate with the ACME endpoint. |
CertificateTags |
Tags to apply to certificates issued through this ACME endpoint. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.