View source: R/acm_operations.R
| acm_create_acme_external_account_binding | R Documentation |
Creates an external account binding (EAB) for an ACME endpoint. An EAB provides credentials that authorize an ACME client to register an account with the endpoint. Each EAB is associated with an IAM role that controls what certificate operations the ACME client can perform.
See https://www.paws-r-sdk.com/docs/acm_create_acme_external_account_binding/ for full documentation.
acm_create_acme_external_account_binding(
IdempotencyToken = NULL,
AcmeEndpointArn,
RoleArn,
Expiration = NULL,
Tags = NULL
)
IdempotencyToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
AcmeEndpointArn |
[required] The Amazon Resource Name (ARN) of the ACME endpoint. |
RoleArn |
[required] The Amazon Resource Name (ARN) of the IAM role to associate with the external account binding. |
Expiration |
The expiration configuration for the external account binding. |
Tags |
One or more tags to associate with the external account binding. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.