View source: R/acm_operations.R
| acm_export_certificate | R Documentation |
Exports a private certificate issued by a private certificate authority (CA) or a public certificate for use anywhere. The exported file contains the certificate, the certificate chain, and the encrypted private key associated with the public key that is embedded in the certificate. For security, you must assign a passphrase for the private key when exporting it.
See https://www.paws-r-sdk.com/docs/acm_export_certificate/ for full documentation.
acm_export_certificate(CertificateArn, Passphrase)
CertificateArn |
[required] An Amazon Resource Name (ARN) of the issued certificate. This must be of the form:
|
Passphrase |
[required] Passphrase to associate with the encrypted exported private key. When creating your passphrase, you can use any ASCII character except #, $, or %. If you want to later decrypt the private key, you must have the passphrase. You can use the following OpenSSL command to decrypt a private key. After entering the command, you are prompted for the passphrase.
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.