View source: R/acm_operations.R
| acm_revoke_acme_external_account_binding | R Documentation |
Revokes an external account binding, preventing new ACME accounts from being registered using this binding. Existing ACME accounts that were previously registered using the binding are not affected and must be revoked separately.
See https://www.paws-r-sdk.com/docs/acm_revoke_acme_external_account_binding/ for full documentation.
acm_revoke_acme_external_account_binding(AcmeExternalAccountBindingArn)
AcmeExternalAccountBindingArn |
[required] The Amazon Resource Name (ARN) of the ACME external account binding to revoke. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.