View source: R/acm_operations.R
| acm_revoke_certificate | R Documentation |
Revokes a public ACM certificate. You can only revoke certificates that have been previously exported.
See https://www.paws-r-sdk.com/docs/acm_revoke_certificate/ for full documentation.
acm_revoke_certificate(CertificateArn, RevocationReason)
CertificateArn |
[required] The Amazon Resource Name (ARN) of the public or private certificate that will be revoked. The ARN must have the following form:
|
RevocationReason |
[required] Specifies why you revoked the certificate. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.