View source: R/acm_operations.R
| acm_tag_resource | R Documentation |
Adds one or more tags to an ACM resource. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a key and an optional value.
See https://www.paws-r-sdk.com/docs/acm_tag_resource/ for full documentation.
acm_tag_resource(ResourceArn, Tags)
ResourceArn |
[required] The ARN of the ACM resource to which the tag is to be applied. |
Tags |
[required] The key-value pair that defines the tag to apply. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.