View source: R/cleanroomsml_operations.R
| cleanroomsml_cancel_trained_model | R Documentation |
Submits a request to cancel the trained model job.
See https://www.paws-r-sdk.com/docs/cleanroomsml_cancel_trained_model/ for full documentation.
cleanroomsml_cancel_trained_model(
membershipIdentifier,
trainedModelArn,
versionIdentifier = NULL
)
membershipIdentifier |
[required] The membership ID of the trained model job that you want to cancel. |
trainedModelArn |
[required] The Amazon Resource Name (ARN) of the trained model job that you want to cancel. |
versionIdentifier |
The version identifier of the trained model to cancel. This parameter allows you to specify which version of the trained model you want to cancel when multiple versions exist. If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.