View source: R/cleanroomsml_operations.R
| cleanroomsml_delete_trained_model_output | R Documentation |
Deletes the model artifacts stored by the service.
See https://www.paws-r-sdk.com/docs/cleanroomsml_delete_trained_model_output/ for full documentation.
cleanroomsml_delete_trained_model_output(
trainedModelArn,
membershipIdentifier,
versionIdentifier = NULL
)
trainedModelArn |
[required] The Amazon Resource Name (ARN) of the trained model whose output you want to delete. |
membershipIdentifier |
[required] The membership ID of the member that is deleting the trained model output. |
versionIdentifier |
The version identifier of the trained model to delete. If not specified, the operation will delete the base version of the trained model. When specified, only the particular version will be deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.