cognitoidentity_describe_identity: Returns metadata related to the given identity, including when the
identity was created and any associated linked logins
Description
Returns metadata related to the given identity, including when the
identity was created and any associated linked logins.
You must use AWS Developer credentials to call this API.
Usage
cognitoidentity_describe_identity(IdentityId)
Arguments
IdentityId
[required] A unique identifier in the format REGION:GUID.