cognitoidentity_list_identity_pools: Lists all of the Cognito identity pools registered for your account
Description
Lists all of the Cognito identity pools registered for your account.
You must use AWS Developer credentials to call this API.
Usage
cognitoidentity_list_identity_pools(MaxResults, NextToken)
Arguments
MaxResults
[required] The maximum number of identities to return.
Request syntax
svc$list_identity_pools(
MaxResults = 123,
NextToken = "string"
)