View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_get_user | R Documentation |
Given a username, returns details about a user profile in a user pool. You can specify alias attributes in the Username request parameter.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_get_user/ for full documentation.
cognitoidentityprovider_admin_get_user(UserPoolId, Username)
UserPoolId |
[required] The ID of the user pool where you want to get information about the user. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.