View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_admin_update_auth_event_feedback | R Documentation |
Provides the feedback for an authentication event generated by threat protection features. Your response indicates that you think that the event either was from a valid user or was an unwanted authentication attempt. This feedback improves the risk evaluation decision for the user pool as part of Amazon Cognito threat protection. To activate this setting, your user pool must be on the Plus tier.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_admin_update_auth_event_feedback/ for full documentation.
cognitoidentityprovider_admin_update_auth_event_feedback(
UserPoolId,
Username,
EventId,
FeedbackValue
)
UserPoolId |
[required] The ID of the user pool where you want to submit authentication-event feedback. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
EventId |
[required] The ID of the threat protection authentication event that you want to update. |
FeedbackValue |
[required] Your feedback to the authentication event. When you provide a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.