View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_create_terms | R Documentation |
Creates terms documents for the requested app client. When Terms and conditions and Privacy policy documents are configured, the app client displays links to them in the sign-up page of managed login for the app client.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_create_terms/ for full documentation.
cognitoidentityprovider_create_terms(
UserPoolId,
ClientId,
TermsName,
TermsSource,
Enforcement,
Links = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to create terms documents. |
ClientId |
[required] The ID of the app client where you want to create terms documents. Must be an app client in the requested user pool. |
TermsName |
[required] A friendly name for the document that you want to create in the current request. Must begin with |
TermsSource |
[required] This parameter is reserved for future use and currently accepts only one value. |
Enforcement |
[required] This parameter is reserved for future use and currently accepts only one value. |
Links |
A map of URLs to languages. For each localized language that will view the requested For example, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.