View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_delete_terms | R Documentation |
Deletes the terms documents with the requested ID from your app client.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_terms/ for full documentation.
cognitoidentityprovider_delete_terms(TermsId, UserPoolId)
TermsId |
[required] The ID of the terms documents that you want to delete. |
UserPoolId |
[required] The ID of the user pool that contains the terms documents that you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.