View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_delete_user | R Documentation |
Deletes the profile of the currently signed-in user. A deleted user profile can no longer be used to sign in and can't be restored.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_user/ for full documentation.
cognitoidentityprovider_delete_user(AccessToken)
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.