View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_delete_user_pool_client_secret | R Documentation |
Deletes a specific client secret from a user pool app client. You cannot delete the last remaining secret for an app client.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_delete_user_pool_client_secret/ for full documentation.
cognitoidentityprovider_delete_user_pool_client_secret(
UserPoolId,
ClientId,
ClientSecretId
)
UserPoolId |
[required] The ID of the user pool that contains the app client. |
ClientId |
[required] The ID of the app client from which you want to delete the secret. |
ClientSecretId |
[required] The unique identifier of the client secret you want to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.