View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_describe_terms | R Documentation |
Returns details for the requested terms documents ID. For more information, see Terms documents.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_describe_terms/ for full documentation.
cognitoidentityprovider_describe_terms(TermsId, UserPoolId)
TermsId |
[required] The ID of the terms documents that you want to describe. |
UserPoolId |
[required] The ID of the user pool that contains the terms documents that you want to describe. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.