View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_forget_device | R Documentation |
Given a device key, deletes a remembered device as the currently signed-in user. For more information about device authentication, see Working with user devices in your user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_forget_device/ for full documentation.
cognitoidentityprovider_forget_device(AccessToken = NULL, DeviceKey)
AccessToken |
A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
DeviceKey |
[required] The unique identifier, or device key, of the device that the user wants to forget. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.