View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_csv_header | R Documentation |
Given a user pool ID, generates a comma-separated value (CSV) list populated with available user attributes in the user pool. This list is the header for the CSV file that determines the users in a user import job. Save the content of CSVHeader in the response as a .csv file and populate it with the usernames and attributes of users that you want to import. For more information about CSV user import, see Importing users from a CSV file.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_csv_header/ for full documentation.
cognitoidentityprovider_get_csv_header(UserPoolId)
UserPoolId |
[required] The ID of the user pool that you want to import users into. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.