View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_group | R Documentation |
Given a user pool ID and a group name, returns information about the user group.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_group/ for full documentation.
cognitoidentityprovider_get_group(GroupName, UserPoolId)
GroupName |
[required] The name of the group that you want to get information about. |
UserPoolId |
[required] The ID of the user pool that contains the group that you want to query. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.