View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_log_delivery_configuration | R Documentation |
Given a user pool ID, returns the logging configuration. User pools can export message-delivery error and threat-protection activity logs to external Amazon Web Services services. For more information, see Exporting user pool logs.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_log_delivery_configuration/ for full documentation.
cognitoidentityprovider_get_log_delivery_configuration(UserPoolId)
UserPoolId |
[required] The ID of the user pool that has the logging configuration that you want to view. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.