View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_ui_customization | R Documentation |
Given a user pool ID or app client, returns information about classic hosted UI branding that you applied, if any. Returns user-pool level branding information if no app client branding is applied, or if you don't specify an app client ID. Returns an empty object if you haven't applied hosted UI branding to either the client or the user pool. For more information, see Hosted UI (classic) branding.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_ui_customization/ for full documentation.
cognitoidentityprovider_get_ui_customization(UserPoolId, ClientId = NULL)
UserPoolId |
[required] The ID of the user pool that you want to query for branding settings. |
ClientId |
The ID of the app client that you want to query for branding settings. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.