View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_get_user_attribute_verification_code | R Documentation |
Given an attribute name, sends a user attribute verification code for the specified attribute name to the currently signed-in user.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_get_user_attribute_verification_code/ for full documentation.
cognitoidentityprovider_get_user_attribute_verification_code(
AccessToken,
AttributeName,
ClientMetadata = NULL
)
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
AttributeName |
[required] The name of the attribute that the user wants to verify, for example |
ClientMetadata |
A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When Amazon Cognito invokes any of these functions, it passes a JSON payload, which the function receives as input. This payload contains a To review the Lambda trigger types that Amazon Cognito invokes at runtime with API requests, see Connecting API actions to Lambda triggers in the Amazon Cognito Developer Guide. When you use the
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.