Lists the user import jobs.
cognitoidentityprovider_list_user_import_jobs(UserPoolId, MaxResults,
PaginationToken)[required] The user pool ID for the user pool that the users are being imported into.
[required] The maximum number of import jobs you want the request to return.
An identifier that was returned from the previous call to
ListUserImportJobs, which can be used to return the next set of import
jobs in the list.
svc$list_user_import_jobs( UserPoolId = "string", MaxResults = 123, PaginationToken = "string" )