View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_set_risk_configuration | R Documentation |
Configures threat protection for a user pool or app client. Sets configuration for the following.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_risk_configuration/ for full documentation.
cognitoidentityprovider_set_risk_configuration(
UserPoolId,
ClientId = NULL,
CompromisedCredentialsRiskConfiguration = NULL,
AccountTakeoverRiskConfiguration = NULL,
RiskExceptionConfiguration = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to set a risk configuration. If you include |
ClientId |
The ID of the app client where you want to set a risk configuration. If When you include a |
CompromisedCredentialsRiskConfiguration |
The configuration of automated reactions to detected compromised credentials. Includes settings for blocking future sign-in requests and for the types of password-submission events you want to monitor. |
AccountTakeoverRiskConfiguration |
The settings for automated responses and notification templates for adaptive authentication with threat protection. |
RiskExceptionConfiguration |
A set of IP-address overrides to threat protection. You can set up IP-address always-block and always-allow lists. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.