View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_set_ui_customization | R Documentation |
Configures UI branding settings for domains with the hosted UI (classic) branding version. Your user pool must have a domain. Configure a domain with .
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_ui_customization/ for full documentation.
cognitoidentityprovider_set_ui_customization(
UserPoolId,
ClientId = NULL,
CSS = NULL,
ImageFile = NULL
)
UserPoolId |
[required] The ID of the user pool where you want to apply branding to the classic hosted UI. |
ClientId |
The ID of the app client that you want to customize. To apply a default style to all app clients not configured with client-level branding, set this parameter value to |
CSS |
A plaintext CSS file that contains the custom fields that you want to apply to your user pool or app client. To download a template, go to the Amazon Cognito console. Navigate to your user pool App clients tab, select Login pages, edit Hosted UI (classic) style, and select the link to |
ImageFile |
The image that you want to set as your login in the classic hosted UI, as a Base64-formatted binary object. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.