View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_set_user_mfa_preference | R Documentation |
Set the user's multi-factor authentication (MFA) method preference, including which MFA factors are activated and if any are preferred. Only one factor can be set as preferred. The preferred MFA factor will be used to authenticate a user if multiple factors are activated. If multiple options are activated and no preference is set, a challenge to choose an MFA option will be returned during sign-in. If an MFA type is activated for a user, the user will be prompted for MFA during all sign-in attempts unless device tracking is turned on and the device has been trusted. If you want MFA to be applied selectively based on the assessed risk level of sign-in attempts, deactivate MFA for users and turn on Adaptive Authentication for the user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_user_mfa_preference/ for full documentation.
cognitoidentityprovider_set_user_mfa_preference(
SMSMfaSettings = NULL,
SoftwareTokenMfaSettings = NULL,
EmailMfaSettings = NULL,
WebAuthnMfaSettings = NULL,
AccessToken
)
SMSMfaSettings |
User preferences for SMS message MFA. Activates or deactivates SMS MFA and sets it as the preferred MFA method when multiple methods are available. |
SoftwareTokenMfaSettings |
User preferences for time-based one-time password (TOTP) MFA. Activates or deactivates TOTP MFA and sets it as the preferred MFA method when multiple methods are available. Users must register a TOTP authenticator before they set this as their preferred MFA method. |
EmailMfaSettings |
User preferences for email message MFA. Activates or deactivates email MFA and sets it as the preferred MFA method when multiple methods are available. To activate this setting, your user pool must be in the Essentials tier or higher. |
WebAuthnMfaSettings |
User preferences for passkey MFA. Activates or deactivates passkey MFA for the user. When activated, passkey authentication requires user verification, and passkey sign-in is available when MFA is required. To activate this setting, the |
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.