View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_set_user_pool_mfa_config | R Documentation |
Sets user pool multi-factor authentication (MFA) and passkey configuration. For more information about user pool MFA, see Adding MFA. For more information about WebAuthn passkeys see Authentication flows.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_set_user_pool_mfa_config/ for full documentation.
cognitoidentityprovider_set_user_pool_mfa_config(
UserPoolId,
SmsMfaConfiguration = NULL,
SoftwareTokenMfaConfiguration = NULL,
EmailMfaConfiguration = NULL,
MfaConfiguration = NULL,
WebAuthnConfiguration = NULL
)
UserPoolId |
[required] The user pool ID. |
SmsMfaConfiguration |
Configures user pool SMS messages for MFA. Sets the message template and the SMS message sending configuration for Amazon SNS. |
SoftwareTokenMfaConfiguration |
Configures a user pool for time-based one-time password (TOTP) MFA. Enables or disables TOTP. |
EmailMfaConfiguration |
Sets configuration for user pool email message MFA and sign-in with one-time passwords (OTPs). Includes the subject and body of the email message template for sign-in and MFA messages. To activate this setting, your user pool must be in the Essentials tier or higher. |
MfaConfiguration |
Sets multi-factor authentication (MFA) to be on, off, or optional. When When |
WebAuthnConfiguration |
The configuration of your user pool for passkey, or WebAuthn, authentication and registration. Includes relying-party configuration, user-verification requirements, and whether passkeys can satisfy MFA requirements. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.