View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_start_user_import_job | R Documentation |
Instructs your user pool to start importing users from a CSV file that contains their usernames and attributes. For more information about importing users from a CSV file, see Importing users from a CSV file.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_start_user_import_job/ for full documentation.
cognitoidentityprovider_start_user_import_job(UserPoolId, JobId)
UserPoolId |
[required] The ID of the user pool that you want to start importing users into. |
JobId |
[required] The ID of a user import job that you previously created. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.