View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_start_web_authn_registration | R Documentation |
Requests credential creation options from your user pool for the currently signed-in user. Returns information about the user pool, the user profile, and authentication requirements. Users must provide this information in their request to enroll your application with their passkey provider.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_start_web_authn_registration/ for full documentation.
cognitoidentityprovider_start_web_authn_registration(AccessToken)
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.