View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_untag_resource | R Documentation |
Given tag IDs that you previously assigned to a user pool, removes them.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_untag_resource/ for full documentation.
cognitoidentityprovider_untag_resource(ResourceArn, TagKeys)
ResourceArn |
[required] The Amazon Resource Name (ARN) of the user pool that the tags are assigned to. |
TagKeys |
[required] An array of tag keys that you want to remove from the user pool. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.