cognitoidentityprovider_untag_resource: Removes the specified tags from an Amazon Cognito user pool
Description
Removes the specified tags from an Amazon Cognito user pool. You can use
this action up to 5 times per second, per account
Usage
cognitoidentityprovider_untag_resource(ResourceArn, TagKeys)
Arguments
ResourceArn
[required] The Amazon Resource Name (ARN) of the user pool that the tags are
assigned to.
TagKeys
The keys of the tags to remove from the user pool.
Request syntax
svc$untag_resource(
ResourceArn = "string",
TagKeys = list(
"string"
)
)