View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_auth_event_feedback | R Documentation |
Provides the feedback for an authentication event generated by threat protection features. The user's response indicates that you think that the event either was from a valid user or was an unwanted authentication attempt. This feedback improves the risk evaluation decision for the user pool as part of Amazon Cognito threat protection. To activate this setting, your user pool must be on the Plus tier.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_auth_event_feedback/ for full documentation.
cognitoidentityprovider_update_auth_event_feedback(
UserPoolId,
Username,
EventId,
FeedbackToken,
FeedbackValue
)
UserPoolId |
[required] The ID of the user pool where you want to update auth event feedback. |
Username |
[required] The name of the user that you want to query or modify. The value of this parameter is typically your user's username, but it can be any of their alias attributes. If |
EventId |
[required] The ID of the authentication event that you want to submit feedback for. |
FeedbackToken |
[required] The feedback token, an encrypted object generated by Amazon Cognito and passed to your user in the notification email message from the event. |
FeedbackValue |
[required] Your feedback to the authentication event. When you provide a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.