View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_device_status | R Documentation |
Updates the status of a the currently signed-in user's device so that it is marked as remembered or not remembered for the purpose of device authentication. Device authentication is a "remember me" mechanism that silently completes sign-in from trusted devices with a device key instead of a user-provided MFA code. This operation changes the status of a device without deleting it, so you can enable it again later. For more information about device authentication, see Working with devices.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_device_status/ for full documentation.
cognitoidentityprovider_update_device_status(
AccessToken,
DeviceKey,
DeviceRememberedStatus = NULL
)
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
DeviceKey |
[required] The device key of the device you want to update, for example |
DeviceRememberedStatus |
To enable device authentication with the specified device, set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.