View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_group | R Documentation |
Given the name of a user pool group, updates any of the properties for precedence, IAM role, or description. For more information about user pool groups, see Adding groups to a user pool.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_group/ for full documentation.
cognitoidentityprovider_update_group(
GroupName,
UserPoolId,
Description = NULL,
RoleArn = NULL,
Precedence = NULL
)
GroupName |
[required] The name of the group that you want to update. |
UserPoolId |
[required] The ID of the user pool that contains the group you want to update. |
Description |
A new description of the existing group. |
RoleArn |
The Amazon Resource Name (ARN) of an IAM role that you want to associate with the group. The role assignment contributes to the |
Precedence |
A non-negative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. Zero is the highest precedence value. Groups with lower Two groups can have the same The default |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.