View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_resource_server | R Documentation |
Updates the name and scopes of a resource server. All other fields are read-only. For more information about resource servers, see Access control with resource servers.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_resource_server/ for full documentation.
cognitoidentityprovider_update_resource_server(
UserPoolId,
Identifier,
Name,
Scopes = NULL
)
UserPoolId |
[required] The ID of the user pool that contains the resource server that you want to update. |
Identifier |
[required] A unique resource server identifier for the resource server. The identifier can be an API friendly name like Amazon Cognito represents scopes in the access token in the format |
Name |
[required] The updated name of the resource server. |
Scopes |
An array of updated custom scope names and descriptions that you want to associate with your resource server. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.