View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_terms | R Documentation |
Modifies existing terms documents for the requested app client. When Terms and conditions and Privacy policy documents are configured, the app client displays links to them in the sign-up page of managed login for the app client.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_terms/ for full documentation.
cognitoidentityprovider_update_terms(
TermsId,
UserPoolId,
TermsName = NULL,
TermsSource = NULL,
Enforcement = NULL,
Links = NULL
)
TermsId |
[required] The ID of the terms document that you want to update. |
UserPoolId |
[required] The ID of the user pool that contains the terms that you want to update. |
TermsName |
The new name that you want to apply to the requested terms documents. |
TermsSource |
This parameter is reserved for future use and currently accepts only one value. |
Enforcement |
This parameter is reserved for future use and currently accepts only one value. |
Links |
A map of URLs to languages. For each localized language that will view the requested For example, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.