View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_update_user_pool_domain | R Documentation |
A user pool domain hosts managed login, an authorization server and web server for authentication in your application. This operation updates the branding version for user pool domains between 1 for hosted UI (classic) and 2 for managed login. It also updates the SSL certificate for user pool custom domains.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_update_user_pool_domain/ for full documentation.
cognitoidentityprovider_update_user_pool_domain(
Domain,
UserPoolId,
ManagedLoginVersion = NULL,
CustomDomainConfig = NULL
)
Domain |
[required] The name of the domain that you want to update. For custom domains, this is the fully-qualified domain name, for example |
UserPoolId |
[required] The ID of the user pool that is associated with the domain you're updating. |
ManagedLoginVersion |
A version number that indicates the state of managed login for your domain. Version |
CustomDomainConfig |
The configuration for a custom domain that hosts managed login for your application. In an When you create a custom domain, the passkey RP ID defaults to the custom domain. If you had a prefix domain active, this will cause passkey integration for your prefix domain to stop working due to a mismatch in RP ID. To keep the prefix domain passkey integration working, you can explicitly set RP ID to the prefix domain. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.