View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_verify_software_token | R Documentation |
Registers the current user's time-based one-time password (TOTP) authenticator with a code generated in their authenticator app from a private key that's supplied by your user pool. Marks the user's software token MFA status as "verified" if successful. The request takes an access token or a session string, but not both.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_verify_software_token/ for full documentation.
cognitoidentityprovider_verify_software_token(
AccessToken = NULL,
Session = NULL,
UserCode,
FriendlyDeviceName = NULL
)
AccessToken |
A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
Session |
The session ID from an |
UserCode |
[required] A TOTP that the user generated in their configured authenticator app. |
FriendlyDeviceName |
A friendly name for the device that's running the TOTP authenticator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.