Use this API to register a user's entered TOTP code and mark the user's software token MFA status as "verified" if successful. The request takes an access token or a session string, but not both.
cognitoidentityprovider_verify_software_token(AccessToken, Session,
UserCode, FriendlyDeviceName)A list with the following syntax:
list(
Status = "SUCCESS"|"ERROR",
Session = "string"
)
The access token.
The session which should be passed both ways in challenge-response calls to the service.
[required] The one time password computed using the secret code returned by AssociateSoftwareToken".
The friendly device name.
svc$verify_software_token(
AccessToken = "string",
Session = "string",
UserCode = "string",
FriendlyDeviceName = "string"
)