View source: R/cognitoidentityprovider_operations.R
| cognitoidentityprovider_verify_user_attribute | R Documentation |
Submits a verification code for a signed-in user who has added or changed a value of an auto-verified attribute. When successful, the user's attribute becomes verified and the attribute email_verified or phone_number_verified becomes true.
See https://www.paws-r-sdk.com/docs/cognitoidentityprovider_verify_user_attribute/ for full documentation.
cognitoidentityprovider_verify_user_attribute(AccessToken, AttributeName, Code)
AccessToken |
[required] A valid access token that Amazon Cognito issued to the currently signed-in user. Must include a scope claim for |
AttributeName |
[required] The name of the attribute that you want to verify. |
Code |
[required] The verification code that your user pool sent to the added or changed attribute, for example the user's email address. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.