cognitosync_list_identity_pool_usage: Gets a list of identity pools registered with Cognito
Description
Gets a list of identity pools registered with Cognito.
ListIdentityPoolUsage can only be called with developer credentials. You
cannot make this API call with the temporary user credentials provided
by Cognito Identity.
Usage
cognitosync_list_identity_pool_usage(NextToken, MaxResults)
Arguments
NextToken
A pagination token for obtaining the next page of results.
MaxResults
The maximum number of results to be returned.
Request syntax
svc$list_identity_pool_usage(
NextToken = "string",
MaxResults = 123
)