View source: R/directoryservice_operations.R
| directoryservice_create_hybrid_ad | R Documentation |
Creates a hybrid directory that connects your self-managed Active Directory (AD) infrastructure and Amazon Web Services.
See https://www.paws-r-sdk.com/docs/directoryservice_create_hybrid_ad/ for full documentation.
directoryservice_create_hybrid_ad(SecretArn, AssessmentId, Tags = NULL)
SecretArn |
[required] The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that contains the credentials for the service account used to join hybrid domain controllers to your self-managed AD domain. This secret is used once and not stored. The secret must contain key-value pairs with keys matching |
AssessmentId |
[required] The unique identifier of the successful directory assessment that validates your self-managed AD environment. You must have a successful directory assessment before you create a hybrid directory. |
Tags |
The tags to be assigned to the directory. Each tag consists of a key and value pair. You can specify multiple tags as a list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.