View source: R/directoryservice_operations.R
| directoryservice_describe_ca_enrollment_policy | R Documentation |
Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory. This policy determines how client certificates are automatically enrolled and managed through Amazon Web Services Private Certificate Authority.
See https://www.paws-r-sdk.com/docs/directoryservice_describe_ca_enrollment_policy/ for full documentation.
directoryservice_describe_ca_enrollment_policy(DirectoryId)
DirectoryId |
[required] The identifier of the directory for which to retrieve the CA enrollment policy information. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.