directoryservice_describe_certificate: Displays information about the certificate registered for secure LDAP or
client certificate authentication
Description
Displays information about the certificate registered for secure LDAP or
client certificate authentication.
Usage
directoryservice_describe_certificate(DirectoryId, CertificateId)
Arguments
DirectoryId
[required] The identifier of the directory.
CertificateId
[required] The identifier of the certificate.
Request syntax
svc$describe_certificate(
DirectoryId = "string",
CertificateId = "string"
)