View source: R/directoryservice_operations.R
| directoryservice_enable_ca_enrollment_policy | R Documentation |
Enables certificate authority (CA) enrollment policy for the specified directory. This allows domain-joined clients to automatically request and receive certificates from the specified Amazon Web Services Private Certificate Authority.
See https://www.paws-r-sdk.com/docs/directoryservice_enable_ca_enrollment_policy/ for full documentation.
directoryservice_enable_ca_enrollment_policy(DirectoryId, PcaConnectorArn)
DirectoryId |
[required] The identifier of the directory for which to enable the CA enrollment policy. |
PcaConnectorArn |
[required] The Amazon Resource Name (ARN) of the Private Certificate Authority (PCA) connector to use for automatic certificate enrollment. This connector must be properly configured and accessible from the directory. The ARN format is: |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.