View source: R/directoryservice_operations.R
| directoryservice_update_directory_setup | R Documentation |
Updates directory configuration for the specified update type.
See https://www.paws-r-sdk.com/docs/directoryservice_update_directory_setup/ for full documentation.
directoryservice_update_directory_setup(
DirectoryId,
UpdateType,
OSUpdateSettings = NULL,
DirectorySizeUpdateSettings = NULL,
NetworkUpdateSettings = NULL,
CreateSnapshotBeforeUpdate = NULL
)
DirectoryId |
[required] The identifier of the directory to update. |
UpdateType |
[required] The type of update to perform on the directory. |
OSUpdateSettings |
Operating system configuration to apply during the directory update operation. |
DirectorySizeUpdateSettings |
Directory size configuration to apply during the update operation. |
NetworkUpdateSettings |
Network configuration to apply during the directory update operation. |
CreateSnapshotBeforeUpdate |
Specifies whether to create a directory snapshot before performing the update. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.