View source: R/guardduty_operations.R
| guardduty_delete_trusted_entity_set | R Documentation |
Deletes the trusted entity set that is associated with the specified trustedEntitySetId.
See https://www.paws-r-sdk.com/docs/guardduty_delete_trusted_entity_set/ for full documentation.
guardduty_delete_trusted_entity_set(DetectorId, TrustedEntitySetId)
DetectorId |
[required] The unique ID of the detector associated with the trusted entity set resource. To find the |
TrustedEntitySetId |
[required] The unique ID that helps GuardDuty identify which trusted entity set needs to be deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.