View source: R/guardduty_operations.R
| guardduty_get_malware_scan | R Documentation |
Retrieves the detailed information for a specific malware scan. Each member account can view the malware scan details for their own account. An administrator can view malware scan details for all accounts in the organization.
See https://www.paws-r-sdk.com/docs/guardduty_get_malware_scan/ for full documentation.
guardduty_get_malware_scan(ScanId)
ScanId |
[required] A unique identifier that gets generated when you invoke the API without any error. Each malware scan has a corresponding scan ID. Using this scan ID, you can monitor the status of your malware scan. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.