View source: R/guardduty_operations.R
| guardduty_start_malware_scan | R Documentation |
Initiates the malware scan. Invoking this API will automatically create the Service-linked role in the corresponding account if the resourceArn belongs to an EC2 instance.
See https://www.paws-r-sdk.com/docs/guardduty_start_malware_scan/ for full documentation.
guardduty_start_malware_scan(
ResourceArn,
ClientToken = NULL,
ScanConfiguration = NULL
)
ResourceArn |
[required] Amazon Resource Name (ARN) of the resource for which you invoked the API. |
ClientToken |
The idempotency token for the create request. |
ScanConfiguration |
Contains information about the configuration to be used for the malware scan. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.