View source: R/iam_operations.R
| iam_accept_delegation_request | R Documentation |
Accepts a delegation request, granting the requested temporary access.
See https://www.paws-r-sdk.com/docs/iam_accept_delegation_request/ for full documentation.
iam_accept_delegation_request(DelegationRequestId)
DelegationRequestId |
[required] The unique identifier of the delegation request to accept. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.