View source: R/iam_operations.R
| iam_get_delegation_request | R Documentation |
Retrieves information about a specific delegation request.
See https://www.paws-r-sdk.com/docs/iam_get_delegation_request/ for full documentation.
iam_get_delegation_request(
DelegationRequestId,
DelegationPermissionCheck = NULL
)
DelegationRequestId |
[required] The unique identifier of the delegation request to retrieve. |
DelegationPermissionCheck |
Specifies whether to perform a permission check for the delegation request. If set to true, the Setting this parameter to true does not guarantee an answer in the response. See the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.