View source: R/iam_operations.R
| iam_get_human_readable_summary | R Documentation |
Retrieves a human readable summary for a given entity. At this time, the only supported entity type is delegation-request
See https://www.paws-r-sdk.com/docs/iam_get_human_readable_summary/ for full documentation.
iam_get_human_readable_summary(EntityArn, Locale = NULL)
EntityArn |
[required] Arn of the entity to be summarized. At this time, the only supported entity type is |
Locale |
A string representing the locale to use for the summary generation. The supported locale strings are based on the Supported languages of the Amazon Web Services Management Console . |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.