View source: R/iam_operations.R
| iam_send_delegation_token | R Documentation |
Sends the exchange token for an accepted delegation request.
See https://www.paws-r-sdk.com/docs/iam_send_delegation_token/ for full documentation.
iam_send_delegation_token(DelegationRequestId)
DelegationRequestId |
[required] The unique identifier of the delegation request for which to send the token. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.