Learn R Programming

paws.security.identity (version 0.1.10)

iam_update_login_profile: Changes the password for the specified IAM user

Description

Changes the password for the specified IAM user.

IAM users can change their own passwords by calling ChangePassword. For more information about modifying passwords, see Managing Passwords in the IAM User Guide.

Usage

iam_update_login_profile(UserName, Password, PasswordResetRequired)

Arguments

UserName

[required] The name of the user whose password you want to update.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: \_+=,.@-

Password

The new password for the specified IAM user.

The regex pattern used to validate this parameter is a string of characters consisting of the following:

  • Any printable ASCII character ranging from the space character (U+0020) through the end of the ASCII character range

  • The printable characters in the Basic Latin and Latin-1 Supplement character set (through U+00FF)

  • The special characters tab (U+0009), line feed (U+000A), and carriage return (U+000D)

However, the format can be further restricted by the account administrator by setting a password policy on the AWS account. For more information, see UpdateAccountPasswordPolicy.

PasswordResetRequired

Allows this new password to be used only once by requiring the specified IAM user to set a new password on next sign-in.

Request syntax

svc$update_login_profile(
  UserName = "string",
  Password = "string",
  PasswordResetRequired = TRUE|FALSE
)

Examples

Run this code
# NOT RUN {
# The following command creates or changes the password for the IAM user
# named Bob.
svc$update_login_profile(
  Password = "SomeKindOfPassword123!@#",
  UserName = "Bob"
)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab