View source: R/identitystore_operations.R
| identitystore_update_group | R Documentation |
Updates the specified group metadata and attributes in the specified identity store.
See https://www.paws-r-sdk.com/docs/identitystore_update_group/ for full documentation.
identitystore_update_group(IdentityStoreId, GroupId, Operations)
IdentityStoreId |
[required] The globally unique identifier for the identity store. |
GroupId |
[required] The identifier for a group in the identity store. |
Operations |
[required] A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.