View source: R/identitystore_operations.R
| identitystore_update_user | R Documentation |
Updates the specified user metadata and attributes in the specified identity store.
See https://www.paws-r-sdk.com/docs/identitystore_update_user/ for full documentation.
identitystore_update_user(IdentityStoreId, UserId, Operations)
IdentityStoreId |
[required] The globally unique identifier for the identity store. |
UserId |
[required] The identifier for a user in the identity store. |
Operations |
[required] A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.