View source: R/inspector2_operations.R
| inspector2_create_code_security_integration | R Documentation |
Creates a code security integration with a source code repository provider.
See https://www.paws-r-sdk.com/docs/inspector2_create_code_security_integration/ for full documentation.
inspector2_create_code_security_integration(
name,
type,
details = NULL,
tags = NULL
)
name |
[required] The name of the code security integration. |
type |
[required] The type of repository provider for the integration. |
details |
The integration details specific to the repository provider type. |
tags |
The tags to apply to the code security integration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.