| inspector2_list_code_security_scan_configuration_associations | R Documentation |
Lists the associations between code repositories and Amazon Inspector code security scan configurations.
See https://www.paws-r-sdk.com/docs/inspector2_list_code_security_scan_configuration_associations/ for full documentation.
inspector2_list_code_security_scan_configuration_associations(
scanConfigurationArn,
nextToken = NULL,
maxResults = NULL
)
scanConfigurationArn |
[required] The Amazon Resource Name (ARN) of the scan configuration to list associations for. |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the |
maxResults |
The maximum number of results to return in the response. If your request would return more than the maximum the response will return a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.