View source: R/inspector2_operations.R
| inspector2_list_code_security_scan_configurations | R Documentation |
Lists all code security scan configurations in your account.
See https://www.paws-r-sdk.com/docs/inspector2_list_code_security_scan_configurations/ for full documentation.
inspector2_list_code_security_scan_configurations(
nextToken = NULL,
maxResults = NULL
)
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page. |
maxResults |
The maximum number of results to return in a single call. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.