View source: R/kms_operations.R
| kms_get_key_last_usage | R Documentation |
Returns usage information about the last successful cryptographic operation performed with a specified KMS key, including the operation type, timestamp, and associated CloudTrail event ID.
See https://www.paws-r-sdk.com/docs/kms_get_key_last_usage/ for full documentation.
kms_get_key_last_usage(KeyId)
KeyId |
[required] Identifies the KMS key to get usage information for. To specify a KMS key, use its key ID or key ARN. Alias names are not supported. Specify the key ID or key ARN of the KMS key. For example:
To get the key ID and key ARN for a KMS key, use |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.