View source: R/kms_operations.R
| kms_import_key_material | R Documentation |
Imports or reimports key material into an existing KMS key that was created without key material. You can also use this operation to set or update the expiration model and expiration date of the imported key material.
See https://www.paws-r-sdk.com/docs/kms_import_key_material/ for full documentation.
kms_import_key_material(
KeyId,
ImportToken,
EncryptedKeyMaterial,
ValidTo = NULL,
ExpirationModel = NULL,
ImportType = NULL,
KeyMaterialDescription = NULL,
KeyMaterialId = NULL
)
KeyId |
[required] The identifier of the KMS key that will be associated with the imported key material. This must be the same KMS key specified in the The KMS key can be a symmetric encryption KMS key, HMAC KMS key, asymmetric encryption KMS key, or asymmetric signing KMS key, including a multi-Region key of any supported type. You cannot perform this operation on a KMS key in a custom key store, or on a KMS key in a different Amazon Web Services account. Specify the key ID or key ARN of the KMS key. For example:
To get the key ID and key ARN for a KMS key, use |
ImportToken |
[required] The import token that you received in the response to a previous |
EncryptedKeyMaterial |
[required] The encrypted key material to import. The key material must be encrypted under the public wrapping key that |
ValidTo |
The date and time when the imported key material expires. This parameter is required when the value of the The value of this parameter must be a future date and time. The maximum value is 365 days from the request date. When the key material expires, KMS deletes the key material from the KMS key. Without its key material, the KMS key is unusable. To use the KMS key in cryptographic operations, you must reimport the same key material. You cannot change the |
ExpirationModel |
Specifies whether the key material expires. The default is When the value of You cannot change the |
ImportType |
Indicates whether the key material being imported is previously associated with this KMS key or not. This parameter is optional and only usable with symmetric encryption keys. If no key material has ever been imported into the KMS key, and this parameter is omitted, the parameter defaults to For multi-Region keys, you must first import new key material into the primary Region key. You should use the |
KeyMaterialDescription |
Description for the key material being imported. This parameter is optional and only usable with symmetric encryption keys. If you do not specify a key material description, KMS retains the value you specified when you last imported the same key material into this KMS key. |
KeyMaterialId |
Identifies the key material being imported. This parameter is optional and only usable with symmetric encryption keys. You cannot specify a key material ID with
To get the list of key material IDs associated with a KMS key, use |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.