View source: R/kms_operations.R
| kms_list_key_rotations | R Documentation |
Returns information about the key materials associated with the specified KMS key. You can use the optional IncludeKeyMaterial parameter to control which key materials are included in the response.
See https://www.paws-r-sdk.com/docs/kms_list_key_rotations/ for full documentation.
kms_list_key_rotations(
KeyId,
IncludeKeyMaterial = NULL,
Limit = NULL,
Marker = NULL
)
KeyId |
[required] Gets the key rotations for the specified KMS key. Specify the key ID or key ARN of the KMS key. For example:
To get the key ID and key ARN for a KMS key, use |
IncludeKeyMaterial |
Use this optional parameter to control which key materials associated with this key are listed in the response. The default value of this parameter is |
Limit |
Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 1000, inclusive. If you do not include a value, it defaults to 100. |
Marker |
Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.