View source: R/ram_operations.R
| ram_list_source_associations | R Documentation |
Lists source associations for resource shares. Source associations control which sources can be used with service principals in resource shares. This operation provides visibility into source associations for resource share owners.
See https://www.paws-r-sdk.com/docs/ram_list_source_associations/ for full documentation.
ram_list_source_associations(
resourceShareArns = NULL,
sourceId = NULL,
sourceType = NULL,
associationStatus = NULL,
nextToken = NULL,
maxResults = NULL
)
resourceShareArns |
The Amazon Resource Names (ARNs) of the resource shares for which you want to retrieve source associations. |
sourceId |
The identifier of the source for which you want to retrieve associations. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path. |
sourceType |
The type of source for which you want to retrieve associations. |
associationStatus |
The status of the source associations that you want to retrieve. |
nextToken |
The pagination token that indicates the next set of results to retrieve. |
maxResults |
The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.