View source: R/secretsmanager_operations.R
| secretsmanager_rotate_secret | R Documentation |
Configures and starts the asynchronous process of rotating the secret. For information about rotation, see Rotate secrets in the Secrets Manager User Guide. If you include the configuration parameters, the operation sets the values for the secret and then immediately starts a rotation. If you don't include the configuration parameters, the operation starts a rotation with the values already stored in the secret.
See https://www.paws-r-sdk.com/docs/secretsmanager_rotate_secret/ for full documentation.
secretsmanager_rotate_secret(
SecretId,
ClientRequestToken = NULL,
RotationLambdaARN = NULL,
RotationRules = NULL,
ExternalSecretRotationMetadata = NULL,
ExternalSecretRotationRoleArn = NULL,
RotateImmediately = NULL
)
SecretId |
[required] The ARN or name of the secret to rotate. For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN. |
ClientRequestToken |
A unique identifier for the new version of the secret. You only need to specify this value if you implement your own retry logic and you want to ensure that Secrets Manager doesn't attempt to create a secret version twice. If you use the Amazon Web Services CLI or one of the Amazon Web Services SDKs to call this operation, then you can leave this parameter empty. The CLI or SDK generates a random UUID for you and includes it as the value for this parameter in the request. If you generate a raw HTTP request to the Secrets Manager service endpoint, then you must generate a This value helps ensure idempotency. Secrets Manager uses this value to prevent the accidental creation of duplicate versions if there are failures and retries during a rotation. We recommend that you generate a UUID-type value to ensure uniqueness of your versions within the specified secret. |
RotationLambdaARN |
For secrets that use a Lambda rotation function to rotate, the ARN of the Lambda rotation function. For secrets that use managed rotation, omit this field. For more information, see Managed rotation in the Secrets Manager User Guide. |
RotationRules |
A structure that defines the rotation configuration for this secret. When changing an existing rotation schedule and setting
|
ExternalSecretRotationMetadata |
The metadata needed to successfully rotate a managed external secret. A list of key value pairs in JSON format specified by the partner. For more information about the required information, see Using Secrets Manager managed external secrets |
ExternalSecretRotationRoleArn |
The Amazon Resource Name (ARN) of the role that allows Secrets Manager to rotate a secret held by a third-party partner. For more information, see Security and permissions. |
RotateImmediately |
Specifies whether to rotate the secret immediately or wait until the next scheduled rotation window. The rotation schedule is defined in RotateSecretRequest$RotationRules. The default for If you set When changing an existing rotation schedule and setting
Rotation is an asynchronous process. For more information, see How rotation works. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.