View source: R/securityhub_operations.R
| securityhub_batch_update_findings_v2 | R Documentation |
Updates information about a customer's investigation into a finding. Delegated administrator accounts can update findings for their account and their member accounts. Member accounts can update findings for their own account.
See https://www.paws-r-sdk.com/docs/securityhub_batch_update_findings_v2/ for full documentation.
securityhub_batch_update_findings_v2(
MetadataUids = NULL,
FindingIdentifiers = NULL,
Comment = NULL,
SeverityId = NULL,
StatusId = NULL
)
MetadataUids |
The list of finding |
FindingIdentifiers |
Provides information to identify a specific V2 finding. |
Comment |
The updated value for a user provided comment about the finding. Minimum character length 1. Maximum character length 512. |
SeverityId |
The updated value for the normalized severity identifier. The severity ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 6, 99]. When customer provides the updated severity ID, the string sibling severity will automatically be updated in the finding. |
StatusId |
The updated value for the normalized status identifier. The status ID is an integer with the allowed enum values [0, 1, 2, 3, 4, 5, 99]. When customer provides the updated status ID, the string sibling status will automatically be updated in the finding. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.