View source: R/securityhub_operations.R
| securityhub_create_automation_rule_v2 | R Documentation |
Creates a V2 automation rule.
See https://www.paws-r-sdk.com/docs/securityhub_create_automation_rule_v2/ for full documentation.
securityhub_create_automation_rule_v2(
RuleName,
RuleStatus = NULL,
Description,
RuleOrder,
Criteria,
Actions,
Tags = NULL,
ClientToken = NULL
)
RuleName |
[required] The name of the V2 automation rule. |
RuleStatus |
The status of the V2 automation rule. |
Description |
[required] A description of the V2 automation rule. |
RuleOrder |
[required] The value for the rule priority. |
Criteria |
[required] The filtering type and configuration of the automation rule. |
Actions |
[required] A list of actions to be performed when the rule criteria is met. |
Tags |
A list of key-value pairs associated with the V2 automation rule. |
ClientToken |
A unique identifier used to ensure idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.