View source: R/securityhub_operations.R
| securityhub_create_ticket_v2 | R Documentation |
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.
See https://www.paws-r-sdk.com/docs/securityhub_create_ticket_v2/ for full documentation.
securityhub_create_ticket_v2(
ConnectorId,
FindingMetadataUid,
ClientToken = NULL,
Mode = NULL
)
ConnectorId |
[required] The UUID of the connectorV2 to identify connectorV2 resource. |
FindingMetadataUid |
[required] The the unique ID for the finding. |
ClientToken |
The client idempotency token. |
Mode |
The mode for ticket creation. When set to DRYRUN, the ticket is created using a Security Hub owned template test finding to verify the integration is working correctly. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.