View source: R/securityhub_operations.R
| securityhub_enable_security_hub_v2 | R Documentation |
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.
See https://www.paws-r-sdk.com/docs/securityhub_enable_security_hub_v2/ for full documentation.
securityhub_enable_security_hub_v2(Tags = NULL)
Tags |
The tags to add to the hub V2 resource when you enable Security Hub. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.