View source: R/securityhub_operations.R
| securityhub_get_finding_history | R Documentation |
Returns the history of a Security Hub CSPM finding. The history includes changes made to any fields in the Amazon Web Services Security Finding Format (ASFF) except top-level timestamp fields, such as the CreatedAt and UpdatedAt fields.
See https://www.paws-r-sdk.com/docs/securityhub_get_finding_history/ for full documentation.
securityhub_get_finding_history(
FindingIdentifier,
StartTime = NULL,
EndTime = NULL,
NextToken = NULL,
MaxResults = NULL
)
FindingIdentifier |
[required] Identifies which finding to get the finding history for. |
StartTime |
A timestamp that indicates the start time of the requested finding history. If you provide values for both For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps. |
EndTime |
An ISO 8601-formatted timestamp that indicates the end time of the requested finding history. If you provide values for both For more information about the validation and formatting of timestamp fields in Security Hub CSPM, see Timestamps. |
NextToken |
A token for pagination purposes. Provide |
MaxResults |
The maximum number of results to be returned. If you don’t provide it, Security Hub CSPM returns up to 100 results of finding history. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.