View source: R/securityhub_operations.R
| securityhub_get_resources_v2 | R Documentation |
Returns a list of resources.
See https://www.paws-r-sdk.com/docs/securityhub_get_resources_v2/ for full documentation.
securityhub_get_resources_v2(
Filters = NULL,
Scopes = NULL,
SortCriteria = NULL,
NextToken = NULL,
MaxResults = NULL
)
Filters |
Filters resources based on a set of criteria. |
Scopes |
Limits the results to resources from specific organizational units or from the delegated administrator's organization. Only the delegated administrator account can use this parameter. Other accounts receive an This parameter is optional. If you omit it, the delegated administrator sees resources from all accounts across the entire organization. Other accounts see only their own resources. You can specify up to 10 entries in |
SortCriteria |
The resource attributes used to sort the list of returned resources. |
NextToken |
The token required for pagination. On your first call, set the value of this parameter to |
MaxResults |
The maximum number of results to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.