Lists all findings-generating solutions (products) whose findings you have subscribed to receive in Security Hub.
securityhub_list_enabled_products_for_import(NextToken, MaxResults)Paginates results. On your first call to the
ListEnabledProductsForImport operation, set the value of this
parameter to NULL. For subsequent calls to the operation, fill
nextToken in the request with the value of NextToken from the
previous response to continue listing data.
The maximum number of items that you want in the response.
svc$list_enabled_products_for_import( NextToken = "string", MaxResults = 123 )