View source: R/securityhub_operations.R
| securityhub_update_automation_rule_v2 | R Documentation |
Updates a V2 automation rule.
See https://www.paws-r-sdk.com/docs/securityhub_update_automation_rule_v2/ for full documentation.
securityhub_update_automation_rule_v2(
Identifier,
RuleStatus = NULL,
RuleOrder = NULL,
Description = NULL,
RuleName = NULL,
Criteria = NULL,
Actions = NULL
)
Identifier |
[required] The ARN of the automation rule. |
RuleStatus |
The status of the automation rule. |
RuleOrder |
Represents a value for the rule priority. |
Description |
A description of the automation rule. |
RuleName |
The name of the automation rule. |
Criteria |
The filtering type and configuration of the automation rule. |
Actions |
A list of actions to be performed when the rule criteria is met. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.