View source: R/ssoadmin_operations.R
| ssoadmin_update_instance | R Documentation |
Update the details for the instance of IAM Identity Center that is owned by the Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/ssoadmin_update_instance/ for full documentation.
ssoadmin_update_instance(
Name = NULL,
InstanceArn,
EncryptionConfiguration = NULL
)
Name |
Updates the instance name. |
InstanceArn |
[required] The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference. |
EncryptionConfiguration |
Specifies the encryption configuration for your IAM Identity Center instance. You can use this to configure customer managed KMS keys or Amazon Web Services owned KMS keys for encrypting your instance data. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.