View source: R/sts_operations.R
| sts_get_delegated_access_token | R Documentation |
Exchanges a trade-in token for temporary Amazon Web Services credentials with the permissions associated with the assumed principal. This operation allows you to obtain credentials for a specific principal based on a trade-in token, enabling delegation of access to Amazon Web Services resources.
See https://www.paws-r-sdk.com/docs/sts_get_delegated_access_token/ for full documentation.
sts_get_delegated_access_token(TradeInToken)
TradeInToken |
[required] The token to exchange for temporary Amazon Web Services credentials. This token must be valid and unexpired at the time of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.