View source: R/verifiedpermissions_operations.R
| verifiedpermissions_create_policy | R Documentation |
Creates a Cedar policy and saves it in the specified policy store. You can create either a static policy or a policy linked to a policy template.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_create_policy/ for full documentation.
verifiedpermissions_create_policy(
clientToken = NULL,
policyStoreId,
definition,
name = NULL
)
clientToken |
Specifies a unique, case-sensitive ID that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value.. If you don't provide this value, then Amazon Web Services generates a random one for you. If you retry the operation with the same Verified Permissions recognizes a |
policyStoreId |
[required] Specifies the To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
definition |
[required] A structure that specifies the policy type and content to use for the new policy. You must include either a static or a templateLinked element. The policy content must be written in the Cedar policy language. |
name |
Specifies a name for the policy that is unique among all policies within the policy store. You can use the name in place of the policy ID in API operations that reference the policy. The name must be prefixed with If you specify a name that is already associated with another policy in the policy store, you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.