View source: R/verifiedpermissions_operations.R
| verifiedpermissions_create_policy_store_alias | R Documentation |
Creates a policy store alias for the specified policy store. A policy store alias is an alternative identifier that you can use to reference a policy store in API operations.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_create_policy_store_alias/ for full documentation.
verifiedpermissions_create_policy_store_alias(aliasName, policyStoreId)
aliasName |
[required] Specifies the name of the policy store alias to create. The name must be unique within your Amazon Web Services account and Amazon Web Services Region. The alias name must always be prefixed with |
policyStoreId |
[required] Specifies the ID of the policy store to associate with the alias. The associated policy store must be specified using its ID. The alias name cannot be used. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.