View source: R/verifiedpermissions_operations.R
| verifiedpermissions_delete_policy_store_alias | R Documentation |
Deletes the specified policy store alias.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy_store_alias/ for full documentation.
verifiedpermissions_delete_policy_store_alias(aliasName, deletionMode = NULL)
aliasName |
[required] Specifies the name of the policy store alias that you want to delete. The alias name must always be prefixed with |
deletionMode |
Specifies the deletion mode for the policy store alias. The valid values are:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.