View source: R/verifiedpermissions_operations.R
| verifiedpermissions_delete_policy_template | R Documentation |
Deletes the specified policy template from the policy store.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_delete_policy_template/ for full documentation.
verifiedpermissions_delete_policy_template(policyStoreId, policyTemplateId)
policyStoreId |
[required] Specifies the ID of the policy store that contains the policy template that you want to delete. To specify a policy store, use its ID or alias name. When using an alias name, prefix it with
To view aliases, use |
policyTemplateId |
[required] Specifies the ID of the policy template that you want to delete. You can use the policy template name in place of the policy template ID. When using a name, prefix it with
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.