View source: R/verifiedpermissions_operations.R
| verifiedpermissions_get_policy_store_alias | R Documentation |
Retrieves details about the specified policy store alias.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_get_policy_store_alias/ for full documentation.
verifiedpermissions_get_policy_store_alias(aliasName)
aliasName |
[required] Specifies the name of the policy store alias that you want information about. The alias name must always be prefixed with |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.