View source: R/verifiedpermissions_operations.R
| verifiedpermissions_tag_resource | R Documentation |
Assigns one or more tags (key-value pairs) to the specified Amazon Verified Permissions resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Verified Permissions, policy stores can be tagged.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_tag_resource/ for full documentation.
verifiedpermissions_tag_resource(resourceArn, tags)
resourceArn |
[required] The ARN of the resource that you're adding tags to. |
tags |
[required] The list of key-value pairs to associate with the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.