View source: R/verifiedpermissions_operations.R
| verifiedpermissions_untag_resource | R Documentation |
Removes one or more tags from the specified Amazon Verified Permissions resource. In Verified Permissions, policy stores can be tagged.
See https://www.paws-r-sdk.com/docs/verifiedpermissions_untag_resource/ for full documentation.
verifiedpermissions_untag_resource(resourceArn, tagKeys)
resourceArn |
[required] The ARN of the resource from which you are removing tags. |
tagKeys |
[required] The list of tag keys to remove from the resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.